@@ -34,415 +34,415 @@ int database_info_build_query_enum(char *s, size_t len,
       enum database_query_type type,
       const char *path)
 {
-   size_t pos = 0;
+   size_t _len = 0;
 
    switch (type)
    {
       case DATABASE_QUERY_ENTRY:
-         s[0]       = '{';
-         s[1]       = '\'';
-         s[2]       = 'n';
-         s[3]       = 'a';
-         s[4]       = 'm';
-         s[5]       = 'e';
-         s[6]       = '\'';
-         s[7]       = ':';
-         s[8]       = '"';
-         s[9]       = '\0';
-         pos        = strlcat(s, path, len);
-         s[pos  ]   = '"';
-         s[pos+1]   = '}';
-         s[pos+2]   = '\0';
+         s[  _len]  = '{';
+         s[++_len]  = '\'';
+         s[++_len]  = 'n';
+         s[++_len]  = 'a';
+         s[++_len]  = 'm';
+         s[++_len]  = 'e';
+         s[++_len]  = '\'';
+         s[++_len]  = ':';
+         s[++_len]  = '"';
+         s[++_len]  = '\0';
+         _len      += strlcpy(s + _len, path, len - _len);
+         s[  _len]  = '"';
+         s[++_len]  = '}';
+         s[++_len]  = '\0';
          break;
       case DATABASE_QUERY_ENTRY_PUBLISHER:
-         s[0]       = '{';
-         s[1]       = '\'';
-         s[2]       = 'p';
-         s[3]       = 'u';
-         s[4]       = 'b';
-         s[5]       = 'l';
-         s[6]       = 'i';
-         s[7]       = 's';
-         s[8]       = 'h';
-         s[9]       = 'e';
-         s[10]      = 'r';
-         s[11]      = '\'';
-         s[12]      = ':';
-         s[13]      = '"';
-         s[14]      = '\0';
-         pos        = strlcat(s, path, len);
-         s[pos  ]   = '"';
-         s[pos+1]   = '}';
-         s[pos+2]   = '\0';
+         s[  _len]  = '{';
+         s[++_len]  = '\'';
+         s[++_len]  = 'p';
+         s[++_len]  = 'u';
+         s[++_len]  = 'b';
+         s[++_len]  = 'l';
+         s[++_len]  = 'i';
+         s[++_len]  = 's';
+         s[++_len]  = 'h';
+         s[++_len]  = 'e';
+         s[++_len]  = 'r';
+         s[++_len]  = '\'';
+         s[++_len]  = ':';
+         s[++_len]  = '"';
+         s[++_len]  = '\0';
+         _len      += strlcpy(s + _len, path, len - _len);
+         s[  _len]  = '"';
+         s[++_len]  = '}';
+         s[++_len]  = '\0';
          break;
       case DATABASE_QUERY_ENTRY_DEVELOPER:
-         s[0]       = '{';
-         s[1]       = '\'';
-         s[2]       = 'd';
-         s[3]       = 'e';
-         s[4]       = 'v';
-         s[5]       = 'e';
-         s[6]       = 'l';
-         s[7]       = 'o';
-         s[8]       = 'p';
-         s[9]       = 'e';
-         s[10]      = 'r';
-         s[11]      = '\'';
-         s[12]      = ':';
-         s[13]      = 'g';
-         s[14]      = 'l';
-         s[15]      = 'o';
-         s[16]      = 'b';
-         s[17]      = '(';
-         s[18]      = '\'';
-         s[19]      = '*';
-         s[20]      = '\0';
-         pos        = strlcat(s, path, len);
-         s[pos  ]   = '*';
-         s[pos+1]   = '\'';
-         s[pos+2]   = ')';
-         s[pos+3]   = '}';
-         s[pos+4]   = '\0';
+         s[  _len]  = '{';
+         s[++_len]  = '\'';
+         s[++_len]  = 'd';
+         s[++_len]  = 'e';
+         s[++_len]  = 'v';
+         s[++_len]  = 'e';
+         s[++_len]  = 'l';
+         s[++_len]  = 'o';
+         s[++_len]  = 'p';
+         s[++_len]  = 'e';
+         s[++_len]  = 'r';
+         s[++_len]  = '\'';
+         s[++_len]  = ':';
+         s[++_len]  = 'g';
+         s[++_len]  = 'l';
+         s[++_len]  = 'o';
+         s[++_len]  = 'b';
+         s[++_len]  = '(';
+         s[++_len]  = '\'';
+         s[++_len]  = '*';
+         s[++_len]  = '\0';
+         _len      += strlcpy(s + _len, path, len - _len);
+         s[  _len]  = '*';
+         s[++_len]  = '\'';
+         s[++_len]  = ')';
+         s[++_len]  = '}';
+         s[++_len]  = '\0';
          break;
       case DATABASE_QUERY_ENTRY_ORIGIN:
-         s[0]       = '{';
-	      s[1]       = '\'';
-         s[2]       = 'o';
-         s[3]       = 'r';
-         s[4]       = 'i';
-         s[5]       = 'g';
-         s[6]       = 'i';
-         s[7]       = 'n';
-         s[8]       = '\'';
-         s[9]       = ':';
-         s[10]      = '"';
-         s[11]      = '\0';
-         pos        = strlcat(s, path, len);
-         s[pos  ]   = '"';
-         s[pos+1]   = '}';
-         s[pos+2]   = '\0';
+         s[  _len]  = '{';
+	      s[++_len]  = '\'';
+         s[++_len]  = 'o';
+         s[++_len]  = 'r';
+         s[++_len]  = 'i';
+         s[++_len]  = 'g';
+         s[++_len]  = 'i';
+         s[++_len]  = 'n';
+         s[++_len]  = '\'';
+         s[++_len]  = ':';
+         s[++_len]  = '"';
+         s[++_len]  = '\0';
+         _len      += strlcpy(s + _len, path, len - _len);
+         s[  _len]  = '"';
+         s[++_len]  = '}';
+         s[++_len]  = '\0';
          break;
       case DATABASE_QUERY_ENTRY_FRANCHISE:
-         s[0]       = '{';
-         s[1]       = '\'';
-         s[2]       = 'f';
-         s[3]       = 'r';
-         s[4]       = 'a';
-         s[5]       = 'n';
-         s[6]       = 'c';
-         s[7]       = 'h';
-         s[8]       = 'i';
-         s[9]       = 's';
-         s[10]      = 'e';
-         s[11]      = '\'';
-         s[12]      = ':';
-         s[13]      = '"';
-         s[14]      = '\0';
-         pos        = strlcat(s, path, len);
-         s[pos  ]   = '"';
-         s[pos+1]   = '}';
-         s[pos+2]   = '\0';
+         s[  _len]  = '{';
+         s[++_len]  = '\'';
+         s[++_len]  = 'f';
+         s[++_len]  = 'r';
+         s[++_len]  = 'a';
+         s[++_len]  = 'n';
+         s[++_len]  = 'c';
+         s[++_len]  = 'h';
+         s[++_len]  = 'i';
+         s[++_len]  = 's';
+         s[++_len]  = 'e';
+         s[++_len]  = '\'';
+         s[++_len]  = ':';
+         s[++_len]  = '"';
+         s[++_len]  = '\0';
+         _len      += strlcpy(s + _len, path, len - _len);
+         s[  _len]  = '"';
+         s[++_len]  = '}';
+         s[++_len]  = '\0';
          break;
       case DATABASE_QUERY_ENTRY_RATING:
-         s[0]       = '{';
-         s[1]       = '\'';
-         s[2]       = 'e';
-         s[3]       = 's';
-         s[4]       = 'r';
-         s[5]       = 'b';
-         s[6]       = '_';
-         s[7]       = 'r';
-         s[8]       = 'a';
-         s[9]       = 't';
-         s[10]      = 'i';
-         s[11]      = 'n';
-         s[12]      = 'g';
-         s[13]      = '\'';
-         s[14]      = ':';
-         s[15]      = '"';
-         pos        = strlcat(s, path, len);
-         s[pos  ]   = '"';
-         s[pos+1]   = '}';
-         s[pos+2]   = '\0';
+         s[  _len]  = '{';
+         s[++_len]  = '\'';
+         s[++_len]  = 'e';
+         s[++_len]  = 's';
+         s[++_len]  = 'r';
+         s[++_len]  = 'b';
+         s[++_len]  = '_';
+         s[++_len]  = 'r';
+         s[++_len]  = 'a';
+         s[++_len]  = 't';
+         s[++_len]  = 'i';
+         s[++_len]  = 'n';
+         s[++_len]  = 'g';
+         s[++_len]  = '\'';
+         s[++_len]  = ':';
+         s[++_len]  = '"';
+         _len      += strlcpy(s + _len, path, len - _len);
+         s[  _len]  = '"';
+         s[++_len]  = '}';
+         s[++_len]  = '\0';
          break;
       case DATABASE_QUERY_ENTRY_BBFC_RATING:
-         s[0]       = '{';
-         s[1]       = '\'';
-         s[2]       = 'b';
-         s[3]       = 'b';
-         s[4]       = 'f';
-         s[5]       = 'c';
-         s[6]       = '_';
-         s[7]       = 'r';
-         s[8]       = 'a';
-         s[9]       = 't';
-         s[10]      = 'i';
-         s[11]      = 'n';
-         s[12]      = 'g';
-         s[13]      = '\'';
-         s[14]      = ':';
-         s[15]      = '"';
-         s[16]      = '\0';
-         pos        = strlcat(s, path, len);
-         s[pos  ]   = '"';
-         s[pos+1]   = '}';
-         s[pos+2]   = '\0';
+         s[  _len]  = '{';
+         s[++_len]  = '\'';
+         s[++_len]  = 'b';
+         s[++_len]  = 'b';
+         s[++_len]  = 'f';
+         s[++_len]  = 'c';
+         s[++_len]  = '_';
+         s[++_len]  = 'r';
+         s[++_len]  = 'a';
+         s[++_len]  = 't';
+         s[++_len]  = 'i';
+         s[++_len]  = 'n';
+         s[++_len]  = 'g';
+         s[++_len]  = '\'';
+         s[++_len]  = ':';
+         s[++_len]  = '"';
+         s[++_len]  = '\0';
+         _len      += strlcpy(s + _len, path, len - _len);
+         s[++_len]  = '"';
+         s[++_len]  = '}';
+         s[++_len] = '\0';
          break;
       case DATABASE_QUERY_ENTRY_ELSPA_RATING:
-         s[0]       = '{';
-         s[1]       = '\'';
-         s[2]       = 'e';
-         s[3]       = 'l';
-         s[4]       = 's';
-         s[5]       = 'p';
-         s[6]       = 'a';
-         s[7]       = '_';
-         s[8]       = 'r';
-         s[9]       = 'a';
-         s[10]      = 't';
-         s[11]      = 'i';
-         s[12]      = 'n';
-         s[13]      = 'g';
-         s[14]      = '\'';
-         s[15]      = ':';
-         s[16]      = '"';
-         s[17]      = '\0';
-         pos        = strlcat(s, path, len);
-         s[pos  ]   = '"';
-         s[pos+1]   = '}';
-         s[pos+2]   = '\0';
+         s[  _len]  = '{';
+         s[++_len]  = '\'';
+         s[++_len]  = 'e';
+         s[++_len]  = 'l';
+         s[++_len]  = 's';
+         s[++_len]  = 'p';
+         s[++_len]  = 'a';
+         s[++_len]  = '_';
+         s[++_len]  = 'r';
+         s[++_len]  = 'a';
+         s[++_len]  = 't';
+         s[++_len]  = 'i';
+         s[++_len]  = 'n';
+         s[++_len]  = 'g';
+         s[++_len]  = '\'';
+         s[++_len]  = ':';
+         s[++_len]  = '"';
+         s[++_len]  = '\0';
+         _len      += strlcpy(s + _len, path, len - _len);
+         s[  _len]  = '"';
+         s[++_len]  = '}';
+         s[++_len]  = '\0';
          break;
       case DATABASE_QUERY_ENTRY_ESRB_RATING:
-         s[0]       = '{';
-         s[1]       = '\'';
-         s[2]       = 'e';
-         s[3]       = 's';
-         s[4]       = 'r';
-         s[5]       = 'b';
-         s[6]       = '_';
-         s[7]       = 'r';
-         s[8]       = 'a';
-         s[9 ]      = 't';
-         s[10]      = 'i';
-         s[11]      = 'n';
-         s[12]      = 'g';
-         s[13]      = '\'';
-         s[14]      = ':';
-         s[15]      = '"';
-         s[16]      = '\0';
-         pos        = strlcat(s, path, len);
-         s[pos  ]   = '"';
-         s[pos+1]   = '}';
-         s[pos+2]   = '\0';
+         s[  _len]  = '{';
+         s[++_len]  = '\'';
+         s[++_len]  = 'e';
+         s[++_len]  = 's';
+         s[++_len]  = 'r';
+         s[++_len]  = 'b';
+         s[++_len]  = '_';
+         s[++_len]  = 'r';
+         s[++_len]  = 'a';
+         s[++_len]  = 't';
+         s[++_len]  = 'i';
+         s[++_len]  = 'n';
+         s[++_len]  = 'g';
+         s[++_len]  = '\'';
+         s[++_len]  = ':';
+         s[++_len]  = '"';
+         s[++_len]  = '\0';
+         _len      += strlcpy(s + _len, path, len - _len);
+         s[  _len]  = '"';
+         s[++_len]  = '}';
+         s[++_len]  = '\0';
          break;
       case DATABASE_QUERY_ENTRY_PEGI_RATING:
-         s[0]       = '{';
-         s[1]       = '\'';
-         s[2]       = 'p';
-         s[3]       = 'e';
-         s[4]       = 'g';
-         s[5]       = 'i';
-         s[6]       = '_';
-         s[7]       = 'r';
-         s[8]       = 'a';
-         s[9]       = 't';
-         s[10]      = 'i';
-         s[11]      = 'n';
-         s[12]      = 'g';
-         s[13]      = '\'';
-         s[14]      = ':';
-         s[15]      = '"';
-         s[16]      = '\0';
-         pos        = strlcat(s, path, len);
-         s[pos  ]   = '"';
-         s[pos+1]   = '}';
-         s[pos+2]   = '\0';
+         s[  _len]  = '{';
+         s[++_len]  = '\'';
+         s[++_len]  = 'p';
+         s[++_len]  = 'e';
+         s[++_len]  = 'g';
+         s[++_len]  = 'i';
+         s[++_len]  = '_';
+         s[++_len]  = 'r';
+         s[++_len]  = 'a';
+         s[++_len]  = 't';
+         s[++_len]  = 'i';
+         s[++_len]  = 'n';
+         s[++_len]  = 'g';
+         s[++_len]  = '\'';
+         s[++_len]  = ':';
+         s[++_len]  = '"';
+         s[++_len]  = '\0';
+         _len      += strlcpy(s + _len, path, len - _len);
+         s[  _len]  = '"';
+         s[++_len]  = '}';
+         s[++_len]  = '\0';
          break;
       case DATABASE_QUERY_ENTRY_CERO_RATING:
-         s[0]       = '{';
-         s[1]       = '\'';
-         s[2]       = 'c';
-         s[3]       = 'e';
-         s[4]       = 'r';
-         s[5]       = 'o';
-         s[6]       = '_';
-         s[7]       = 'r';
-         s[8]       = 'a';
-         s[9]       = 't';
-         s[10]      = 'i';
-         s[11]      = 'n';
-         s[12]      = 'g';
-         s[13]      = '\'';
-         s[14]      = ':';
-         s[15]      = '"';
-         s[16]      = '\0';
-         pos        = strlcat(s, path, len);
-         s[pos  ]   = '"';
-         s[pos+1]   = '}';
-         s[pos+2]   = '\0';
+         s[  _len]  = '{';
+         s[++_len]  = '\'';
+         s[++_len]  = 'c';
+         s[++_len]  = 'e';
+         s[++_len]  = 'r';
+         s[++_len]  = 'o';
+         s[++_len]  = '_';
+         s[++_len]  = 'r';
+         s[++_len]  = 'a';
+         s[++_len]  = 't';
+         s[++_len]  = 'i';
+         s[++_len]  = 'n';
+         s[++_len]  = 'g';
+         s[++_len]  = '\'';
+         s[++_len]  = ':';
+         s[++_len]  = '"';
+         s[++_len]  = '\0';
+         _len      += strlcpy(s + _len, path, len - _len);
+         s[  _len]  = '"';
+         s[++_len]  = '}';
+         s[++_len]  = '\0';
          break;
       case DATABASE_QUERY_ENTRY_ENHANCEMENT_HW:
-         s[0]       = '{';
-         s[1]       = '\'';
-         s[2]       = 'e';
-         s[3]       = 'n';
-         s[4]       = 'h';
-         s[5]       = 'a';
-         s[6]       = 'n';
-         s[7]       = 'c';
-         s[8]       = 'e';
-         s[9]       = 'm';
-         s[10]      = 'e';
-         s[11]      = 'n';
-         s[12]      = 't';
-         s[13]      = '_';
-         s[14]      = 'h';
-         s[15]      = 'w';
-         s[16]      = '\'';
-         s[17]      = ':';
-         s[18]      = '"';
-         s[19]      = '\0';
-         pos        = strlcat(s, path, len);
-         s[pos  ]   = '"';
-         s[pos+1]   = '}';
-         s[pos+2]   = '\0';
+         s[  _len]  = '{';
+         s[++_len]  = '\'';
+         s[++_len]  = 'e';
+         s[++_len]  = 'n';
+         s[++_len]  = 'h';
+         s[++_len]  = 'a';
+         s[++_len]  = 'n';
+         s[++_len]  = 'c';
+         s[++_len]  = 'e';
+         s[++_len]  = 'm';
+         s[++_len]  = 'e';
+         s[++_len]  = 'n';
+         s[++_len]  = 't';
+         s[++_len]  = '_';
+         s[++_len]  = 'h';
+         s[++_len]  = 'w';
+         s[++_len]  = '\'';
+         s[++_len]  = ':';
+         s[++_len]  = '"';
+         s[++_len]  = '\0';
+         _len      += strlcpy(s + _len, path, len - _len);
+         s[  _len]  = '"';
+         s[++_len]  = '}';
+         s[++_len]  = '\0';
          break;
       case DATABASE_QUERY_ENTRY_EDGE_MAGAZINE_RATING:
-         s[0]       = '{';
-         s[1]       = '\'';
-         s[2]       = 'e';
-         s[3]       = 'd';
-         s[4]       = 'g';
-         s[5]       = 'e';
-         s[6]       = '_';
-         s[7]       = 'r';
-         s[8]       = 'a';
-         s[9]       = 't';
-         s[10]      = 'i';
-         s[11]      = 'n';
-         s[12]      = 'g';
-         s[13]      = '\'';
-         s[14]      = ':';
-         s[15]      = '\0';
-         pos        = strlcat(s, path, len);
-         s[pos  ]   = '}';
-         s[pos+1]   = '\0';
+         s[  _len]  = '{';
+         s[++_len]  = '\'';
+         s[++_len]  = 'e';
+         s[++_len]  = 'd';
+         s[++_len]  = 'g';
+         s[++_len]  = 'e';
+         s[++_len]  = '_';
+         s[++_len]  = 'r';
+         s[++_len]  = 'a';
+         s[++_len]  = 't';
+         s[++_len]  = 'i';
+         s[++_len]  = 'n';
+         s[++_len]  = 'g';
+         s[++_len]  = '\'';
+         s[++_len]  = ':';
+         s[++_len]  = '\0';
+         _len      += strlcpy(s + _len, path, len - _len);
+         s[  _len]   = '}';
+         s[++_len]  = '\0';
          break;
       case DATABASE_QUERY_ENTRY_EDGE_MAGAZINE_ISSUE:
-         s[0]       = '{';
-         s[1]       = '\'';
-         s[2]       = 'e';
-         s[3]       = 'd';
-         s[4]       = 'g';
-         s[5]       = 'e';
-         s[6]       = '_';
-         s[7]       = 'i';
-         s[8]       = 's';
-         s[9]       = 's';
-         s[10]      = 'u';
-         s[11]      = 'e';
-         s[12]      = '\'';
-         s[13]      = ':';
-         s[14]      = '\0';
-         pos        = strlcat(s, path, len);
-         s[pos  ]   = '}';
-         s[pos+1]   = '\0';
+         s[  _len]  = '{';
+         s[++_len]  = '\'';
+         s[++_len]  = 'e';
+         s[++_len]  = 'd';
+         s[++_len]  = 'g';
+         s[++_len]  = 'e';
+         s[++_len]  = '_';
+         s[++_len]  = 'i';
+         s[++_len]  = 's';
+         s[++_len]  = 's';
+         s[++_len]  = 'u';
+         s[++_len]  = 'e';
+         s[++_len]  = '\'';
+         s[++_len]  = ':';
+         s[++_len]  = '\0';
+         _len      += strlcpy(s + _len, path, len - _len);
+         s[  _len]  = '}';
+         s[++_len]  = '\0';
          break;
       case DATABASE_QUERY_ENTRY_FAMITSU_MAGAZINE_RATING:
-         s[0]       = '{';
-         s[1]       = '\'';
-         s[2]       = 'f';
-         s[3]       = 'a';
-         s[4]       = 'm';
-         s[5]       = 'i';
-         s[6]       = 't';
-         s[7]       = 's';
-         s[8]       = 'u';
-         s[9]       = '_';
-         s[10]      = 'r';
-         s[11]      = 'a';
-         s[12]      = 't';
-         s[13]      = 'i';
-         s[14]      = 'n';
-         s[15]      = 'g';
-         s[16]      = '\'';
-         s[17]      = ':';
-         s[18]      = '\0';
-         pos        = strlcat(s, path, len);
-         s[pos  ]   = '}';
-         s[pos+1]   = '\0';
+         s[  _len]  = '{';
+         s[++_len]  = '\'';
+         s[++_len]  = 'f';
+         s[++_len]  = 'a';
+         s[++_len]  = 'm';
+         s[++_len]  = 'i';
+         s[++_len]  = 't';
+         s[++_len]  = 's';
+         s[++_len]  = 'u';
+         s[++_len]  = '_';
+         s[++_len]  = 'r';
+         s[++_len]  = 'a';
+         s[++_len]  = 't';
+         s[++_len]  = 'i';
+         s[++_len]  = 'n';
+         s[++_len]  = 'g';
+         s[++_len]  = '\'';
+         s[++_len]  = ':';
+         s[++_len]  = '\0';
+         _len      += strlcpy(s + _len, path, len - _len);
+         s[  _len]  = '}';
+         s[++_len]  = '\0';
          break;
       case DATABASE_QUERY_ENTRY_RELEASEDATE_MONTH:
-         s[0]       = '{';
-         s[1]       = '\'';
-         s[2]       = 'r';
-         s[3]       = 'e';
-         s[4]       = 'l';
-         s[5]       = 'e';
-         s[6]       = 'a';
-         s[7]       = 's';
-         s[8]       = 'e';
-         s[9]       = 'm';
-         s[10]      = 'o';
-         s[11]      = 'n';
-         s[12]      = 't';
-         s[13]      = 'h';
-         s[14]      = '\'';
-         s[15]      = ':';
-         s[16]      = '\0';
-         pos        = strlcat(s, path, len);
-         s[pos  ]   = '}';
-         s[pos+1]   = '\0';
+         s[  _len]  = '{';
+         s[++_len]  = '\'';
+         s[++_len]  = 'r';
+         s[++_len]  = 'e';
+         s[++_len]  = 'l';
+         s[++_len]  = 'e';
+         s[++_len]  = 'a';
+         s[++_len]  = 's';
+         s[++_len]  = 'e';
+         s[++_len]  = 'm';
+         s[++_len]  = 'o';
+         s[++_len]  = 'n';
+         s[++_len]  = 't';
+         s[++_len]  = 'h';
+         s[++_len]  = '\'';
+         s[++_len]  = ':';
+         s[++_len]  = '\0';
+         _len      += strlcpy(s + _len, path, len - _len);
+         s[  _len]  = '}';
+         s[++_len]  = '\0';
          break;
       case DATABASE_QUERY_ENTRY_RELEASEDATE_YEAR:
-	      s[0]       = '{';
-	      s[1]       = '\'';
-         s[2]       = 'r';
-         s[3]       = 'e';
-         s[4]       = 'l';
-         s[5]       = 'e';
-         s[6]       = 'a';
-         s[7]       = 's';
-         s[8]       = 'e';
-         s[9]       = 'y';
-         s[10]      = 'e';
-         s[11]      = 'a';
-         s[12]      = 'r';
-         s[13]      = '\'';
-         s[14]      = ':';
-         s[15]      = '\0';
-         pos        = strlcat(s, path, len);
-         s[pos  ]   = '}';
-         s[pos+1]   = '\0';
+         s[  _len]  = '{';
+         s[++_len]  = '\'';
+         s[++_len]  = 'r';
+         s[++_len]  = 'e';
+         s[++_len]  = 'l';
+         s[++_len]  = 'e';
+         s[++_len]  = 'a';
+         s[++_len]  = 's';
+         s[++_len]  = 'e';
+         s[++_len]  = 'y';
+         s[++_len]  = 'e';
+         s[++_len]  = 'a';
+         s[++_len]  = 'r';
+         s[++_len]  = '\'';
+         s[++_len]  = ':';
+         s[++_len]  = '\0';
+         _len      += strlcpy(s + _len, path, len - _len);
+         s[  _len]  = '}';
+         s[++_len]  = '\0';
          break;
       case DATABASE_QUERY_ENTRY_MAX_USERS:
-         s[0]       = '{';
-         s[1]       = '\'';
-         s[2]       = 'u';
-         s[3]       = 's';
-         s[4]       = 'e';
-         s[5]       = 'r';
-         s[6]       = 's';
-         s[7]       = '\'';
-         s[8]       = ':';
-         s[9]       = '\0';
-         pos        = strlcat(s, path, len);
-         s[pos  ]   = '}';
-         s[pos+1]   = '\0';
+         s[  _len]  = '{';
+         s[++_len]  = '\'';
+         s[++_len]  = 'u';
+         s[++_len]  = 's';
+         s[++_len]  = 'e';
+         s[++_len]  = 'r';
+         s[++_len]  = 's';
+         s[++_len]  = '\'';
+         s[++_len]  = ':';
+         s[++_len]  = '\0';
+         _len      += strlcpy(s + _len, path, len - _len);
+         s[  _len]  = '}';
+         s[++_len]  = '\0';
          break;
       case DATABASE_QUERY_NONE:
-         s[0]       = '{';
-         s[1]       = '\'';
-         s[2]       = '\'';
-         s[3]       = ':';
-         s[4]       = '\'';
-         s[5]       = ':';
-         s[6]       = '"';
-         s[7]       = '\0';
-         pos        = strlcat(s, path, len);
-         s[pos  ]   = '"';
-         s[pos+1]   = '}';
-         s[pos+2]   = '\0';
+         s[  _len]  = '{';
+         s[++_len]  = '\'';
+         s[++_len]  = '\'';
+         s[++_len]  = ':';
+         s[++_len]  = '\'';
+         s[++_len]  = ':';
+         s[++_len]  = '"';
+         s[++_len]  = '\0';
+         _len      += strlcpy(s + _len, path, len - _len);
+         s[  _len]  = '"';
+         s[++_len]  = '}';
+         s[++_len]  = '\0';
          break;
    }
 
@@ -515,8 +515,11 @@ static int database_cursor_iterate(libretrodb_cursor_t *cur,
       }
       else if (string_is_equal(str, "rom_name"))
       {
+/* rom_name is not used anywhere in codebase, but is frequently added to DB */
+#if 0
          if (!string_is_empty(val_string))
             db_info->rom_name = strdup(val_string);
+#endif
       }
       else if (string_is_equal(str, "name"))
       {
@@ -717,7 +720,7 @@ static int database_cursor_open(libretrodb_t *db,
    const char *error     = NULL;
    libretrodb_query_t *q = NULL;
 
-   if ((libretrodb_open(path, db)) != 0)
+   if ((libretrodb_open(path, db, false)) != 0)
       return -1;
 
    if (query)
@@ -762,11 +765,6 @@ static int dir_entry_compare(const void *left, const void *right)
    return (int) r - (int) l;
 }
 
-static void dir_list_prioritize(struct string_list *list)
-{
-   qsort(list->elems, list->size, sizeof(*list->elems), dir_entry_compare);
-}
-
 database_info_handle_t *database_info_dir_init(const char *dir,
       enum database_type type, retro_task_t *task,
       bool show_hidden_files)
@@ -789,7 +787,8 @@ database_info_handle_t *database_info_dir_init(const char *dir,
       return NULL;
    }
 
-   dir_list_prioritize(list);
+   /* dir list prioritize */
+   qsort(list->elems, list->size, sizeof(*list->elems), dir_entry_compare);
 
    db->status             = DATABASE_STATUS_ITERATE;
    db->type               = type;
