@@ -221,6 +221,7 @@ RC_EXPORT void RC_CCONV rc_client_get_user_game_summary(const rc_client_t* clien
 | Game                                                                        |
 \*****************************************************************************/
 
+#ifdef RC_CLIENT_SUPPORTS_HASH
 /**
  * Start loading an unidentified game.
  */
@@ -228,6 +229,7 @@ RC_EXPORT rc_client_async_handle_t* RC_CCONV rc_client_begin_identify_and_load_g
     uint32_t console_id, const char* file_path,
     const uint8_t* data, size_t data_size,
     rc_client_callback_t callback, void* callback_userdata);
+#endif
 
 /**
  * Start loading a game.
@@ -235,6 +237,25 @@ RC_EXPORT rc_client_async_handle_t* RC_CCONV rc_client_begin_identify_and_load_g
 RC_EXPORT rc_client_async_handle_t* RC_CCONV rc_client_begin_load_game(rc_client_t* client, const char* hash,
     rc_client_callback_t callback, void* callback_userdata);
 
+/**
+ * Gets the current progress of the asynchronous load game process.
+ */
+RC_EXPORT int RC_CCONV rc_client_get_load_game_state(const rc_client_t* client);
+enum {
+  RC_CLIENT_LOAD_GAME_STATE_NONE,
+  RC_CLIENT_LOAD_GAME_STATE_IDENTIFYING_GAME,
+  RC_CLIENT_LOAD_GAME_STATE_AWAIT_LOGIN,
+  RC_CLIENT_LOAD_GAME_STATE_FETCHING_GAME_DATA,
+  RC_CLIENT_LOAD_GAME_STATE_STARTING_SESSION,
+  RC_CLIENT_LOAD_GAME_STATE_DONE,
+  RC_CLIENT_LOAD_GAME_STATE_ABORTED
+};
+
+/**
+ * Determines if a game was successfully identified and loaded.
+ */
+RC_EXPORT int RC_CCONV rc_client_is_game_loaded(const rc_client_t* client);
+
 /**
  * Unloads the current game.
  */
@@ -250,6 +271,7 @@ typedef struct rc_client_game_t {
 
 /**
  * Get information about the current game. Returns NULL if no game is loaded.
+ * NOTE: returns a dummy game record if an unidentified game is loaded.
  */
 RC_EXPORT const rc_client_game_t* RC_CCONV rc_client_get_game_info(const rc_client_t* client);
 
@@ -259,11 +281,19 @@ RC_EXPORT const rc_client_game_t* RC_CCONV rc_client_get_game_info(const rc_clie
  */
 RC_EXPORT int RC_CCONV rc_client_game_get_image_url(const rc_client_game_t* game, char buffer[], size_t buffer_size);
 
+#ifdef RC_CLIENT_SUPPORTS_HASH
 /**
  * Changes the active disc in a multi-disc game.
  */
 RC_EXPORT rc_client_async_handle_t* RC_CCONV rc_client_begin_change_media(rc_client_t* client, const char* file_path,
     const uint8_t* data, size_t data_size, rc_client_callback_t callback, void* callback_userdata);
+#endif
+
+/**
+ * Changes the active disc in a multi-disc game.
+ */
+RC_EXPORT rc_client_async_handle_t* RC_CCONV rc_client_begin_change_media_from_hash(rc_client_t* client, const char* hash,
+    rc_client_callback_t callback, void* callback_userdata);
 
 /*****************************************************************************\
 | Subsets                                                                     |
@@ -487,6 +517,7 @@ typedef struct rc_client_leaderboard_entry_t {
 typedef struct rc_client_leaderboard_entry_list_t {
   rc_client_leaderboard_entry_t* entries;
   uint32_t num_entries;
+  uint32_t total_entries;
   int32_t user_index;
 } rc_client_leaderboard_entry_list_t;
 
@@ -663,15 +694,29 @@ RC_EXPORT size_t RC_CCONV rc_client_progress_size(rc_client_t* client);
 /**
  * Serializes the runtime state into a buffer.
  * Returns RC_OK on success, or an error indicator.
+ * [deprecated] use rc_client_serialize_progress_sized instead
  */
 RC_EXPORT int RC_CCONV rc_client_serialize_progress(rc_client_t* client, uint8_t* buffer);
 
 /**
- * Deserializes the runtime state from a buffer.
+ * Serializes the runtime state into a buffer.
  * Returns RC_OK on success, or an error indicator.
  */
+RC_EXPORT int RC_CCONV rc_client_serialize_progress_sized(rc_client_t* client, uint8_t* buffer, size_t buffer_size);
+
+/**
+ * Deserializes the runtime state from a buffer.
+ * Returns RC_OK on success, or an error indicator.
+ * [deprecated] use rc_client_deserialize_progress_sized instead
+ */
 RC_EXPORT int RC_CCONV rc_client_deserialize_progress(rc_client_t* client, const uint8_t* serialized);
 
+/**
+ * Serializes the runtime state into a buffer.
+ * Returns RC_OK on success, or an error indicator.
+ */
+RC_EXPORT int RC_CCONV rc_client_deserialize_progress_sized(rc_client_t* client, const uint8_t* serialized, size_t serialized_size);
+
 RC_END_C_DECLS
 
 #endif /* RC_RUNTIME_H */
