@@ -53,6 +53,7 @@ class drmkms_timing : public custom_video
 		int m_caps = 0;
 
 		char m_device_name[32];
+		char m_drm_name[32];
 		unsigned int m_desktop_output = 0;
 		int m_video_modes_position = 0;
 
@@ -83,6 +84,7 @@ class drmkms_timing : public custom_video
 		__typeof__(drmModeFreePlaneResources) *p_drmModeFreePlaneResources;
 		__typeof__(drmIoctl) *p_drmIoctl;
 		__typeof__(drmGetCap) *p_drmGetCap;
+		__typeof__(drmGetDevices2) *p_drmGetDevices2;
 		__typeof__(drmIsMaster) *p_drmIsMaster;
 		__typeof__(drmSetMaster) *p_drmSetMaster;
 		__typeof__(drmDropMaster) *p_drmDropMaster;
