@@ -106,7 +106,7 @@ typedef enum
 {
    CFUserDomainMask     = 1,       /* user's home directory --- place to install user's personal items (~) */
    CFLocalDomainMask    = 2,       /* local to the current machine --- place to install items available to everyone on this machine (/Library) */
-   CFNetworkDomainMask  = 4,       /* publically available location in the local area network --- place to install items available on the network (/Network) */
+   CFNetworkDomainMask  = 4,       /* publicly available location in the local area network --- place to install items available on the network (/Network) */
    CFSystemDomainMask   = 8,       /* provided by Apple, unmodifiable (/System) */
    CFAllDomainsMask     = 0x0ffff  /* All domains: all of the above and future items */
 } CFDomainMask;
@@ -131,7 +131,7 @@ static void CFSearchPathForDirectoriesInDomains(
             NSUserDomainMask, YES) firstObject];
 #else
    CFStringRef array_val     = nil;
-   NSArray *arr              = 
+   NSArray *arr              =
       NSSearchPathForDirectoriesInDomains(dir,
             NSUserDomainMask, YES);
    if ([arr count] != 0)
@@ -160,7 +160,7 @@ void get_ios_version(int *major, int *minor);
 #define PMGMT_STRMATCH(a,b) (CFStringCompare(a, b, 0) == kCFCompareEqualTo)
 #define PMGMT_GETVAL(k,v)   CFDictionaryGetValueIfPresent(dict, CFSTR(k), (const void **) v)
 
-/* Note that AC power sources also include a 
+/* Note that AC power sources also include a
  * laptop battery it is charging. */
 static void darwin_check_power_source(
       CFDictionaryRef dict,
@@ -280,31 +280,24 @@ static void frontend_darwin_get_name(char *s, size_t len)
 #endif
 }
 
-static void frontend_darwin_get_os(char *s, size_t len, int *major, int *minor)
+static size_t frontend_darwin_get_os(char *s, size_t len, int *major, int *minor)
 {
+   size_t _len;
 #if defined(IOS)
    get_ios_version(major, minor);
 #if TARGET_OS_TV
-   s[0] = 't';
-   s[1] = 'v';
-   s[2] = 'O';
-   s[3] = 'S';
-   s[4] = '\0';
+   _len = strlcpy(s, "tvOS", len);
 #else
-   s[0] = 'i';
-   s[1] = 'O';
-   s[2] = 'S';
-   s[3] = '\0';
+   _len = strlcpy(s, "iOS", len);
 #endif
 #elif defined(OSX)
-
 #if MAC_OS_X_VERSION_MIN_REQUIRED >= 101300 /* MAC_OS_X_VERSION_10_13 */
    NSOperatingSystemVersion version = NSProcessInfo.processInfo.operatingSystemVersion;
    *major = (int)version.majorVersion;
    *minor = (int)version.minorVersion;
 #else
-    /* MacOS 10.9 includes the [NSProcessInfo operatingSystemVersion] function, but it's not in the 10.9 SDK. So, call it via NSInvocation */
-    /* Credit: OpenJDK (https://github.com/openjdk/jdk/commit/d4c7db50) */
+   /* MacOS 10.9 includes the [NSProcessInfo operatingSystemVersion] function, but it's not in the 10.9 SDK. So, call it via NSInvocation */
+   /* Credit: OpenJDK (https://github.com/openjdk/jdk/commit/d4c7db50) */
    if ([[NSProcessInfo processInfo] respondsToSelector:@selector(operatingSystemVersion)])
    {
       typedef struct
@@ -313,12 +306,12 @@ static void frontend_darwin_get_os(char *s, size_t len, int *major, int *minor)
          NSInteger minorVersion;
          NSInteger patchVersion;
       } NSMyOSVersion;
-       NSMyOSVersion version;
-       NSMethodSignature *sig = [[NSProcessInfo processInfo] methodSignatureForSelector:@selector(operatingSystemVersion)];
-       NSInvocation *invoke = [NSInvocation invocationWithMethodSignature:sig];
-       invoke.selector = @selector(operatingSystemVersion);
-       [invoke invokeWithTarget:[NSProcessInfo processInfo]];
-       [invoke getReturnValue:&version];
+      NSMyOSVersion version;
+      NSMethodSignature *sig = [[NSProcessInfo processInfo] methodSignatureForSelector:@selector(operatingSystemVersion)];
+      NSInvocation *invoke = [NSInvocation invocationWithMethodSignature:sig];
+      invoke.selector = @selector(operatingSystemVersion);
+      [invoke invokeWithTarget:[NSProcessInfo processInfo]];
+      [invoke getReturnValue:&version];
       *major = (int)version.majorVersion;
       *minor = (int)version.minorVersion;
    }
@@ -328,11 +321,9 @@ static void frontend_darwin_get_os(char *s, size_t len, int *major, int *minor)
       Gestalt(gestaltSystemVersionMajor, (SInt32*)major);
    }
 #endif
-   s[0] = 'O';
-   s[1] = 'S';
-   s[2] = 'X';
-   s[3] = '\0';
+   _len = strlcpy(s, "OSX", len);
 #endif
+   return _len;
 }
 
 static void frontend_darwin_get_env(int *argc, char *argv[],
@@ -341,9 +332,9 @@ static void frontend_darwin_get_env(int *argc, char *argv[],
    char assets_zip_path[PATH_MAX_LENGTH];
    CFURLRef bundle_url;
    CFStringRef bundle_path;
-   char temp_dir[PATH_MAX_LENGTH]          = {0};
+   char temp_dir[DIR_MAX_LENGTH]           = {0};
    char bundle_path_buf[PATH_MAX_LENGTH]   = {0};
-   char documents_dir_buf[PATH_MAX_LENGTH] = {0};
+   char documents_dir_buf[DIR_MAX_LENGTH]  = {0};
    char application_data[PATH_MAX_LENGTH]  = {0};
    CFBundleRef bundle                      = CFBundleGetMainBundle();
 
@@ -411,23 +402,23 @@ static void frontend_darwin_get_env(int *argc, char *argv[],
    fill_pathname_join(g_defaults.dirs[DEFAULT_DIR_REMAP], g_defaults.dirs[DEFAULT_DIR_MENU_CONFIG], "remaps", sizeof(g_defaults.dirs[DEFAULT_DIR_REMAP]));
 #if defined(HAVE_UPDATE_CORES) || defined(HAVE_STEAM)
    fill_pathname_join(g_defaults.dirs[DEFAULT_DIR_CORE], application_data, "cores", sizeof(g_defaults.dirs[DEFAULT_DIR_CORE]));
+#elif defined(OSX) && defined(HAVE_APPLE_STORE)
+   fill_pathname_join(g_defaults.dirs[DEFAULT_DIR_CORE], bundle_path_buf, "Contents/Frameworks", sizeof(g_defaults.dirs[DEFAULT_DIR_CORE]));
 #else
    fill_pathname_join(g_defaults.dirs[DEFAULT_DIR_CORE], bundle_path_buf, "Frameworks", sizeof(g_defaults.dirs[DEFAULT_DIR_CORE]));
 #endif
    fill_pathname_join(g_defaults.dirs[DEFAULT_DIR_DATABASE], application_data, "database/rdb", sizeof(g_defaults.dirs[DEFAULT_DIR_DATABASE]));
    fill_pathname_join(g_defaults.dirs[DEFAULT_DIR_CORE_ASSETS], application_data, "downloads", sizeof(g_defaults.dirs[DEFAULT_DIR_CORE_ASSETS]));
    NSURL *url = [[NSBundle mainBundle] URLForResource:nil withExtension:@"dsp" subdirectory:@"filters/audio"];
-   if (url) {
+   if (url)
        strlcpy(g_defaults.dirs[DEFAULT_DIR_AUDIO_FILTER], [[url baseURL] fileSystemRepresentation],  sizeof(g_defaults.dirs[DEFAULT_DIR_AUDIO_FILTER]));
-   } else {
+   else
        fill_pathname_join(g_defaults.dirs[DEFAULT_DIR_AUDIO_FILTER], application_data, "filters/audio", sizeof(g_defaults.dirs[DEFAULT_DIR_AUDIO_FILTER]));
-   }
    url = [[NSBundle mainBundle] URLForResource:nil withExtension:@"filt" subdirectory:@"filters/video"];
-   if (url) {
+   if (url)
        strlcpy(g_defaults.dirs[DEFAULT_DIR_VIDEO_FILTER], [[url baseURL] fileSystemRepresentation],  sizeof(g_defaults.dirs[DEFAULT_DIR_VIDEO_FILTER]));
-   } else {
+   else
        fill_pathname_join(g_defaults.dirs[DEFAULT_DIR_VIDEO_FILTER], application_data, "filters/video", sizeof(g_defaults.dirs[DEFAULT_DIR_VIDEO_FILTER]));
-   }
    fill_pathname_join(g_defaults.dirs[DEFAULT_DIR_CORE_INFO], application_data, "info", sizeof(g_defaults.dirs[DEFAULT_DIR_CORE_INFO]));
    fill_pathname_join(g_defaults.dirs[DEFAULT_DIR_OVERLAY], application_data, "overlays", sizeof(g_defaults.dirs[DEFAULT_DIR_OVERLAY]));
    fill_pathname_join(g_defaults.dirs[DEFAULT_DIR_OSK_OVERLAY], application_data, "overlays/keyboards", sizeof(g_defaults.dirs[DEFAULT_DIR_OSK_OVERLAY]));
@@ -462,8 +453,9 @@ static void frontend_darwin_get_env(int *argc, char *argv[],
              settings->paths.bundle_assets_dst,
              application_data
        );
-       /* TODO/FIXME: Just hardcode this for now */
-       configuration_set_uint(settings, settings->uints.bundle_assets_extract_version_current, 1);
+       NSString *bundleVersionString = [[NSBundle mainBundle] objectForInfoDictionaryKey:@"CFBundleVersion"];
+       NSInteger bundleVersion = [bundleVersionString integerValue];
+       configuration_set_uint(settings, settings->uints.bundle_assets_extract_version_current, (uint)bundleVersion);
     }
 
    CFTemporaryDirectory(temp_dir, sizeof(temp_dir));
@@ -682,7 +674,7 @@ static enum frontend_architecture frontend_darwin_get_arch(void)
 
     if (uname(&buffer) != 0)
        return FRONTEND_ARCH_NONE;
-    
+
    if (string_is_equal(buffer.machine, "x86_64"))
       return FRONTEND_ARCH_X86_64;
    if (string_is_equal(buffer.machine, "x86"))
@@ -696,7 +688,7 @@ static enum frontend_architecture frontend_darwin_get_arch(void)
    size_t size = sizeof(type);
 
    sysctlbyname("hw.cputype", &type, &size, NULL, 0);
-    
+
    if (type == CPU_TYPE_X86_64)
       return FRONTEND_ARCH_X86_64;
    else if (type == CPU_TYPE_X86)
@@ -846,7 +838,7 @@ static char* accessibility_mac_language_code(const char* language)
       return "Ioana";
    else if (string_is_equal(language,"pt_pt"))
       return "Joana";
-   else if (string_is_equal(language,"pt_bt") 
+   else if (string_is_equal(language,"pt_bt")
          || string_is_equal(language,"pt"))
       return "Luciana";
    else if (string_is_equal(language,"th"))
@@ -861,7 +853,7 @@ static char* accessibility_mac_language_code(const char* language)
       return "Maged";
    else if (string_is_equal(language,"hu"))
       return "Mariska";
-   else if (string_is_equal(language,"zh_tw") 
+   else if (string_is_equal(language,"zh_tw")
          || string_is_equal(language,"zh"))
       return "Mei-Jia";
    else if (string_is_equal(language,"el"))
@@ -884,7 +876,7 @@ static char* accessibility_mac_language_code(const char* language)
       return "Yuna";
    else if (string_is_equal(language,"pl"))
       return "Zosia";
-   else if (string_is_equal(language,"cs")) 
+   else if (string_is_equal(language,"cs"))
       return "Zuzana";
    return "";
 }
@@ -925,16 +917,16 @@ static bool accessibility_speak_macos(int speed,
       /* parent process */
       speak_pid = pid;
 
-      /* Tell the system that we'll ignore the exit status of the child 
+      /* Tell the system that we'll ignore the exit status of the child
        * process.  This prevents zombie processes. */
       signal(SIGCHLD,SIG_IGN);
    }
    else
-   { 
-      /* child process: replace process with the say command */ 
+   {
+      /* child process: replace process with the say command */
       if (language_speaker && language_speaker[0] != '\0')
       {
-         char* cmd[] = {"say", "-v", NULL, 
+         char* cmd[] = {"say", "-v", NULL,
                         NULL, "-r", NULL, NULL};
          cmd[2]      = language_speaker;
          cmd[3]      = (char *) speak_text;
