@@ -86,7 +86,7 @@ extern bool nxlink_connected;
 
 void libnx_apply_overclock(void)
 {
-   const size_t profiles_count = sizeof(SWITCH_CPU_PROFILES) 
+   const size_t profiles_count = sizeof(SWITCH_CPU_PROFILES)
       / sizeof(SWITCH_CPU_PROFILES[1]);
    settings_t *settings        = config_get_ptr();
    unsigned libnx_overclock    = settings->uints.libnx_overclock;
@@ -565,7 +565,7 @@ static void frontend_switch_init(void *data)
    bool recording_supported      = false;
 
    nifmInitialize(NifmServiceType_User);
-   
+
    if (hosversionBefore(8, 0, 0))
       pcvInitialize();
    else
@@ -609,8 +609,8 @@ static int frontend_switch_parse_drive_list(void *data, bool load_content)
 {
 #ifndef IS_SALAMANDER
    file_list_t *list = (file_list_t *)data;
-   enum msg_hash_enums enum_idx = load_content 
-      ? MENU_ENUM_LABEL_FILE_DETECT_CORE_LIST_PUSH_DIR 
+   enum msg_hash_enums enum_idx = load_content
+      ? MENU_ENUM_LABEL_FILE_DETECT_CORE_LIST_PUSH_DIR
       : MENU_ENUM_LABEL_FILE_BROWSER_DIRECTORY;
 
    if (!list)
@@ -637,7 +637,7 @@ static uint64_t frontend_switch_get_total_mem(void)
    return mem_info.usmblks;
 }
 
-static enum frontend_powerstate 
+static enum frontend_powerstate
 frontend_switch_get_powerstate(int *seconds, int *percent)
 {
    uint32_t pct;
@@ -671,9 +671,10 @@ frontend_switch_get_powerstate(int *seconds, int *percent)
    return FRONTEND_POWERSTATE_NO_SOURCE;
 }
 
-static void frontend_switch_get_os(
+static size_t frontend_switch_get_os(
       char *s, size_t len, int *major, int *minor)
 {
+   size_t _len;
 #ifdef HAVE_LIBNX
    u32 hosVersion;
 #else
@@ -684,7 +685,7 @@ static void frontend_switch_get_os(
    ipc_request_t rq;
 #endif
 
-   strlcpy(s, "Horizon OS", len);
+   _len       = strlcpy(s, "Horizon OS", len);
 
 #ifdef HAVE_LIBNX
    *major     = 0;
@@ -716,8 +717,8 @@ fail_object:
 fail_sm:
    sm_finalize();
 fail:
-   return;
 #endif
+   return _len;
 }
 
 static void frontend_switch_get_name(char *s, size_t len)
