@@ -267,7 +267,7 @@ static void gfx_set_dwm(void)
       g_plat_win32_flags |= PLAT_WIN32_FLAG_DWM_COMPOSITION_DISABLED;
 }
 
-static void frontend_win32_get_os(char *s, size_t len, int *major, int *minor)
+static size_t frontend_win32_get_os(char *s, size_t len, int *major, int *minor)
 {
    size_t _len            = 0;
    char build_str[11]     = {0};
@@ -424,6 +424,7 @@ static void frontend_win32_get_os(char *s, size_t len, int *major, int *minor)
       _len += strlcpy(s + _len, " ", len - _len);
       strlcpy(s + _len, vi.szCSDVersion, len - _len);
    }
+   return _len;
 }
 
 static void frontend_win32_init(void *data)
@@ -453,7 +454,7 @@ static void frontend_win32_init(void *data)
 static void init_nvda(void)
 {
 #ifdef HAVE_DYLIB
-   if (     (g_plat_win32_flags & PLAT_WIN32_FLAG_USE_NVDA) 
+   if (     (g_plat_win32_flags & PLAT_WIN32_FLAG_USE_NVDA)
          && !nvda_lib)
    {
       if ((nvda_lib = dylib_load("nvdaControllerClient64.dll")))
@@ -751,23 +752,18 @@ static void frontend_win32_respawn(char *s, size_t len, char *args)
    STARTUPINFO si;
    PROCESS_INFORMATION pi;
    char executable_path[PATH_MAX_LENGTH] = {0};
-   char executable_args[PATH_MAX_LENGTH] = {0};
 
    if (win32_fork_mode != FRONTEND_FORK_RESTART)
       return;
 
-   fill_pathname_application_path(executable_path,
-         sizeof(executable_path));
+   GetModuleFileName(NULL, executable_path, PATH_MAX_LENGTH);
    path_set(RARCH_PATH_CORE, executable_path);
 
-   /* Remove executable path from arguments given to CreateProcess */
-   snprintf(executable_args, sizeof(executable_args), "%s", strstr(args, ".exe") + 4);
-
    memset(&si, 0, sizeof(si));
    si.cb = sizeof(si);
    memset(&pi, 0, sizeof(pi));
 
-   if (!CreateProcess(executable_path, executable_args,
+   if (!CreateProcess(executable_path, GetCommandLine(),
          NULL, NULL, FALSE, 0, NULL, NULL, &si, &pi))
       RARCH_ERR("Failed to restart RetroArch\n");
 }
@@ -853,7 +849,7 @@ static const char *accessibility_win_language_id(const char* language)
       return "412";
    else if (string_is_equal(language,"pl"))
       return "415";
-   else if (string_is_equal(language,"cs")) 
+   else if (string_is_equal(language,"cs"))
       return "405";
    return "";
 }
@@ -966,12 +962,12 @@ static bool create_win32_process(char* cmd, const char * input)
       size_t input_len = strlen(input);
       if (!CreatePipe(&rd, &wr, NULL, input_len))
          return false;
-      
+
       SetHandleInformation(rd, HANDLE_FLAG_INHERIT, HANDLE_FLAG_INHERIT);
-      
+
       WriteFile(wr, input, input_len, &dummy, NULL);
       CloseHandle(wr);
-      
+
       si.dwFlags    |= STARTF_USESTDHANDLES;
       si.hStdInput   = rd;
       si.hStdOutput  = GetStdHandle(STD_OUTPUT_HANDLE);
@@ -1006,7 +1002,7 @@ static bool is_narrator_running_windows(void)
    {
       long res = nvdaController_testIfRunning_func();
 
-      if (res != 0) 
+      if (res != 0)
       {
          /* The running nvda service wasn't found, so revert
             back to the powershell method
@@ -1057,7 +1053,7 @@ static bool accessibility_speak_windows(int speed,
 #ifdef HAVE_NVDA
    init_nvda();
 #endif
-   
+
    if (g_plat_win32_flags & PLAT_WIN32_FLAG_USE_POWERSHELL)
    {
       const char * template_lang = "powershell.exe -NoProfile -WindowStyle Hidden -Command \"Add-Type -AssemblyName System.Speech; $synth = New-Object System.Speech.Synthesis.SpeechSynthesizer; $synth.SelectVoice(\\\"%s\\\"); $synth.Rate = %s; $synth.Speak($input);\"";
@@ -1079,7 +1075,7 @@ static bool accessibility_speak_windows(int speed,
       wchar_t        *wc = utf8_to_utf16_string_alloc(speak_text);
       long res           = nvdaController_testIfRunning_func();
 
-      if (!wc || res != 0) 
+      if (!wc || res != 0)
       {
          RARCH_ERR("Error communicating with NVDA\n");
          if (wc)
