@@ -670,7 +670,7 @@ static bool win32_browser(
        * FIXME: We should really handle the
        * error case when this isn't big enough. */
       char new_title[PATH_MAX];
-      char new_file[32768];
+      char new_file[32768]; /* TODO/FIXME - is this not way too big? */
 
       new_title[0] = '\0';
       new_file[0]  = '\0';
@@ -752,12 +752,24 @@ static LRESULT win32_menu_loop(HWND owner, WPARAM wparam)
          {
             char win32_file[PATH_MAX_LENGTH] = {0};
             char *title_cp          = NULL;
+            wchar_t *title_wide     = NULL;
             size_t converted        = 0;
             const char *extensions  = "All Files (*.*)\0*.*\0\0";
             const char *title       = msg_hash_to_str(
                   MENU_ENUM_LABEL_VALUE_LOAD_CONTENT_LIST);
             settings_t *settings    = config_get_ptr();
             const char *initial_dir = settings->paths.directory_menu_content;
+            bool browser            = true;
+
+            /* Menubar accelerator hotkey is hijacked always, therefore must
+             * press the keyboard event manually when blocking the accelerator. */
+            if (     !settings->bools.ui_menubar_enable
+                  || (!settings->bools.video_windowed_fullscreen && settings->bools.video_fullscreen))
+            {
+               input_keyboard_event(true, RETROK_o,
+                     0, RETROK_LCTRL, RETRO_DEVICE_KEYBOARD);
+               break;
+            }
 
             /* Convert UTF8 to UTF16, then back to the
              * local code page.
@@ -765,26 +777,20 @@ static LRESULT win32_menu_loop(HWND owner, WPARAM wparam)
              * string display until Unicode is
              * fully supported.
              */
-            wchar_t *title_wide     = utf8_to_utf16_string_alloc(title);
+            title_wide = utf8_to_utf16_string_alloc(title);
 
             if (title_wide)
-               title_cp             = utf16_to_utf8_string_alloc(title_wide);
+               title_cp = utf16_to_utf8_string_alloc(title_wide);
 
-            if (!win32_browser(owner, win32_file, sizeof(win32_file),
-                     extensions, title_cp, initial_dir))
-            {
-               if (title_wide)
-                  free(title_wide);
-               if (title_cp)
-                  free(title_cp);
-               break;
-            }
+            browser = win32_browser(owner, win32_file, sizeof(win32_file), extensions, title_cp, initial_dir);
 
             if (title_wide)
                free(title_wide);
             if (title_cp)
                free(title_cp);
-            win32_load_content_from_gui(win32_file);
+
+            if (browser)
+               win32_load_content_from_gui(win32_file);
          }
          break;
       case ID_M_RESET:
@@ -815,6 +821,18 @@ static LRESULT win32_menu_loop(HWND owner, WPARAM wparam)
          command_event(CMD_EVENT_DISK_PREV, NULL);
          break;
       case ID_M_FULL_SCREEN:
+         {
+            /* Menubar accelerator hotkey is hijacked always, therefore must
+             * press the keyboard event manually when blocking the accelerator. */
+            settings_t *settings    = config_get_ptr();
+            if (     !settings->bools.ui_menubar_enable
+                  || (!settings->bools.video_windowed_fullscreen && settings->bools.video_fullscreen))
+            {
+               input_keyboard_event(true, RETROK_RETURN,
+                     0, RETROK_LALT, RETRO_DEVICE_KEYBOARD);
+               break;
+            }
+         }
          command_event(CMD_EVENT_FULLSCREEN_TOGGLE, NULL);
          break;
       case ID_M_MOUSE_GRAB:
@@ -877,12 +895,12 @@ static void win32_save_position(void)
    placement.rcNormalPosition.right  = 0;
    placement.rcNormalPosition.bottom = 0;
 
-   /* If 'skip_window_positions' is true it means we've
+   /* If SETTINGS_FLG_SKIP_WINDOW_POSITIONS is set, it means we've
     * just unloaded an override that had fullscreen mode
     * enabled while we have windowed mode set globally,
     * in this case we skip the following blocks to not
     * end up with fullscreen size and position. */
-   if (!settings->skip_window_positions)
+   if (!(settings->flags & SETTINGS_FLG_SKIP_WINDOW_POSITIONS))
    {
       if (GetWindowPlacement(main_window.hwnd, &placement))
       {
@@ -897,7 +915,7 @@ static void win32_save_position(void)
       }
    }
    else
-      settings->skip_window_positions = false;
+      settings->flags &= ~SETTINGS_FLG_SKIP_WINDOW_POSITIONS;
 
    if (window_save_positions)
    {
@@ -987,6 +1005,8 @@ static LRESULT CALLBACK wnd_proc_common(
                mod |= RETROKMOD_CAPSLOCK;
             if (GetKeyState(VK_SCROLL)  & 0x81)
                mod |= RETROKMOD_SCROLLOCK;
+            if (GetKeyState(VK_NUMLOCK) & 0x81)
+               mod |= RETROKMOD_NUMLOCK;
             if ((GetKeyState(VK_LWIN) | GetKeyState(VK_RWIN)) & 0x80)
                mod |= RETROKMOD_META;
 
@@ -1111,6 +1131,8 @@ static LRESULT CALLBACK wnd_proc_common_internal(HWND hwnd,
                mod |= RETROKMOD_CAPSLOCK;
             if (GetKeyState(VK_SCROLL)  & 0x81)
                mod |= RETROKMOD_SCROLLOCK;
+            if (GetKeyState(VK_NUMLOCK) & 0x81)
+               mod |= RETROKMOD_NUMLOCK;
             if ((GetKeyState(VK_LWIN) | GetKeyState(VK_RWIN)) & 0x80)
                mod |= RETROKMOD_META;
 
@@ -1350,15 +1372,18 @@ static LRESULT CALLBACK wnd_proc_common_dinput_internal(HWND hwnd,
             if (extended)
                keysym |= 0x80;
 
-            keycode = input_keymaps_translate_keysym_to_rk(keysym);
-            switch (keycode)
+            /* tell the driver about shift and alt key events */
+            if (keysym == 0x2A/*DIK_LSHIFT*/ || keysym == 0x36/*DIK_RSHIFT*/
+                     || keysym == 0x38/*DIK_LMENU*/ || keysym == 0xB8/*DIK_RMENU*/)
             {
-               /* L+R Shift handling done in dinput_poll */
-               case RETROK_LSHIFT:
-               case RETROK_RSHIFT:
-                  return 0;
+               void* input_data = (void*)(LONG_PTR)GetWindowLongPtr(main_window.hwnd, GWLP_USERDATA);
+               if (input_data && dinput_handle_message(input_data,
+                        message, wparam, lparam))
+                  return 0; /* key up already handled by the driver */
             }
 
+            keycode = input_keymaps_translate_keysym_to_rk(keysym);
+
             if (GetKeyState(VK_SHIFT)   & 0x80)
                mod |= RETROKMOD_SHIFT;
             if (GetKeyState(VK_CONTROL) & 0x80)
@@ -1369,6 +1394,8 @@ static LRESULT CALLBACK wnd_proc_common_dinput_internal(HWND hwnd,
                mod |= RETROKMOD_CAPSLOCK;
             if (GetKeyState(VK_SCROLL)  & 0x81)
                mod |= RETROKMOD_SCROLLOCK;
+            if (GetKeyState(VK_NUMLOCK) & 0x81)
+               mod |= RETROKMOD_NUMLOCK;
             if ((GetKeyState(VK_LWIN) | GetKeyState(VK_RWIN)) & 0x80)
                mod |= RETROKMOD_META;
 
