@@ -540,7 +540,7 @@ static void hlsl_d3d9_renderchain_set_shader_params(
       struct shader_pass *pass,
       unsigned video_w, unsigned video_h,
       unsigned tex_w, unsigned tex_h,
-      unsigned viewport_w, unsigned viewport_h)
+      unsigned vp_width, unsigned vp_height)
 {
    float frame_cnt;
    float video_size[2];
@@ -553,8 +553,8 @@ static void hlsl_d3d9_renderchain_set_shader_params(
    video_size[1]                            = video_h;
    texture_size[0]                          = tex_w;
    texture_size[1]                          = tex_h;
-   output_size[0]                           = viewport_w;
-   output_size[1]                           = viewport_h;
+   output_size[0]                           = vp_width;
+   output_size[1]                           = vp_height;
 
    d3d9x_constant_table_set_defaults(dev, fprg);
    d3d9x_constant_table_set_defaults(dev, vprg);
@@ -827,13 +827,13 @@ static bool hlsl_d3d9_renderchain_init(
       d3d9_video_t *d3d,
       hlsl_renderchain_t *chain,
       LPDIRECT3DDEVICE9 dev,
-      const D3DVIEWPORT9 *final_viewport,
+      const D3DVIEWPORT9 *out_vp,
       const struct LinkInfo *info,
       unsigned fmt
       )
 {
    chain->chain.dev                         = dev;
-   chain->chain.final_viewport              = (D3DVIEWPORT9*)final_viewport;
+   chain->chain.out_vp                      = (D3DVIEWPORT9*)out_vp;
    chain->chain.frame_count                 = 0;
    chain->chain.pixel_size                  = (fmt == RETRO_PIXEL_FORMAT_RGB565) ? 2 : 4;
 
@@ -966,7 +966,7 @@ static void hlsl_d3d9_renderchain_render(
    d3d9_convert_geometry(
          &first_pass->info,
          &out_width, &out_height,
-         current_width, current_height, chain->chain.final_viewport);
+         current_width, current_height, chain->chain.out_vp);
 
    d3d9_blit_to_texture(first_pass->tex,
          frame,
@@ -998,7 +998,7 @@ static void hlsl_d3d9_renderchain_render(
 
       d3d9_convert_geometry(&from_pass->info,
             &out_width, &out_height,
-            current_width, current_height, chain->chain.final_viewport);
+            current_width, current_height, chain->chain.out_vp);
 
       /* Clear out whole FBO. */
       viewport.Width  = to_pass->info.tex_w;
@@ -1043,18 +1043,18 @@ static void hlsl_d3d9_renderchain_render(
 
    d3d9_convert_geometry(&last_pass->info,
          &out_width, &out_height,
-         current_width, current_height, chain->chain.final_viewport);
+         current_width, current_height, chain->chain.out_vp);
 
    IDirect3DDevice9_SetViewport(
-         chain->chain.dev, (D3DVIEWPORT9*)chain->chain.final_viewport);
+         chain->chain.dev, (D3DVIEWPORT9*)chain->chain.out_vp);
 
    hlsl_d3d9_renderchain_set_vertices(
          d3d,
          chain, last_pass,
          current_width, current_height,
          out_width, out_height,
-         chain->chain.final_viewport->Width,
-         chain->chain.final_viewport->Height,
+         chain->chain.out_vp->Width,
+         chain->chain.out_vp->Height,
          chain->chain.frame_count, rotation);
 
    hlsl_d3d9_renderchain_render_pass(chain, last_pass,
@@ -1069,8 +1069,8 @@ static void hlsl_d3d9_renderchain_render(
    d3d9_hlsl_bind_program(chain->chain.dev, &chain->stock_shader);
    hlsl_d3d9_renderchain_calc_and_set_shader_mvp(
          chain, &chain->stock_shader,
-         chain->chain.final_viewport->Width,
-         chain->chain.final_viewport->Height, 0);
+         chain->chain.out_vp->Width,
+         chain->chain.out_vp->Height, 0);
 }
 
 static bool hlsl_d3d9_renderchain_add_pass(
@@ -1192,7 +1192,7 @@ static bool d3d9_hlsl_init_chain(d3d9_video_t *d3d,
    if (
          !hlsl_d3d9_renderchain_init(
             d3d, (hlsl_renderchain_t*)d3d->renderchain_data,
-            d3d->dev, &d3d->final_viewport, &link_info,
+            d3d->dev, &d3d->out_vp, &link_info,
             rgb32
             ? RETRO_PIXEL_FORMAT_XRGB8888
             : RETRO_PIXEL_FORMAT_RGB565
@@ -1213,7 +1213,7 @@ static bool d3d9_hlsl_init_chain(d3d9_video_t *d3d,
       d3d9_convert_geometry(
             &link_info,
             &out_width, &out_height,
-            current_width, current_height, &d3d->final_viewport);
+            current_width, current_height, &d3d->out_vp);
 
       link_info.pass  = &d3d->shader.pass[i];
       link_info.tex_w = next_pow2(out_width);
@@ -1343,7 +1343,21 @@ static bool d3d9_hlsl_initialize(
 
    d3d_matrix_identity(&d3d->mvp_transposed);
    d3d_matrix_ortho_off_center_lh(&d3d->mvp_transposed, 0, 1, 0, 1, 0, 1);
-   d3d_matrix_transpose(&d3d->mvp, &d3d->mvp_transposed);
+   d3d->mvp = d3d->mvp_transposed;
+
+   if (d3d->translate_x)
+   {
+      struct d3d_matrix *pout = (struct d3d_matrix*)&d3d->mvp;
+      float vp_x = -(d3d->translate_x/(float)d3d->out_vp.Width);
+      pout->m[3][0] = -1.0f + vp_x - 2.0f * 1 / (0 - 1);
+   }
+
+   if (d3d->translate_y)
+   {
+      struct d3d_matrix *pout = (struct d3d_matrix*)&d3d->mvp;
+      float vp_y = -(d3d->translate_y/(float)d3d->out_vp.Height);
+      pout->m[3][1] = 1.0f + vp_y + 2.0f * 1 / (0 - 1);
+   }
 
    IDirect3DDevice9_SetRenderState(d3d->dev, D3DRS_CULLMODE, D3DCULL_NONE);
    IDirect3DDevice9_SetRenderState(d3d->dev, D3DRS_SCISSORTESTENABLE, TRUE);
@@ -1622,7 +1636,11 @@ static bool d3d9_hlsl_frame(void *data, const void *frame,
    struct font_params *osd_params      = (struct font_params*)
       &video_info->osd_stat_params;
    const char *stat_text               = video_info->stat_text;
+#ifdef HAVE_MENU
    bool menu_is_alive                  = (video_info->menu_st_flags & MENU_ST_FLAG_ALIVE) ? true : false;
+#else
+   bool menu_is_alive                  = false;
+#endif
    bool overlay_behind_menu            = video_info->overlay_behind_menu;
 #ifdef HAVE_GFX_WIDGETS
    bool widgets_active                 = video_info->widgets_active;
@@ -1655,7 +1673,7 @@ static bool d3d9_hlsl_frame(void *data, const void *frame,
       d3d9_set_viewport(d3d, width, height, false, true);
 
       if (chain)
-         chain->final_viewport   = (D3DVIEWPORT9*)&d3d->final_viewport;
+         chain->out_vp           = (D3DVIEWPORT9*)&d3d->out_vp;
 
       d3d9_recompute_pass_sizes(chain->dev, chain, d3d);
 
@@ -1675,7 +1693,7 @@ static bool d3d9_hlsl_frame(void *data, const void *frame,
          0, 1, 0);
 
    IDirect3DDevice9_SetVertexShaderConstantF(d3d->dev, 0,
-         (const float*)&d3d->mvp_transposed, 4);
+         (const float*)&d3d->mvp, 4);
    hlsl_d3d9_renderchain_render(
          d3d, frame, frame_width, frame_height,
          pitch, d3d->dev_rotation);
@@ -1713,7 +1731,7 @@ static bool d3d9_hlsl_frame(void *data, const void *frame,
    if (d3d->menu && d3d->menu->enabled)
    {
       IDirect3DDevice9_SetVertexShaderConstantF(d3d->dev, 0,
-            (const float*)&d3d->mvp_transposed, 4);
+            (const float*)&d3d->mvp, 4);
       d3d9_overlay_render(d3d, width, height, d3d->menu, false);
 
       d3d->menu_display.offset = 0;
