@@ -393,8 +393,8 @@ static void fpga_get_poke_interface(void *data,
 }
 
 /* TODO/FIXME - implement */
-static void fpga_set_viewport(void *data, unsigned viewport_width,
-      unsigned viewport_height, bool force_full, bool allow_rotate) { }
+static void fpga_set_viewport(void *data, unsigned vp_width,
+      unsigned vp_height, bool force_full, bool allow_rotate) { }
 
 video_driver_t video_fpga = {
    fpga_init,
