@@ -923,76 +923,27 @@ static void gx2_set_projection(wiiu_video_t *wiiu)
 
 static void gx2_update_viewport(wiiu_video_t *wiiu)
 {
-   int x                           = 0;
-   int y                           = 0;
-   unsigned viewport_width         = wiiu->color_buffer.surface.width;
-   unsigned viewport_height        = wiiu->color_buffer.surface.height;
-   float device_aspect             = (float)viewport_width / viewport_height;
+   unsigned vp_width               = wiiu->color_buffer.surface.width;
+   unsigned vp_height              = wiiu->color_buffer.surface.height;
    settings_t *settings            = config_get_ptr();
    bool video_scale_integer        = settings->bools.video_scale_integer;
-   unsigned video_aspect_ratio_idx = settings->uints.video_aspect_ratio_idx;
 
    if (video_scale_integer)
    {
       video_viewport_get_scaled_integer(&wiiu->vp,
-            viewport_width, viewport_height,
-            video_driver_get_aspect_ratio(), wiiu->keep_aspect);
-      viewport_width  = wiiu->vp.width;
-      viewport_height = wiiu->vp.height;
+            vp_width, vp_height,
+            video_driver_get_aspect_ratio(), wiiu->keep_aspect, true);
+      vp_width  = wiiu->vp.width;
+      vp_height = wiiu->vp.height;
    }
    else if (wiiu->keep_aspect)
-   {
-      float desired_aspect = video_driver_get_aspect_ratio();
-
-#if defined(HAVE_MENU)
-      if (video_aspect_ratio_idx == ASPECT_RATIO_CUSTOM)
-      {
-         video_viewport_t *custom_vp = &settings->video_viewport_custom;
-         /* GX2 has top-left origin viewport. */
-         x                           = custom_vp->x;
-         y                           = custom_vp->y;
-         viewport_width              = custom_vp->width;
-         viewport_height             = custom_vp->height;
-      }
-      else
-#endif
-      {
-         float delta;
-
-         if (fabsf(device_aspect - desired_aspect) < 0.0001f)
-         {
-            /* If the aspect ratios of screen and desired aspect
-             * ratio are sufficiently equal (floating point stuff),
-             * assume they are actually equal.
-             */
-         }
-         else if (device_aspect > desired_aspect)
-         {
-            delta          = (desired_aspect / device_aspect - 1.0f)
-                             / 2.0f + 0.5f;
-            x              = (int)roundf(viewport_width * (0.5f - delta));
-            viewport_width = (unsigned)roundf(2.0f * viewport_width * delta);
-         }
-         else
-         {
-            delta           = (device_aspect / desired_aspect - 1.0f)
-                              / 2.0f + 0.5f;
-            y               = (int)roundf(viewport_height * (0.5f - delta));
-            viewport_height = (unsigned)roundf(2.0f * viewport_height * delta);
-         }
-      }
-
-      wiiu->vp.x      = x;
-      wiiu->vp.y      = y;
-      wiiu->vp.width  = viewport_width;
-      wiiu->vp.height = viewport_height;
-   }
+      video_viewport_get_scaled_aspect(&wiiu->vp, vp_width, vp_height, true);
    else
    {
       wiiu->vp.x      = 0;
       wiiu->vp.y      = 0;
-      wiiu->vp.width  = viewport_width;
-      wiiu->vp.height = viewport_height;
+      wiiu->vp.width  = vp_width;
+      wiiu->vp.height = vp_height;
    }
 
    gx2_set_projection(wiiu);
@@ -1712,7 +1663,8 @@ static bool wiiu_init_frame_textures(wiiu_video_t *wiiu, unsigned width, unsigne
 static void gx2_update_uniform_block(wiiu_video_t *wiiu,
       int pass, float *ubo, int id,
       int size, int uniformVarCount, GX2UniformVar *uniformVars,
-      uint64_t frame_count, int32_t frame_direction, uint32_t rotation)
+      uint64_t frame_count, int32_t frame_direction, uint32_t rotation, float core_aspect,
+      float core_aspect_rot, uint32_t frame_time_delta, uint32_t original_fps)
 {
    unsigned i;
    for (i = 0; i < uniformVarCount; i++)
@@ -1763,6 +1715,19 @@ static void gx2_update_uniform_block(wiiu_video_t *wiiu,
          continue;
       }
 
+      if (string_is_equal(id, "FrameTimeDelta"))
+      {
+         *dst        = frame_time_delta;
+         *(u32 *)dst = __builtin_bswap32(*(u32 *)dst);
+         continue;
+      }
+
+      if (string_is_equal(id, "OriginalFPS"))
+      {
+         *dst        = original_fps;
+         continue;
+      }
+
       if (string_is_equal(id, "Rotation"))
       {
          *dst        = rotation;
@@ -1770,6 +1735,18 @@ static void gx2_update_uniform_block(wiiu_video_t *wiiu,
          continue;
       }
 
+      if (string_is_equal(id, "OriginalAspect"))
+      {
+         *dst        = core_aspect;
+         continue;
+      }
+
+      if (string_is_equal(id, "OriginalAspectRotated"))
+      {
+         *dst        = core_aspect_rot;
+         continue;
+      }
+
       if (string_is_equal(id, "OriginalSize"))
       {
          ((GX2_vec4 *)dst)->x = wiiu->texture.surface.width;
@@ -1985,8 +1962,20 @@ static bool gx2_frame(void *data, const void *frame,
 #else
       int32_t frame_direction = 1;
 #endif
+
+      uint32_t frame_time_delta = video_driver_get_frame_time_delta_usec();
+
+      float original_fps = video_driver_get_original_fps();
+
       uint32_t rotation       = retroarch_get_rotation();
 
+      float core_aspect = video_driver_get_core_aspect();
+
+      /* OriginalAspectRotated: return 1/aspect for 90 and 270 rotated content */
+      float core_aspect_rot = core_aspect;
+      if (rotation == 1 || rotation == 3)
+         core_aspect_rot = 1/core_aspect;
+
       for (i = 0; i < wiiu->shader_preset->passes; i++)
       {
          unsigned j;
@@ -1997,7 +1986,8 @@ static bool gx2_frame(void *data, const void *frame,
             gx2_update_uniform_block(wiiu, i, wiiu->pass[i].vs_ubos[j], j,
                   wiiu->pass[i].gfd->vs->uniformBlocks[j].size,
                   wiiu->pass[i].gfd->vs->uniformVarCount, wiiu->pass[i].gfd->vs->uniformVars,
-                  frame_count, frame_direction, rotation);
+                  frame_count, frame_direction, rotation, core_aspect, core_aspect_rot,frame_time_delta, original_fps);
+
             GX2SetVertexUniformBlock(wiiu->pass[i].gfd->vs->uniformBlocks[j].offset,
                   wiiu->pass[i].gfd->vs->uniformBlocks[j].size, wiiu->pass[i].vs_ubos[j]);
          }
@@ -2009,7 +1999,7 @@ static bool gx2_frame(void *data, const void *frame,
             gx2_update_uniform_block(wiiu, i, wiiu->pass[i].ps_ubos[j], j,
                   wiiu->pass[i].gfd->ps->uniformBlocks[j].size,
                   wiiu->pass[i].gfd->ps->uniformVarCount, wiiu->pass[i].gfd->ps->uniformVars,
-                  frame_count, frame_direction, rotation);
+                  frame_count, frame_direction, rotation, core_aspect, core_aspect_rot,frame_time_delta, original_fps);
             GX2SetPixelUniformBlock(wiiu->pass[i].gfd->ps->uniformBlocks[j].offset,
                   wiiu->pass[i].gfd->ps->uniformBlocks[j].size, wiiu->pass[i].ps_ubos[j]);
          }
