@@ -24,7 +24,6 @@
 #include <fcntl.h>
 #include <unistd.h>
 #include <ctype.h>
-#include <assert.h>
 
 #include <sys/mman.h>
 #include <linux/omapfb.h>
@@ -38,7 +37,6 @@
 #endif
 
 #include <retro_inline.h>
-#include <retro_assert.h>
 #include <gfx/scaler/scaler.h>
 #include <gfx/video_frame.h>
 #include <string/stdstring.h>
@@ -66,27 +64,22 @@ typedef struct omapfb_state
 
 typedef struct omapfb_data
 {
-  const char* fbname;
-  int fd;
-
-  void *fb_mem;
-  unsigned fb_framesize;
-
   omapfb_page_t *pages;
-  int num_pages;
+  const char* fbname;
+  void *fb_mem;
   omapfb_page_t *cur_page;
   omapfb_page_t *old_page;
-
   /* current and saved (for later restore) states */
   omapfb_state_t* current_state;
   omapfb_state_t* saved_state;
 
+  int fd;
+  int num_pages;
+  unsigned fb_framesize;
   /* native screen size */
   unsigned nat_w, nat_h;
-
   /* bytes per pixel */
   unsigned bpp;
-
   bool sync;
 } omapfb_data_t;
 
@@ -398,7 +391,8 @@ static int omapfb_alloc_mem(omapfb_data_t *pdata)
    struct omapfb_mem_info mi;
    void                              *mem = NULL;
    const struct retro_game_geometry *geom = NULL;
-   struct retro_system_av_info *av_info   = NULL;
+   video_driver_state_t *video_st         = video_state_get_ptr();
+   struct retro_system_av_info *av_info   = &video_st->av_info;
 
    pdata->current_state = (omapfb_state_t*)calloc(1, sizeof(omapfb_state_t));
 
@@ -428,12 +422,10 @@ static int omapfb_alloc_mem(omapfb_data_t *pdata)
       }
    }
 
-   av_info  = video_viewport_get_system_av_info();
+   if (!av_info)
+      goto error;
 
-   if (av_info)
-      geom     = &av_info->geometry;
-
-   if (!geom)
+   if (!(geom = &av_info->geometry))
       goto error;
 
    mem_size = geom->max_width * geom->max_height *
@@ -682,13 +674,9 @@ static void omapfb_prepare(omapfb_data_t *pdata)
    /* issue flip before getting free page */
    omapfb_page_flip(pdata);
 
-   page            = omapfb_get_page(pdata);
-
-   retro_assert(page != NULL);
-
-   pdata->old_page = pdata->cur_page;
-   pdata->cur_page = page;
-
+   page                  = omapfb_get_page(pdata);
+   pdata->old_page       = pdata->cur_page;
+   pdata->cur_page       = page;
    pdata->cur_page->used = true;
 }
 
@@ -802,7 +790,7 @@ typedef struct omap_video
    } menu;
 } omap_video_t;
 
-static void omap_gfx_free(void *data)
+static void omap_free(void *data)
 {
    omap_video_t *vid = data;
    if (!vid)
@@ -932,7 +920,7 @@ static void omap_render_msg(omap_video_t *vid, const char *msg)
 }
 
 /* FIXME/TODO: Filters not supported. */
-static void *omap_gfx_init(const video_info_t *video,
+static void *omap_init(const video_info_t *video,
       input_driver_t **input, void **input_data)
 {
    settings_t *settings = config_get_ptr();
@@ -985,13 +973,13 @@ fail:
    return NULL;
 }
 
-static bool omap_gfx_frame(void *data, const void *frame, unsigned width,
+static bool omap_frame(void *data, const void *frame, unsigned width,
       unsigned height, uint64_t frame_count, unsigned pitch, const char *msg,
       video_frame_info_t *video_info)
 {
    omap_video_t  *vid = (omap_video_t*)data;
 #ifdef HAVE_MENU
-   bool menu_is_alive = video_info->menu_is_alive;
+   bool menu_is_alive = (video_info->menu_st_flags & MENU_ST_FLAG_ALIVE) ? true : false;
 #endif
 
    if (!frame)
@@ -1031,7 +1019,7 @@ static bool omap_gfx_frame(void *data, const void *frame, unsigned width,
    return true;
 }
 
-static void omap_gfx_set_nonblock_state(void *data, bool state, 
+static void omap_set_nonblock_state(void *data, bool state,
       bool adaptive_vsync_enabled, unsigned swap_interval)
 {
    omap_video_t *vid;
@@ -1043,10 +1031,10 @@ static void omap_gfx_set_nonblock_state(void *data, bool state,
    vid->omap->sync = !state;
 }
 
-static bool omap_gfx_alive(void *data) { return true; /* always alive */ }
-static bool omap_gfx_focus(void *data) { return true; /* fb device always has focus */ }
+static bool omap_alive(void *data) { return true; /* always alive */ }
+static bool omap_focus(void *data) { return true; /* fb device always has focus */ }
 
-static void omap_gfx_viewport_info(void *data, struct video_viewport *vp)
+static void omap_viewport_info(void *data, struct video_viewport *vp)
 {
    omap_video_t *vid = (omap_video_t*)data;
 
@@ -1059,13 +1047,13 @@ static void omap_gfx_viewport_info(void *data, struct video_viewport *vp)
    vp->height        = vp->full_height = vid->height;
 }
 
-static bool omap_gfx_suppress_screensaver(void *data, bool enable) { return false; }
-static bool omap_gfx_has_windowed(void *data) { return true; }
+static bool omap_suppress_screensaver(void *data, bool enable) { return false; }
+static bool omap_has_windowed(void *data) { return true; }
 
-static bool omap_gfx_set_shader(void *data,
+static bool omap_set_shader(void *data,
       enum rarch_shader_type type, const char *path) { return false; }
 
-static void omap_gfx_set_texture_frame(void *data, const void *frame, bool rgb32,
+static void omap_set_texture_frame(void *data, const void *frame, bool rgb32,
       unsigned width, unsigned height, float alpha)
 {
    omap_video_t          *vid = (omap_video_t*)data;
@@ -1084,12 +1072,10 @@ static void omap_gfx_set_texture_frame(void *data, const void *frame, bool rgb32
          width * (rgb32 ? sizeof(uint32_t) : sizeof(uint16_t)));
 }
 
-static void omap_gfx_set_texture_enable(void *data, bool state, bool full_screen)
+static void omap_set_texture_enable(void *data, bool state, bool full_screen)
 {
    omap_video_t *vid = (omap_video_t*)data;
-   vid->menu.active = state;
-
-   (void) full_screen;
+   vid->menu.active  = state;
 }
 
 static float omap_get_refresh_rate(void *data)
@@ -1102,11 +1088,11 @@ static float omap_get_refresh_rate(void *data)
           (s->yres + s->upper_margin + s->lower_margin + s->vsync_len);
 }
 
-static const video_poke_interface_t omap_gfx_poke_interface = {
+static const video_poke_interface_t omap_poke_interface = {
    NULL, /* get_flags  */
-   NULL,
-   NULL,
-   NULL,
+   NULL, /* load_texture */
+   NULL, /* unload_texture */
+   NULL, /* set_video_mode */
    omap_get_refresh_rate,
    NULL, /* set_filtering */
    NULL, /* get_video_output_size */
@@ -1116,49 +1102,48 @@ static const video_poke_interface_t omap_gfx_poke_interface = {
    NULL, /* get_proc_address */
    NULL, /* set_aspect_ratio */
    NULL, /* apply_state_changes */
-   omap_gfx_set_texture_frame,
-   omap_gfx_set_texture_enable,
-   NULL,
-   NULL,                         /* show_mouse */
-   NULL,                         /* grab_mouse_toggle */
-   NULL,                         /* get_current_shader */
-   NULL,                         /* get_current_software_framebuffer */
-   NULL,                         /* get_hw_render_interface */
-   NULL,                         /* set_hdr_max_nits */
-   NULL,                         /* set_hdr_paper_white_nits */
-   NULL,                         /* set_hdr_contrast */
-   NULL                          /* set_hdr_expand_gamut */
+   omap_set_texture_frame,
+   omap_set_texture_enable,
+   NULL, /* set_osd_msg */
+   NULL, /* show_mouse */
+   NULL, /* grab_mouse_toggle */
+   NULL, /* get_current_shader */
+   NULL, /* get_current_software_framebuffer */
+   NULL, /* get_hw_render_interface */
+   NULL, /* set_hdr_max_nits */
+   NULL, /* set_hdr_paper_white_nits */
+   NULL, /* set_hdr_contrast */
+   NULL  /* set_hdr_expand_gamut */
 };
 
-static void omap_gfx_get_poke_interface(void *data,
+static void omap_get_poke_interface(void *data,
       const video_poke_interface_t **iface)
 {
-   (void)data;
-   *iface = &omap_gfx_poke_interface;
+   *iface = &omap_poke_interface;
 }
 
 video_driver_t video_omap = {
-   omap_gfx_init,
-   omap_gfx_frame,
-   omap_gfx_set_nonblock_state,
-   omap_gfx_alive,
-   omap_gfx_focus,
-   omap_gfx_suppress_screensaver,
-   omap_gfx_has_windowed,
-   omap_gfx_set_shader,
-   omap_gfx_free,
+   omap_init,
+   omap_frame,
+   omap_set_nonblock_state,
+   omap_alive,
+   omap_focus,
+   omap_suppress_screensaver,
+   omap_has_windowed,
+   omap_set_shader,
+   omap_free,
    "omap",
    NULL, /* set_viewport */
    NULL, /* set_rotation */
-   omap_gfx_viewport_info,
+   omap_viewport_info,
    NULL, /* read_viewport  */
    NULL, /* read_frame_raw */
-
 #ifdef HAVE_OVERLAY
-   NULL, /* overlay_interface */
+   NULL, /* get_overlay_interface */
 #endif
-#ifdef HAVE_VIDEO_LAYOUT
-  NULL,
+   omap_get_poke_interface,
+   NULL, /* wrap_type_to_enum */
+#ifdef HAVE_GFX_WIDGETS
+   NULL  /* gfx_widgets_enabled */
 #endif
-   omap_gfx_get_poke_interface
 };
