@@ -316,47 +316,39 @@ static void vg_free(void *data)
 }
 
 static void vg_calculate_quad(vg_t *vg,
-      unsigned width, unsigned height)
+      unsigned vp_width, unsigned vp_height)
 {
-   /* set viewport for aspect ratio, taken from the OpenGL driver. */
-   if (vg->keep_aspect)
-   {
-      float desired_aspect = video_driver_get_aspect_ratio();
+   struct video_viewport_t vp;
+   settings_t *settings      = config_get_ptr();
+   bool video_scale_integer  = settings->bools.video_scale_integer;
+   float device_aspect       = (float)width / height;
 
-      /* If the aspect ratios of screen and desired aspect ratio
-       * are sufficiently equal (floating point stuff),
-       * assume they are actually equal. */
-      if (fabs(vg->mScreenAspect - desired_aspect) < 0.0001)
-      {
-         vg->x1 = 0;
-         vg->y1 = 0;
-         vg->x2 = width;
-         vg->y2 = height;
-      }
-      else if (vg->mScreenAspect > desired_aspect)
-      {
-         float delta = (desired_aspect / vg->mScreenAspect - 1.0) / 2.0 + 0.5;
-         vg->x1 = width * (0.5 - delta);
-         vg->y1 = 0;
-         vg->x2 = 2.0 * width * delta + vg->x1;
-         vg->y2 = height + vg->y1;
-      }
-      else
-      {
-         float delta = (vg->mScreenAspect / desired_aspect - 1.0) / 2.0 + 0.5;
-         vg->x1 = 0;
-         vg->y1 = height * (0.5 - delta);
-         vg->x2 = width + vg->x1;
-         vg->y2 = 2.0 * height * delta + vg->y1;
-      }
-   }
-   else
+   vp.x                      = 0;
+   vp.y                      = 0;
+   vp.width                  = vp_width;
+   vp.height                 = vp_height;
+   vp.full_width             = vp_width;
+   vp.full_height            = vp_height;
+
+   if (vg->ctx_driver->translate_aspect)
+      device_aspect = vg->ctx_driver->translate_aspect(vg->ctx_data, vp_width, vp_height);
+
+   vg->mScreenAspect = device_aspect;
+   /* OpenVG uses a bottom-left origin coordinate system */
+   if (video_scale_integer)
    {
-      vg->x1 = 0;
-      vg->y1 = 0;
-      vg->x2 = width;
-      vg->y2 = height;
+      video_viewport_get_scaled_integer(&vp,
+            vp_width, vp_height,
+            video_driver_get_aspect_ratio(),
+            vg->keep_aspect,
+            false);
    }
+   else if (vg->keep_aspect)
+      video_viewport_get_scaled_aspect(&vp, vp_width, vp_height, false);
+   vg->x1 = vp.x;
+   vg->y1 = vp.y;
+   vg->x2 = vp.width;
+   vg->y2 = vp.height;
 
    vg->scissor[0] = vg->x1;
    vg->scissor[1] = vg->y1;
