@@ -156,14 +156,14 @@ bool glslang_parse_meta(const struct string_list *lines, glslang_meta *meta)
                 * if they are exactly the same. */
                if (parameter_found)
                {
-                  const glslang_parameter *parameter = 
+                  const glslang_parameter *parameter =
                      &meta->parameters[parameter_index];
 
-                  if (   parameter->desc    != desc    ||
-                        parameter->initial != initial ||
-                        parameter->minimum != minimum ||
-                        parameter->maximum != maximum ||
-                        parameter->step    != step
+                  if (     (parameter->desc    != desc)
+                        || (parameter->initial != initial)
+                        || (parameter->minimum != minimum)
+                        || (parameter->maximum != maximum)
+                        || (parameter->step    != step)
                      )
                   {
                      RARCH_ERR("[slang]: Duplicate parameters found for \"%s\", but arguments do not match.\n", id);
@@ -214,13 +214,13 @@ bool glslang_compile_shader(const char *shader_path, glslang_output *output)
 {
 #if defined(HAVE_GLSLANG)
    struct string_list lines;
-   
+
    if (!string_list_initialize(&lines))
       return false;
 
    RARCH_LOG("[slang]: Compiling shader: \"%s\".\n", shader_path);
 
-   if (!glslang_read_shader_file(shader_path, &lines, true))
+   if (!glslang_read_shader_file(shader_path, &lines, true, false))
       goto error;
    output->meta = glslang_meta{};
    if (!glslang_parse_meta(&lines, &output->meta))
