@@ -98,9 +98,14 @@ struct shader_uniforms
 
    int frame_count;
    int frame_direction;
+   int frame_time_delta;
+   float original_fps;
    /* Use int for maximal compatibility despite other drivers using uint. */
    int rotation;
 
+   float core_aspect;
+   float core_aspect_rot;
+
    int lut_texture[GFX_MAX_TEXTURES];
    unsigned frame_count_mod;
 
@@ -287,7 +292,7 @@ static const XXH64_hash_t gl_glsl_hash_shader(
    {
       XXH64_update(state, source[n], strlen(source[n]));
    }
-   
+
    XXH64_hash_t const hash = XXH64_digest(state);
 
    XXH64_freeState(state);
@@ -366,13 +371,22 @@ static bool gl_glsl_compile_shader(glsl_shader_data_t *glsl,
          strtoul(existing_version + 8, (char**)&program, 10);
 
 #ifdef HAVE_OPENGLES
-      if (version_no < 130)
-         version_no    = 100;
-      else
+      if (version_no >= 130 && version_no < 330)
       {
          version_extra = " es";
          version_no    = 300;
       }
+      else if (version_no == 330)
+      {
+         version_extra = " es";
+         version_no    = 310;
+      }
+      else if (version_no > 330)
+      {
+         version_extra = " es";
+         version_no    = 320;
+      }
+      else version_no  = 100;
 #endif
       snprintf(version,
             sizeof(version), "#version %u%s\n", version_no, version_extra);
@@ -408,10 +422,10 @@ static bool gl_glsl_compile_shader(glsl_shader_data_t *glsl,
    source[2] = glsl->alias_define;
    source[3] = program;
 
-#if defined(ORBIS) 
+#if defined(ORBIS)
    {
       char save_path[250];
-      XXH64_hash_t const hash = 
+      XXH64_hash_t const hash =
          gl_glsl_hash_shader(source, ARRAY_SIZE(source));
       snprintf(save_path, sizeof(save_path),
             "/data/retroarch/temp/%lx.sb", hash);
@@ -459,7 +473,7 @@ static bool gl_glsl_compile_program(
       struct shader_program_info *program_info)
 {
    glsl_shader_data_t                 *glsl = (glsl_shader_data_t*)data;
-   struct shader_program_glsl_data *program = 
+   struct shader_program_glsl_data *program =
       (struct shader_program_glsl_data*)program_data;
    GLuint prog                              = glCreateProgram();
 
@@ -477,7 +491,8 @@ static bool gl_glsl_compile_program(
       if (!gl_glsl_compile_shader(
                glsl,
                program->vprg,
-               "#define VERTEX\n#define PARAMETER_UNIFORM\n", program_info->vertex))
+               "#define VERTEX\n#define PARAMETER_UNIFORM\n#define _HAS_ORIGINALASPECT_UNIFORMS\n#define _HAS_FRAMETIME_UNIFORMS\n",
+               program_info->vertex))
       {
          RARCH_ERR("Failed to compile vertex shader #%u\n", idx);
          goto error;
@@ -491,7 +506,7 @@ static bool gl_glsl_compile_program(
       RARCH_LOG("[GLSL]: Found GLSL fragment shader.\n");
       program->fprg = glCreateShader(GL_FRAGMENT_SHADER);
       if (!gl_glsl_compile_shader(glsl, program->fprg,
-               "#define FRAGMENT\n#define PARAMETER_UNIFORM\n",
+               "#define FRAGMENT\n#define PARAMETER_UNIFORM\n#define _HAS_ORIGINALASPECT_UNIFORMS\n#define _HAS_FRAMETIME_UNIFORMS\n",
                program_info->fragment))
       {
          RARCH_ERR("Failed to compile fragment shader #%u\n", idx);
@@ -725,22 +740,28 @@ static void gl_glsl_find_uniforms(glsl_shader_data_t *glsl,
    glUseProgram(prog);
 
 #if defined(VITA)
-   uni->time            = gl_glsl_get_uniform(glsl, prog, "Time");
+   uni->time             = gl_glsl_get_uniform(glsl, prog, "Time");
 #endif
-   uni->mvp             = gl_glsl_get_uniform(glsl, prog, "MVPMatrix");
-   uni->tex_coord       = gl_glsl_get_attrib(glsl, prog, "TexCoord");
-   uni->vertex_coord    = gl_glsl_get_attrib(glsl, prog, "VertexCoord");
-   uni->color           = gl_glsl_get_attrib(glsl, prog, "Color");
-   uni->lut_tex_coord   = gl_glsl_get_attrib(glsl, prog, "LUTTexCoord");
 
-   uni->input_size      = gl_glsl_get_uniform(glsl, prog, "InputSize");
-   uni->output_size     = gl_glsl_get_uniform(glsl, prog, "OutputSize");
-   uni->texture_size    = gl_glsl_get_uniform(glsl, prog, "TextureSize");
-   uni->final_vp_size   = gl_glsl_get_uniform(glsl, prog, "FinalViewportSize");
+   uni->mvp              = gl_glsl_get_uniform(glsl, prog, "MVPMatrix");
+   uni->tex_coord        = gl_glsl_get_attrib(glsl, prog, "TexCoord");
+   uni->vertex_coord     = gl_glsl_get_attrib(glsl, prog, "VertexCoord");
+   uni->color            = gl_glsl_get_attrib(glsl, prog, "Color");
+   uni->lut_tex_coord    = gl_glsl_get_attrib(glsl, prog, "LUTTexCoord");
+
+   uni->input_size       = gl_glsl_get_uniform(glsl, prog, "InputSize");
+   uni->output_size      = gl_glsl_get_uniform(glsl, prog, "OutputSize");
+   uni->texture_size     = gl_glsl_get_uniform(glsl, prog, "TextureSize");
+   uni->final_vp_size    = gl_glsl_get_uniform(glsl, prog, "FinalViewportSize");
+
+   uni->frame_count      = gl_glsl_get_uniform(glsl, prog, "FrameCount");
+   uni->frame_direction  = gl_glsl_get_uniform(glsl, prog, "FrameDirection");
+   uni->frame_time_delta = gl_glsl_get_uniform(glsl, prog, "FrameTimeDelta");
+   uni->original_fps         = gl_glsl_get_uniform(glsl, prog, "OriginalFPS");
+   uni->rotation         = gl_glsl_get_uniform(glsl, prog, "Rotation");
+   uni->core_aspect      = gl_glsl_get_uniform(glsl, prog, "OriginalAspect");
+   uni->core_aspect_rot  = gl_glsl_get_uniform(glsl, prog, "OriginalAspectRotAted");
 
-   uni->frame_count     = gl_glsl_get_uniform(glsl, prog, "FrameCount");
-   uni->frame_direction = gl_glsl_get_uniform(glsl, prog, "FrameDirection");
-   uni->rotation        = gl_glsl_get_uniform(glsl, prog, "Rotation");
 
    for (i = 0; i < glsl->shader->luts; i++)
       uni->lut_texture[i] = glGetUniformLocation(prog, glsl->shader->lut[i].id);
@@ -1103,7 +1124,7 @@ static void *gl_glsl_init(void *data, const char *path)
       goto error;
    }
 #else
-   if (      glsl_core 
+   if (      glsl_core
          && (!(glsl->shader->flags & SHDR_FLAG_MODERN)))
    {
       RARCH_ERR("[GL]: GL core context is used, but shader is not core compatible. Cannot use it.\n");
@@ -1272,8 +1293,8 @@ static void gl_glsl_set_params(void *dat, void *shader_data)
    float input_size[2], output_size[2], texture_size[2], final_vp_size[2];
    video_shader_ctx_params_t          *params = (video_shader_ctx_params_t*)dat;
    gl2_t                             *gl_data = (gl2_t*)params->data;
-   unsigned vp_width                          = gl_data->vp_out_width;
-   unsigned vp_height                         = gl_data->vp_out_height;
+   unsigned vp_width                          = gl_data->out_vp_width;
+   unsigned vp_height                         = gl_data->out_vp_height;
    unsigned width                             = params->width;
    unsigned height                            = params->height;
    unsigned tex_width                         = params->tex_width;
@@ -1346,9 +1367,27 @@ static void gl_glsl_set_params(void *dat, void *shader_data)
          glUniform1i(uni->frame_direction, 1);
    }
 
+  if (uni->frame_time_delta >= 0)
+      glUniform1i(uni->frame_time_delta, video_driver_get_frame_time_delta_usec());
+
+  if (uni->original_fps >= 0)
+      glUniform1f(uni->original_fps, video_driver_get_original_fps());
+
   if (uni->rotation >= 0)
       glUniform1i(uni->rotation, retroarch_get_rotation());
 
+  if (uni->core_aspect >= 0)
+      glUniform1f(uni->core_aspect, video_driver_get_core_aspect());
+
+  if (uni->core_aspect_rot >= 0) {
+      /* OriginalAspectRotated: return 1/aspect for 90 and 270 rotated content */
+      float core_aspect_rot = video_driver_get_core_aspect();
+      uint32_t rot = retroarch_get_rotation();
+      if (rot == 1 || rot == 3)
+         core_aspect_rot = 1/core_aspect_rot;
+      glUniform1f(uni->core_aspect_rot, core_aspect_rot);
+  }
+
    /* Set lookup textures. */
    for (i = 0; i < glsl->shader->luts; i++)
    {
@@ -1536,7 +1575,7 @@ static bool gl_glsl_set_mvp(void *shader_data, const void *mat_data)
    int loc;
    glsl_shader_data_t *glsl   = (glsl_shader_data_t*)shader_data;
 
-   if (      !glsl 
+   if (      !glsl
          || (!(glsl->shader->flags & SHDR_FLAG_MODERN)))
       return false;
 
@@ -1580,7 +1619,7 @@ static bool gl_glsl_set_coords(void *shader_data,
    const struct shader_uniforms *uni = glsl
       ? &glsl->uniforms[glsl->active_idx] : NULL;
 
-   if (     !glsl 
+   if (     !glsl
          || (!(glsl->shader->flags & SHDR_FLAG_MODERN))
          || !coords)
    {
