@@ -27,6 +27,7 @@
 #include <libretro.h>
 
 #include <boolean.h>
+#include <retro_miscellaneous.h>
 
 #include "../playlist.h"
 
@@ -34,7 +35,7 @@ RETRO_BEGIN_DECLS
 
 /* Note: This implementation reflects the current
  * setup of:
- * - menu_driver_set_thumbnail_system()
+ * - gfx_thumbnail_set_system()
  * - menu_driver_set_thumbnail_content()
  * - menu_driver_update_thumbnail_path()
  * This is absolutely not the best way to handle things,
@@ -44,7 +45,8 @@ RETRO_BEGIN_DECLS
 enum gfx_thumbnail_id
 {
    GFX_THUMBNAIL_RIGHT = 0,
-   GFX_THUMBNAIL_LEFT
+   GFX_THUMBNAIL_LEFT,
+   GFX_THUMBNAIL_ICON
 };
 
 /* Prevent direct access to gfx_thumbnail_path_data_t members */
@@ -57,17 +59,21 @@ struct gfx_thumbnail_path_data
 {
    enum playlist_thumbnail_mode playlist_right_mode;
    enum playlist_thumbnail_mode playlist_left_mode;
+   enum playlist_thumbnail_mode playlist_icon_mode;
    size_t playlist_index;
+   size_t system_len;
+   size_t content_label_len;
+   char content_label[NAME_MAX_LENGTH];
+   char content_core_name[NAME_MAX_LENGTH];
+   char system[NAME_MAX_LENGTH];
+   char content_db_name[NAME_MAX_LENGTH];
    char content_path[PATH_MAX_LENGTH];
    char content_img[PATH_MAX_LENGTH];
    char content_img_short[PATH_MAX_LENGTH];
    char content_img_full[PATH_MAX_LENGTH];
    char right_path[PATH_MAX_LENGTH];
    char left_path[PATH_MAX_LENGTH];
-   char content_label[256];
-   char content_core_name[256];
-   char system[256];
-   char content_db_name[256];
+   char icon_path[PATH_MAX_LENGTH];
 };
 
 /* Initialisation */
@@ -90,6 +96,10 @@ bool gfx_thumbnail_is_enabled(gfx_thumbnail_path_data_t *path_data, enum gfx_thu
 
 /* Setters */
 
+/* Fills content_img field of path_data using existing
+ * content_label field (for internal use only) */
+void gfx_thumbnail_fill_content_img(char *s, size_t len, const char *src, bool shorten);
+
 /* Sets current 'system' (default database name).
  * Returns true if 'system' is valid.
  * If playlist is provided, extracts system-specific
@@ -129,31 +139,9 @@ bool gfx_thumbnail_update_path(gfx_thumbnail_path_data_t *path_data, enum gfx_th
 
 /* Getters */
 
-/* Fetches the current thumbnail file path of the
- * specified thumbnail 'type'.
- * Returns true if path is valid. */
-bool gfx_thumbnail_get_path(gfx_thumbnail_path_data_t *path_data, enum gfx_thumbnail_id thumbnail_id, const char **path);
-
-/* Fetches current 'system' (default database name).
- * Returns true if 'system' is valid. */
-bool gfx_thumbnail_get_system(gfx_thumbnail_path_data_t *path_data, const char **system);
-
-/* Fetches current thumbnail label.
- * Returns true if label is valid. */
-bool gfx_thumbnail_get_label(gfx_thumbnail_path_data_t *path_data, const char **label);
-
-/* Fetches current thumbnail core name.
- * Returns true if core name is valid. */
-bool gfx_thumbnail_get_core_name(gfx_thumbnail_path_data_t *path_data, const char **core_name);
-
-/* Fetches current thumbnail image name
- * (name is the same for all thumbnail types).
- * Returns true if image name is valid. */
-bool gfx_thumbnail_get_img_name(gfx_thumbnail_path_data_t *path_data, const char **img_name, enum playlist_thumbnail_name_flags name_flags);
-
 /* Fetches current content directory.
  * Returns true if content directory is valid. */
-bool gfx_thumbnail_get_content_dir(gfx_thumbnail_path_data_t *path_data, char *content_dir, size_t len);
+size_t gfx_thumbnail_get_content_dir(gfx_thumbnail_path_data_t *path_data, char *s, size_t len);
 
 RETRO_END_DECLS
 
