@@ -66,6 +66,25 @@ enum aspect_ratio
    ASPECT_RATIO_END
 };
 
+enum video_scale_integer_axis
+{
+   VIDEO_SCALE_INTEGER_AXIS_Y = 0,
+   VIDEO_SCALE_INTEGER_AXIS_Y_X,
+   VIDEO_SCALE_INTEGER_AXIS_Y_XHALF,
+   VIDEO_SCALE_INTEGER_AXIS_YHALF_XHALF,
+   VIDEO_SCALE_INTEGER_AXIS_X,
+   VIDEO_SCALE_INTEGER_AXIS_XHALF,
+   VIDEO_SCALE_INTEGER_AXIS_LAST
+};
+
+enum video_scale_integer_scaling
+{
+   VIDEO_SCALE_INTEGER_SCALING_UNDERSCALE = 0,
+   VIDEO_SCALE_INTEGER_SCALING_OVERSCALE,
+   VIDEO_SCALE_INTEGER_SCALING_SMART,
+   VIDEO_SCALE_INTEGER_SCALING_LAST
+};
+
 enum rotation
 {
    ORIENTATION_NORMAL = 0,
