@@ -163,16 +163,21 @@ void gfx_ctx_wl_show_mouse(void *data, bool state)
       return;
 
    if (state)
-   {
-      struct wl_cursor_image *image = wl->cursor.default_cursor->images[0];
-      wl_pointer_set_cursor(wl->wl_pointer,
-            wl->cursor.serial, wl->cursor.surface,
-            image->hotspot_x, image->hotspot_y);
-      wl_surface_attach(wl->cursor.surface,
-            wl_cursor_image_get_buffer(image), 0, 0);
-      wl_surface_damage(wl->cursor.surface, 0, 0, image->width, image->height);
-      wl_surface_commit(wl->cursor.surface);
-   }
+      if (wl->cursor_shape_device)
+         wp_cursor_shape_device_v1_set_shape(
+            wl->cursor_shape_device, wl->cursor.serial, WP_CURSOR_SHAPE_DEVICE_V1_SHAPE_DEFAULT);
+      else
+      {
+         struct wl_cursor_image *image = wl->cursor.default_cursor->images[0];
+         wl_pointer_set_cursor(wl->wl_pointer,
+               wl->cursor.serial, wl->cursor.surface,
+               image->hotspot_x, image->hotspot_y);
+         wl_surface_attach(wl->cursor.surface,
+               wl_cursor_image_get_buffer(image), 0, 0);
+         wl_surface_damage(wl->cursor.surface, 0, 0, image->width, image->height);
+         wl_surface_commit(wl->cursor.surface);
+
+      }
    else
       wl_pointer_set_cursor(wl->wl_pointer, wl->cursor.serial, NULL, 0, 0);
 
@@ -213,6 +218,8 @@ static void wl_pointer_handle_leave(void *data,
    wl->input.mouse.left       = false;
    wl->input.mouse.right      = false;
    wl->input.mouse.middle     = false;
+   wl->input.mouse.side       = false;
+   wl->input.mouse.extra      = false;
 
    if (wl->input.mouse.surface == surface)
       wl->input.mouse.surface = NULL;
@@ -270,6 +277,12 @@ static void wl_pointer_handle_button(void *data,
          case BTN_MIDDLE:
             wl->input.mouse.middle = true;
             break;
+         case BTN_SIDE:
+            wl->input.mouse.side = true;
+            break;
+         case BTN_EXTRA:
+            wl->input.mouse.extra = true;
+            break;
       }
    }
    else
@@ -285,6 +298,12 @@ static void wl_pointer_handle_button(void *data,
          case BTN_MIDDLE:
             wl->input.mouse.middle = false;
             break;
+         case BTN_SIDE:
+            wl->input.mouse.side = false;
+            break;
+         case BTN_EXTRA:
+            wl->input.mouse.extra = false;
+            break;
       }
    }
 }
@@ -450,21 +469,17 @@ static void handle_relative_motion(void *data,
 }
 
 static void
-locked_pointer_locked(void *data, struct zwp_locked_pointer_v1 *locked_pointer)
-{
-}
+locked_pointer_locked(void *data, struct zwp_locked_pointer_v1 *lockptr) { }
 
 static void
-locked_pointer_unlocked(void *data, struct zwp_locked_pointer_v1 *locked_pointer)
-{
-}
+locked_pointer_unlocked(void *data, struct zwp_locked_pointer_v1 *lockptr) { }
 
 static void wl_touch_handle_frame(void *data, struct wl_touch *wl_touch) { }
 
 static void wl_touch_handle_cancel(void *data, struct wl_touch *wl_touch)
 {
    /* If i understand the spec correctly we have to reset all touches here
-    * since they were not ment for us anyway */
+    * since they were not meant for us anyway */
    int i;
    gfx_ctx_wayland_data_t *wl = (gfx_ctx_wayland_data_t*)data;
 
@@ -498,11 +513,20 @@ static void wl_seat_handle_capabilities(void *data,
    {
       wl->wl_pointer = wl_seat_get_pointer(seat);
       wl_pointer_add_listener(wl->wl_pointer, &pointer_listener, wl);
-      wl->wl_relative_pointer =
-         zwp_relative_pointer_manager_v1_get_relative_pointer(
-            wl->relative_pointer_manager, wl->wl_pointer);
-      zwp_relative_pointer_v1_add_listener(wl->wl_relative_pointer,
-         &relative_pointer_listener, wl);
+      if (wl->relative_pointer_manager)
+      {
+         wl->wl_relative_pointer =
+            zwp_relative_pointer_manager_v1_get_relative_pointer(
+               wl->relative_pointer_manager, wl->wl_pointer);
+         zwp_relative_pointer_v1_add_listener(wl->wl_relative_pointer,
+            &relative_pointer_listener, wl);
+      }
+      if (!wl->cursor_shape_device && wl->cursor_shape_manager)
+      {
+         wl->cursor_shape_device =
+            wp_cursor_shape_manager_v1_get_pointer(
+               wl->cursor_shape_manager, wl->wl_pointer);
+      }
    }
    else if (!(caps & WL_SEAT_CAPABILITY_POINTER) && wl->wl_pointer)
    {
@@ -534,13 +558,15 @@ static bool wl_update_scale(gfx_ctx_wayland_data_t *wl)
 
    wl_list_for_each(os, &wl->current_outputs, link)
    {
-      if (os->output->scale > largest_scale) {
+      if (os->output->scale > largest_scale)
+      {
          largest_scale = os->output->scale;
          new_output    = os->output;
       }
    };
 
-   if (new_output && wl->current_output != new_output) {
+   if (new_output && wl->current_output != new_output)
+   {
       wl->current_output       = new_output;
       wl->pending_buffer_scale = new_output->scale;
       return true;
@@ -701,21 +727,22 @@ static bool wl_setup_data_device(gfx_ctx_wayland_data_t *wl)
 static void wl_registry_handle_global(void *data, struct wl_registry *reg,
       uint32_t id, const char *interface, uint32_t version)
 {
+   int found = 1;
    gfx_ctx_wayland_data_t *wl = (gfx_ctx_wayland_data_t*)data;
 
    RARCH_DBG("[Wayland]: Add global %u, interface %s, version %u\n",
          id, interface, version);
 
-   if (string_is_equal(interface, wl_compositor_interface.name))
+   if (string_is_equal(interface, wl_compositor_interface.name) && found++)
       wl->compositor = (struct wl_compositor*)wl_registry_bind(reg,
             id, &wl_compositor_interface, MIN(version, 4));
-   else if (string_is_equal(interface, wp_viewporter_interface.name))
+   else if (string_is_equal(interface, wp_viewporter_interface.name) && found++)
       wl->viewporter = (struct wp_viewporter*)wl_registry_bind(reg,
             id, &wp_viewporter_interface, MIN(version, 1));
-   else if (string_is_equal(interface, wp_fractional_scale_manager_v1_interface.name))
+   else if (string_is_equal(interface, wp_fractional_scale_manager_v1_interface.name) && found++)
       wl->fractional_scale_manager = (struct wp_fractional_scale_manager_v1*)
          wl_registry_bind(reg, id, &wp_fractional_scale_manager_v1_interface, MIN(version, 1));
-   else if (string_is_equal(interface, wl_output_interface.name))
+   else if (string_is_equal(interface, wl_output_interface.name) && found++)
    {
       display_output_t *od = (display_output_t*)
          calloc(1, sizeof(display_output_t));
@@ -730,43 +757,59 @@ static void wl_registry_handle_global(void *data, struct wl_registry *reg,
       wl_list_insert(&wl->all_outputs, &od->link);
       wl_display_roundtrip(wl->input.dpy);
    }
-   else if (string_is_equal(interface, xdg_wm_base_interface.name))
+   else if (string_is_equal(interface, xdg_wm_base_interface.name) && found++)
       wl->xdg_shell = (struct xdg_wm_base*)
          wl_registry_bind(reg, id, &xdg_wm_base_interface, MIN(version, 3));
-   else if (string_is_equal(interface, wl_shm_interface.name))
+   else if (string_is_equal(interface, wl_shm_interface.name) && found++)
       wl->shm = (struct wl_shm*)wl_registry_bind(reg, id, &wl_shm_interface, MIN(version, 1));
-   else if (string_is_equal(interface, wl_seat_interface.name))
+   else if (string_is_equal(interface, wl_seat_interface.name) && found++)
    {
       wl->seat = (struct wl_seat*)wl_registry_bind(reg, id, &wl_seat_interface, MIN(version, 2));
       wl_seat_add_listener(wl->seat, &seat_listener, wl);
       wl_setup_data_device(wl);
    }
-   else if (string_is_equal(interface, wl_data_device_manager_interface.name))
+   else if (string_is_equal(interface, wl_data_device_manager_interface.name) && found++)
    {
       wl->data_device_manager = (struct wl_data_device_manager*)
          wl_registry_bind(
                reg, id, &wl_data_device_manager_interface, MIN(version, 3));
       wl_setup_data_device(wl);
    }
-   else if (string_is_equal(interface, zwp_idle_inhibit_manager_v1_interface.name))
+   else if (string_is_equal(interface, zwp_idle_inhibit_manager_v1_interface.name) && found++)
       wl->idle_inhibit_manager = (struct zwp_idle_inhibit_manager_v1*)
          wl_registry_bind(
             reg, id, &zwp_idle_inhibit_manager_v1_interface, MIN(version, 1));
-   else if (string_is_equal(
-            interface, zxdg_decoration_manager_v1_interface.name))
-      wl->deco_manager = (struct zxdg_decoration_manager_v1*)wl_registry_bind(
+   else if (string_is_equal(interface, zxdg_decoration_manager_v1_interface.name) && found++)
+      wl->deco_manager = (struct zxdg_decoration_manager_v1*)
+         wl_registry_bind(
             reg, id, &zxdg_decoration_manager_v1_interface, MIN(version, 1));
-   else if (string_is_equal(interface, zwp_pointer_constraints_v1_interface.name))
+   else if (string_is_equal(interface, zwp_pointer_constraints_v1_interface.name) && found++)
    {
       wl->pointer_constraints = (struct zwp_pointer_constraints_v1*)
          wl_registry_bind(
             reg, id, &zwp_pointer_constraints_v1_interface, MIN(version, 1));
       wl->locked_pointer = NULL;
    }
-   else if (string_is_equal(interface, zwp_relative_pointer_manager_v1_interface.name))
+   else if (string_is_equal(interface, zwp_relative_pointer_manager_v1_interface.name) && found++)
       wl->relative_pointer_manager = (struct zwp_relative_pointer_manager_v1*)
          wl_registry_bind(
             reg, id, &zwp_relative_pointer_manager_v1_interface, MIN(version, 1));
+   else if (string_is_equal(interface, wp_cursor_shape_manager_v1_interface.name) && found++)
+      wl->cursor_shape_manager = (struct wp_cursor_shape_manager_v1*)
+         wl_registry_bind(
+            reg, id, &wp_cursor_shape_manager_v1_interface, MIN(version, 1));
+   else if (string_is_equal(interface, wp_content_type_manager_v1_interface.name) && found++)
+      wl->content_type_manager = (struct wp_content_type_manager_v1*)
+         wl_registry_bind(
+            reg, id, &wp_content_type_manager_v1_interface, MIN(version, 1));
+   else if (string_is_equal(interface, wp_single_pixel_buffer_manager_v1_interface.name) && found++)
+      wl->single_pixel_manager = (struct wp_single_pixel_buffer_manager_v1*)
+         wl_registry_bind(
+            reg, id, &wp_single_pixel_buffer_manager_v1_interface, MIN(version, 1));
+
+   if (found > 1)
+   RARCH_LOG("[Wayland]: Registered interface %s at version %u\n",
+         interface, version);
 }
 
 static void wl_registry_handle_global_remove(void *data,
@@ -907,7 +950,7 @@ static void wl_data_device_handle_enter(void *data,
 {
    data_offer_ctx *offer_data;
    gfx_ctx_wayland_data_t *wl = (gfx_ctx_wayland_data_t*)data;
-   enum wl_data_device_manager_dnd_action dnd_action = 
+   enum wl_data_device_manager_dnd_action dnd_action =
       WL_DATA_DEVICE_MANAGER_DND_ACTION_NONE;
 
    if (!offer)
@@ -919,11 +962,11 @@ static void wl_data_device_handle_enter(void *data,
    wl_data_offer_accept(offer, serial,
       offer_data->is_file_mime_type ? FILE_MIME : NULL);
 
-   if (     offer_data->is_file_mime_type 
+   if (     offer_data->is_file_mime_type
          && offer_data->supported_actions & DND_ACTION)
       dnd_action = DND_ACTION;
 
-   if (     wl_data_offer_get_version(offer) 
+   if (     wl_data_offer_get_version(offer)
          >= WL_DATA_OFFER_SET_ACTIONS_SINCE_VERSION)
      wl_data_offer_set_actions(offer, dnd_action, dnd_action);
 }
@@ -1108,7 +1151,7 @@ const struct zwp_relative_pointer_v1_listener relative_pointer_listener = {
 };
 
 const struct zwp_locked_pointer_v1_listener locked_pointer_listener = {
-   .locked = locked_pointer_locked,
+   .locked   = locked_pointer_locked,
    .unlocked = locked_pointer_unlocked,
 };
 
