@@ -402,6 +402,15 @@ static void cocoa_input_poll(void *data)
 
       memset(&vp, 0, sizeof(vp));
 
+      video_driver_translate_coord_viewport_confined_wrap(
+            &vp,
+            apple->touches[i].screen_x * backing_scale_factor,
+            apple->touches[i].screen_y * backing_scale_factor,
+            &apple->touches[i].confined_x,
+            &apple->touches[i].confined_y,
+            &apple->touches[i].full_x,
+            &apple->touches[i].full_y);
+
       video_driver_translate_coord_viewport_wrap(
             &vp,
             apple->touches[i].screen_x * backing_scale_factor,
@@ -413,6 +422,69 @@ static void cocoa_input_poll(void *data)
    }
 }
 
+static int16_t cocoa_lightgun_aiming_state(
+      cocoa_input_data_t *apple, unsigned idx, unsigned id)
+{
+   struct video_viewport vp    = {0};
+   int16_t res_x               = 0;
+   int16_t res_y               = 0;
+   int16_t res_screen_x        = 0;
+   int16_t res_screen_y        = 0;
+   
+   int16_t x = apple->window_pos_x;
+   int16_t y = apple->window_pos_y;
+
+#ifndef IOS
+   x *= cocoa_screen_get_backing_scale_factor();
+   y *= cocoa_screen_get_backing_scale_factor();
+#endif
+
+   if (video_driver_translate_coord_viewport_wrap(
+               &vp, x, y,
+               &res_x, &res_y, &res_screen_x, &res_screen_y))
+   {
+      switch (id)
+      {
+         case RETRO_DEVICE_ID_LIGHTGUN_SCREEN_X:
+            return res_x;
+         case RETRO_DEVICE_ID_LIGHTGUN_SCREEN_Y:
+            return res_y;
+         case RETRO_DEVICE_ID_LIGHTGUN_IS_OFFSCREEN:
+            return input_driver_pointer_is_offscreen(res_x, res_y);
+         default:
+            break;
+      }
+   }
+
+   return 0;
+}
+
+static bool cocoa_mouse_button_pressed(
+      cocoa_input_data_t *apple, unsigned port, unsigned key)
+{
+   switch (key)
+   {
+      case RETRO_DEVICE_ID_MOUSE_LEFT:
+         return apple->mouse_buttons & 1;
+      case RETRO_DEVICE_ID_MOUSE_RIGHT:
+         return apple->mouse_buttons & 2;
+      case RETRO_DEVICE_ID_MOUSE_MIDDLE:
+      case RETRO_DEVICE_ID_MOUSE_BUTTON_4:
+      case RETRO_DEVICE_ID_MOUSE_BUTTON_5:
+         return false;
+      case RETRO_DEVICE_ID_MOUSE_WHEELUP:
+         return apple->mouse_wu;
+      case RETRO_DEVICE_ID_MOUSE_WHEELDOWN:
+         return apple->mouse_wd;
+      case RETRO_DEVICE_ID_MOUSE_HORIZ_WHEELUP:
+         return apple->mouse_wl;
+      case RETRO_DEVICE_ID_MOUSE_HORIZ_WHEELDOWN:
+         return apple->mouse_wr;
+   }
+
+   return false;
+}
+
 static int16_t cocoa_input_state(
       void *data,
       const input_device_driver_t *joypad,
@@ -511,7 +583,7 @@ static int16_t cocoa_input_state(
                   }
 #ifdef IOS
 #ifdef HAVE_IOS_TOUCHMOUSE
-                  if (apple->window_pos_x > 0)
+                  if (apple->window_pos_x > 0 || apple->mouse_grabbed)
                   {
                      val = apple->window_pos_x - apple->mouse_x_last;
                      apple->mouse_x_last = apple->window_pos_x;
@@ -537,7 +609,7 @@ static int16_t cocoa_input_state(
                   }
 #ifdef IOS
 #ifdef HAVE_IOS_TOUCHMOUSE
-                  if (apple->window_pos_y > 0)
+                  if (apple->window_pos_y > 0 || apple->mouse_grabbed)
                   {
                      val = apple->window_pos_y - apple->mouse_y_last;
                      apple->mouse_y_last = apple->window_pos_y;
@@ -570,10 +642,6 @@ static int16_t cocoa_input_state(
       case RETRO_DEVICE_POINTER:
       case RARCH_DEVICE_POINTER_SCREEN:
          {
-#ifdef IOS
-            if (!apple->touch_count)
-                return 0;
-#endif
             // with a physical mouse that is hovering, the touch_count will be 0
             // and apple->touches[0] will have the hover position
             if ((idx == 0 || idx < apple->touch_count) && (idx < MAX_TOUCHES))
@@ -592,16 +660,76 @@ static int16_t cocoa_input_state(
                            return (touch->full_x  != -0x8000) && (touch->full_y  != -0x8000); /* Inside? */
                         return    (touch->fixed_x != -0x8000) && (touch->fixed_y != -0x8000); /* Inside? */
                      case RETRO_DEVICE_ID_POINTER_X:
-                        return (device == RARCH_DEVICE_POINTER_SCREEN) ? touch->full_x : touch->fixed_x;
+                        return (device == RARCH_DEVICE_POINTER_SCREEN) ? touch->full_x : touch->confined_x;
                      case RETRO_DEVICE_ID_POINTER_Y:
-                        return (device == RARCH_DEVICE_POINTER_SCREEN) ? touch->full_y : touch->fixed_y;
+                        return (device == RARCH_DEVICE_POINTER_SCREEN) ? touch->full_y : touch->confined_y;
                      case RETRO_DEVICE_ID_POINTER_COUNT:
                         return apple->touch_count;
+                     case RETRO_DEVICE_ID_POINTER_IS_OFFSCREEN:
+                        return input_driver_pointer_is_offscreen(touch->fixed_x, touch->fixed_y);
                   }
                }
             }
          }
          break;
+      case RETRO_DEVICE_LIGHTGUN:
+         switch (id)
+         {
+            /*aiming*/
+            case RETRO_DEVICE_ID_LIGHTGUN_SCREEN_X:
+            case RETRO_DEVICE_ID_LIGHTGUN_SCREEN_Y:
+            case RETRO_DEVICE_ID_LIGHTGUN_IS_OFFSCREEN:
+               return cocoa_lightgun_aiming_state(apple, idx, id);
+            /*buttons*/
+            case RETRO_DEVICE_ID_LIGHTGUN_TRIGGER:
+            case RETRO_DEVICE_ID_LIGHTGUN_RELOAD:
+            case RETRO_DEVICE_ID_LIGHTGUN_AUX_A:
+            case RETRO_DEVICE_ID_LIGHTGUN_AUX_B:
+            case RETRO_DEVICE_ID_LIGHTGUN_AUX_C:
+            case RETRO_DEVICE_ID_LIGHTGUN_START:
+            case RETRO_DEVICE_ID_LIGHTGUN_SELECT:
+            case RETRO_DEVICE_ID_LIGHTGUN_DPAD_UP:
+            case RETRO_DEVICE_ID_LIGHTGUN_DPAD_DOWN:
+            case RETRO_DEVICE_ID_LIGHTGUN_DPAD_LEFT:
+            case RETRO_DEVICE_ID_LIGHTGUN_DPAD_RIGHT:
+            case RETRO_DEVICE_ID_LIGHTGUN_PAUSE:
+               {
+                  unsigned new_id                = input_driver_lightgun_id_convert(id);
+                  const uint64_t bind_joykey     = input_config_binds[port][new_id].joykey;
+                  const uint64_t bind_joyaxis    = input_config_binds[port][new_id].joyaxis;
+                  const uint64_t autobind_joykey = input_autoconf_binds[port][new_id].joykey;
+                  const uint64_t autobind_joyaxis= input_autoconf_binds[port][new_id].joyaxis;
+                  uint16_t joyport               = joypad_info->joy_idx;
+                  float axis_threshold           = joypad_info->axis_threshold;
+                  const uint64_t joykey          = (bind_joykey != NO_BTN) ? bind_joykey  : autobind_joykey;
+                  const uint32_t joyaxis         = (bind_joyaxis != AXIS_NONE) ? bind_joyaxis : autobind_joyaxis;
+                  
+                  if (binds[port][new_id].valid)
+                  {
+                     if ((uint16_t)joykey != NO_BTN && joypad->button(joyport, (uint16_t)joykey))
+                        return 1;
+                     if (joyaxis != AXIS_NONE &&
+                         ((float)abs(joypad->axis(joyport, joyaxis))
+                          / 0x8000) > axis_threshold)
+                        return 1;
+                     else if ((binds[port][new_id].key && binds[port][new_id].key < RETROK_LAST)
+                              && !keyboard_mapping_blocked
+                              && apple_key_state[rarch_keysym_lut[(enum retro_key)binds[port][new_id].key]])
+                        return 1;
+                     else
+                     {
+                        settings_t *settings = config_get_ptr();
+                        if (settings->uints.input_mouse_index[port] == 0)
+                        {
+                           if (cocoa_mouse_button_pressed(apple, port, binds[port][new_id].mbutton))
+                              return 1;
+                        }
+                     }
+                  }
+               }
+               break;
+         }
+         break;
    }
 
    return 0;
@@ -627,6 +755,7 @@ static uint64_t cocoa_input_get_capabilities(void *data)
         (1 << RETRO_DEVICE_JOYPAD)
       | (1 << RETRO_DEVICE_MOUSE)
       | (1 << RETRO_DEVICE_KEYBOARD)
+      | (1 << RETRO_DEVICE_LIGHTGUN)
       | (1 << RETRO_DEVICE_POINTER)
       | (1 << RETRO_DEVICE_ANALOG);
 }
@@ -641,7 +770,7 @@ static bool cocoa_input_set_sensor_state(void *data, unsigned port,
       return false;
 
 #ifdef HAVE_MFI
-   if (@available(iOS 14.0, macOS 11.0, *))
+   if (@available(iOS 14.0, macOS 11.0, tvOS 14.0, *))
    {
       for (GCController *controller in [GCController controllers])
       {
@@ -771,6 +900,16 @@ static void cocoa_input_grab_mouse(void *data, bool state)
    cocoa_show_mouse(nil, !state);
    apple->mouse_grabbed = state;
 }
+#elif TARGET_OS_IOS
+static void cocoa_input_grab_mouse(void *data, bool state)
+{
+   cocoa_input_data_t *apple = (cocoa_input_data_t*)data;
+
+   apple->mouse_grabbed = state;
+
+   if (@available(iOS 14, *))
+      [[CocoaView get] setNeedsUpdateOfPrefersPointerLocked];
+}
 #endif
 
 input_driver_t input_cocoa = {
@@ -782,7 +921,7 @@ input_driver_t input_cocoa = {
    cocoa_input_get_sensor_input,
    cocoa_input_get_capabilities,
    "cocoa",
-#ifdef OSX
+#if defined(OSX) || TARGET_OS_IOS
    cocoa_input_grab_mouse,
 #else
    NULL,                         /* grab_mouse */
