@@ -71,16 +71,17 @@ enum dinput_input_flags
    DINP_FLAG_SHIFT_L           = (1 << 0),
    DINP_FLAG_SHIFT_R           = (1 << 1),
    DINP_FLAG_ALT_L             = (1 << 2),
-   DINP_FLAG_DBCLK_ON_TITLEBAR = (1 << 3),
-   DINP_FLAG_MOUSE_L_BTN       = (1 << 4),
-   DINP_FLAG_MOUSE_R_BTN       = (1 << 5),
-   DINP_FLAG_MOUSE_M_BTN       = (1 << 6),
-   DINP_FLAG_MOUSE_B4_BTN      = (1 << 7),
-   DINP_FLAG_MOUSE_B5_BTN      = (1 << 8),
-   DINP_FLAG_MOUSE_WU_BTN      = (1 << 9),
-   DINP_FLAG_MOUSE_WD_BTN      = (1 << 10),
-   DINP_FLAG_MOUSE_HWU_BTN     = (1 << 11),
-   DINP_FLAG_MOUSE_HWD_BTN     = (1 << 12)
+   DINP_FLAG_ALT_R             = (1 << 3),
+   DINP_FLAG_DBCLK_ON_TITLEBAR = (1 << 4),
+   DINP_FLAG_MOUSE_L_BTN       = (1 << 5),
+   DINP_FLAG_MOUSE_R_BTN       = (1 << 6),
+   DINP_FLAG_MOUSE_M_BTN       = (1 << 7),
+   DINP_FLAG_MOUSE_B4_BTN      = (1 << 8),
+   DINP_FLAG_MOUSE_B5_BTN      = (1 << 9),
+   DINP_FLAG_MOUSE_WU_BTN      = (1 << 10),
+   DINP_FLAG_MOUSE_WD_BTN      = (1 << 11),
+   DINP_FLAG_MOUSE_HWU_BTN     = (1 << 12),
+   DINP_FLAG_MOUSE_HWD_BTN     = (1 << 13)
 };
 
 struct dinput_input
@@ -199,62 +200,24 @@ static void *dinput_init(const char *joypad_driver)
    return di;
 }
 
-static void dinput_keyboard_mods(struct dinput_input *di, int mod)
+static uint16_t dinput_get_active_keyboard_mods()
 {
-   switch (mod)
-   {
-      case RETROKMOD_SHIFT:
-         {
-            unsigned vk_shift_l = GetAsyncKeyState(VK_LSHIFT) >> 1;
-            unsigned vk_shift_r = GetAsyncKeyState(VK_RSHIFT) >> 1;
-
-            if (   ( vk_shift_l && (!(di->flags & DINP_FLAG_SHIFT_L)))
-                || (!vk_shift_l &&   (di->flags & DINP_FLAG_SHIFT_L)))
-            {
-               input_keyboard_event(vk_shift_l, RETROK_LSHIFT,
-                     0, RETROKMOD_SHIFT, RETRO_DEVICE_KEYBOARD);
-               if (di->flags & DINP_FLAG_SHIFT_L)
-                  di->flags &= ~DINP_FLAG_SHIFT_L;
-               else
-                  di->flags |=  DINP_FLAG_SHIFT_L;
-            }
-
-            if (   ( vk_shift_r && (!(di->flags & DINP_FLAG_SHIFT_R)))
-                || (!vk_shift_r &&   (di->flags & DINP_FLAG_SHIFT_R)))
-            {
-               input_keyboard_event(vk_shift_r, RETROK_RSHIFT,
-                     0, RETROKMOD_SHIFT, RETRO_DEVICE_KEYBOARD);
-               if (di->flags & DINP_FLAG_SHIFT_R)
-                  di->flags &= ~DINP_FLAG_SHIFT_R;
-               else
-                  di->flags |=  DINP_FLAG_SHIFT_R;
-            }
-         }
-         break;
-
-      case RETROKMOD_ALT:
-         {
-            unsigned vk_alt_l = GetAsyncKeyState(VK_LMENU) >> 1;
-
-            if (vk_alt_l && (!(di->flags & DINP_FLAG_ALT_L)))
-            {
-               if (di->flags & DINP_FLAG_ALT_L)
-                  di->flags &= ~DINP_FLAG_ALT_L;
-               else
-                  di->flags |=  DINP_FLAG_ALT_L;
-            }
-            else if (!vk_alt_l && (di->flags & DINP_FLAG_ALT_L))
-            {
-               input_keyboard_event(vk_alt_l, RETROK_LALT,
-                     0, RETROKMOD_ALT, RETRO_DEVICE_KEYBOARD);
-               if (di->flags & DINP_FLAG_ALT_L)
-                  di->flags &= ~DINP_FLAG_ALT_L;
-               else
-                  di->flags |=  DINP_FLAG_ALT_L;
-            }
-         }
-         break;
-   }
+   uint16_t mod = 0;
+   if (GetKeyState(VK_SHIFT)   & 0x80)
+      mod |= RETROKMOD_SHIFT;
+   if (GetKeyState(VK_CONTROL) & 0x80)
+      mod |= RETROKMOD_CTRL;
+   if (GetKeyState(VK_MENU)    & 0x80)
+      mod |= RETROKMOD_ALT;
+   if (GetKeyState(VK_CAPITAL) & 0x81)
+      mod |= RETROKMOD_CAPSLOCK;
+   if (GetKeyState(VK_SCROLL)  & 0x81)
+      mod |= RETROKMOD_SCROLLOCK;
+   if (GetKeyState(VK_NUMLOCK) & 0x81)
+      mod |= RETROKMOD_NUMLOCK;
+   if ((GetKeyState(VK_LWIN) | GetKeyState(VK_RWIN)) & 0x80)
+      mod |= RETROKMOD_META;
+   return mod;
 }
 
 static void dinput_poll(void *data)
@@ -289,15 +252,39 @@ static void dinput_poll(void *data)
       }
       else
       {
-         /* Shifts only when window focused */
-         dinput_keyboard_mods(di, RETROKMOD_SHIFT);
-
          /* Ignore 'unknown/undefined' key */
          di->state[RETROK_UNKNOWN] = 0;
       }
 
-      /* Left alt keyup when unfocused, to prevent alt-tab sticky */
-      dinput_keyboard_mods(di, RETROKMOD_ALT);
+      /* If both shift keys are pressed simultaneously, the OS will not issue
+       * a WM_KEYUP for the first one. That up event will be issued here. */
+      if ((di->flags & DINP_FLAG_SHIFT_L) && !(GetAsyncKeyState(VK_LSHIFT) >> 1))
+      {
+         input_keyboard_event(false, RETROK_LSHIFT, 0,
+               dinput_get_active_keyboard_mods(), RETRO_DEVICE_KEYBOARD);
+         di->flags &= ~DINP_FLAG_SHIFT_L;
+      }
+      if ((di->flags & DINP_FLAG_SHIFT_R) && !(GetAsyncKeyState(VK_RSHIFT) >> 1))
+      {
+         input_keyboard_event(false, RETROK_RSHIFT, 0,
+               dinput_get_active_keyboard_mods(), RETRO_DEVICE_KEYBOARD);
+         di->flags &= ~DINP_FLAG_SHIFT_R;
+      }
+
+      /* When using alt-tab, the alt key won't get a WM_KEYUP message from the
+       * OS. Instead we issue it here when ALT isn't pressed down anymore. */
+      if ((di->flags & DINP_FLAG_ALT_L) && !(GetAsyncKeyState(VK_LMENU) >> 1))
+      {
+         input_keyboard_event(false, RETROK_LALT, 0,
+               dinput_get_active_keyboard_mods(), RETRO_DEVICE_KEYBOARD);
+         di->flags &= ~DINP_FLAG_ALT_L;
+      }
+      if ((di->flags & DINP_FLAG_ALT_R) && !(GetAsyncKeyState(VK_RMENU) >> 1))
+      {
+         input_keyboard_event(false, RETROK_RALT, 0,
+               dinput_get_active_keyboard_mods(), RETRO_DEVICE_KEYBOARD);
+         di->flags &= ~DINP_FLAG_ALT_R;
+      }
    }
 
    if (di->mouse)
@@ -445,8 +432,7 @@ static bool dinput_mouse_button_pressed(
 static int16_t dinput_lightgun_aiming_state(
       struct dinput_input *di, unsigned idx, unsigned id)
 {
-   struct video_viewport vp;
-   const int edge_detect       = 32700;
+   struct video_viewport vp    = {0};
    int16_t res_x               = 0;
    int16_t res_y               = 0;
    int16_t res_screen_x        = 0;
@@ -459,13 +445,6 @@ static int16_t dinput_lightgun_aiming_state(
    struct dinput_pointer_status
       *check_pos               = di->pointer_head.next;
 
-   vp.x                        = 0;
-   vp.y                        = 0;
-   vp.width                    = 0;
-   vp.height                   = 0;
-   vp.full_width               = 0;
-   vp.full_height              = 0;
-
    while (check_pos && num < idx)
    {
       num++;
@@ -488,24 +467,14 @@ static int16_t dinput_lightgun_aiming_state(
                &vp, x, y,
                &res_x, &res_y, &res_screen_x, &res_screen_y))
    {
-      bool inside =
-            (res_x >= -edge_detect)
-         && (res_y >= -edge_detect)
-         && (res_x <=  edge_detect)
-         && (res_y <=  edge_detect);
-
       switch (id)
       {
          case RETRO_DEVICE_ID_LIGHTGUN_SCREEN_X:
-            if (inside)
-               return res_x;
-            break;
+            return res_x;
          case RETRO_DEVICE_ID_LIGHTGUN_SCREEN_Y:
-            if (inside)
-               return res_y;
-            break;
+            return res_y;
          case RETRO_DEVICE_ID_LIGHTGUN_IS_OFFSCREEN:
-            return !inside;
+            return input_driver_pointer_is_offscreen(res_x, res_y);
          default:
             break;
       }
@@ -514,41 +483,6 @@ static int16_t dinput_lightgun_aiming_state(
    return 0;
 }
 
-static unsigned dinput_retro_id_to_rarch(unsigned id)
-{
-   switch (id)
-   {
-      case RETRO_DEVICE_ID_LIGHTGUN_DPAD_RIGHT:
-         return RARCH_LIGHTGUN_DPAD_RIGHT;
-      case RETRO_DEVICE_ID_LIGHTGUN_DPAD_LEFT:
-         return RARCH_LIGHTGUN_DPAD_LEFT;
-      case RETRO_DEVICE_ID_LIGHTGUN_DPAD_UP:
-         return RARCH_LIGHTGUN_DPAD_UP;
-      case RETRO_DEVICE_ID_LIGHTGUN_DPAD_DOWN:
-         return RARCH_LIGHTGUN_DPAD_DOWN;
-      case RETRO_DEVICE_ID_LIGHTGUN_SELECT:
-         return RARCH_LIGHTGUN_SELECT;
-      case RETRO_DEVICE_ID_LIGHTGUN_PAUSE:
-         return RARCH_LIGHTGUN_START;
-      case RETRO_DEVICE_ID_LIGHTGUN_RELOAD:
-         return RARCH_LIGHTGUN_RELOAD;
-      case RETRO_DEVICE_ID_LIGHTGUN_TRIGGER:
-         return RARCH_LIGHTGUN_TRIGGER;
-      case RETRO_DEVICE_ID_LIGHTGUN_AUX_A:
-         return RARCH_LIGHTGUN_AUX_A;
-      case RETRO_DEVICE_ID_LIGHTGUN_AUX_B:
-         return RARCH_LIGHTGUN_AUX_B;
-      case RETRO_DEVICE_ID_LIGHTGUN_AUX_C:
-         return RARCH_LIGHTGUN_AUX_C;
-      case RETRO_DEVICE_ID_LIGHTGUN_START:
-         return RARCH_LIGHTGUN_START;
-      default:
-         break;
-   }
-
-   return 0;
-}
-
 static int16_t dinput_input_state(
       void *data,
       const input_device_driver_t *joypad,
@@ -730,8 +664,7 @@ static int16_t dinput_input_state(
          case RETRO_DEVICE_POINTER:
          case RARCH_DEVICE_POINTER_SCREEN:
             {
-               struct video_viewport vp;
-               bool inside                 = false;
+               struct video_viewport vp    = {0};
                int x                       = 0;
                int y                       = 0;
                int16_t res_x               = 0;
@@ -742,13 +675,6 @@ static int16_t dinput_input_state(
                struct dinput_pointer_status *
                   check_pos                = di->pointer_head.next;
 
-               vp.x                        = 0;
-               vp.y                        = 0;
-               vp.width                    = 0;
-               vp.height                   = 0;
-               vp.full_width               = 0;
-               vp.full_height              = 0;
-
                while (check_pos && num < idx)
                {
                   num++;
@@ -766,7 +692,7 @@ static int16_t dinput_input_state(
                   y            = check_pos->pointer_y;
                }
 
-               if (video_driver_translate_coord_viewport_wrap(&vp, x, y,
+               if (video_driver_translate_coord_viewport_confined_wrap(&vp, x, y,
                            &res_x, &res_y, &res_screen_x, &res_screen_y))
                {
                   if (device == RARCH_DEVICE_POINTER_SCREEN)
@@ -775,19 +701,18 @@ static int16_t dinput_input_state(
                      res_y        = res_screen_y;
                   }
 
-                  if ((inside = (res_x >= -0x7fff) && (res_y >= -0x7fff)))
+                  switch (id)
                   {
-                     switch (id)
-                     {
-                        case RETRO_DEVICE_ID_POINTER_X:
-                           return res_x;
-                        case RETRO_DEVICE_ID_POINTER_Y:
-                           return res_y;
-                        case RETRO_DEVICE_ID_POINTER_PRESSED:
-                           return check_pos ? 1 : (di->flags & DINP_FLAG_MOUSE_L_BTN);
-                        default:
-                           break;
-                     }
+                     case RETRO_DEVICE_ID_POINTER_X:
+                        return res_x;
+                     case RETRO_DEVICE_ID_POINTER_Y:
+                        return res_y;
+                     case RETRO_DEVICE_ID_POINTER_PRESSED:
+                        return check_pos ? 1 : (di->flags & DINP_FLAG_MOUSE_L_BTN) > 0;
+                     case RETRO_DEVICE_ID_POINTER_IS_OFFSCREEN:
+                        return input_driver_pointer_is_offscreen(res_x, res_y);
+                     default:
+                        break;
                   }
                }
             }
@@ -815,7 +740,7 @@ static int16_t dinput_input_state(
                case RETRO_DEVICE_ID_LIGHTGUN_DPAD_RIGHT:
                case RETRO_DEVICE_ID_LIGHTGUN_PAUSE:
                   {
-                     unsigned new_id                = dinput_retro_id_to_rarch(id);
+                     unsigned new_id                = input_driver_lightgun_id_convert(id);
                      const uint64_t bind_joykey     = input_config_binds[port][new_id].joykey;
                      const uint64_t bind_joyaxis    = input_config_binds[port][new_id].joyaxis;
                      const uint64_t autobind_joykey = input_autoconf_binds[port][new_id].joykey;
@@ -1026,6 +951,35 @@ bool dinput_handle_message(void *data,
          if (((short) HIWORD(wParam))/120 < 0)
             di->flags |= DINP_FLAG_MOUSE_HWD_BTN;
          break;
+      case WM_KEYUP:                /* Key released */
+      case WM_SYSKEYUP:             /* Key released */
+      case WM_KEYDOWN:              /* Key pressed  */
+      case WM_SYSKEYDOWN:           /* Key pressed  */
+         {
+            unsigned keysym       = (lParam >> 16) & 0xff;
+            bool extended         = (lParam >> 24) & 0x1;
+            uint16_t flag         = 0;
+
+            /* extended keys will map to dinput if the high bit is set */
+            if (extended)
+               keysym |= 0x80;
+
+            switch (keysym)
+            {
+               case DIK_LSHIFT: flag = DINP_FLAG_SHIFT_L; break;
+               case DIK_RSHIFT: flag = DINP_FLAG_SHIFT_R; break;
+               case DIK_LMENU:  flag = DINP_FLAG_ALT_L;   break;
+               case DIK_RMENU:  flag = DINP_FLAG_ALT_R;   break;
+            }
+
+            if (message == WM_KEYDOWN || message == WM_SYSKEYDOWN)
+               di->flags |= flag;
+            else if (di->flags & flag)
+               di->flags &= ~flag;
+            else if (flag) /* key up already issued or down never happened */
+               return true;
+         }
+         break;
    }
 
    return false;
