@@ -46,19 +46,22 @@ extern "C" {
 #include "../../retroarch.h"
 #include "../../verbosity.h"
 
-typedef struct
+enum winraw_mouse_flags
 {
-   uint8_t keys[SC_LAST];
-   bool pause;
-} winraw_keyboard_t;
+   WRAW_MOUSE_FLG_BTN_L  = (1 << 0),
+   WRAW_MOUSE_FLG_BTN_M  = (1 << 1),
+   WRAW_MOUSE_FLG_BTN_R  = (1 << 2),
+   WRAW_MOUSE_FLG_BTN_B4 = (1 << 3),
+   WRAW_MOUSE_FLG_BTN_B5 = (1 << 4)
+};
 
 typedef struct
 {
    HANDLE hnd;
    LONG x, y, dlt_x, dlt_y;
    LONG whl_u, whl_d;
-   bool btn_l, btn_m, btn_r, btn_b4, btn_b5;
    int device;
+   uint8_t flags;
 } winraw_mouse_t;
 
 struct winraw_pointer_status
@@ -69,6 +72,13 @@ struct winraw_pointer_status
    int pointer_y;
 };
 
+enum winraw_input_flags
+{
+   WRAW_INP_FLG_MOUSE_GRAB             = (1 << 0),
+   WRAW_INP_FLG_MOUSE_XY_MAPPING_READY = (1 << 1),
+   WRAW_INP_FLG_KB_PAUSE               = (1 << 2)
+};
+
 typedef struct
 {
    double view_abs_ratio_x;
@@ -81,31 +91,27 @@ typedef struct
    int rect_delay;   /* Needed to delay resize of window */
    winraw_mouse_t *mice;
    unsigned mouse_cnt;
-   winraw_keyboard_t keyboard;
-   bool mouse_xy_mapping_ready;
-   bool mouse_grab;
+   uint8_t kb_keys[SC_LAST];
+   uint8_t flags;
 } winraw_input_t;
 
 /* TODO/FIXME - static globals */
 static winraw_mouse_t *g_mice        = NULL;
 static bool winraw_focus             = false;
 
-#define WINRAW_KEYBOARD_PRESSED(wr, key) (wr->keyboard.keys[rarch_keysym_lut[(enum retro_key)(key)]])
+#define WINRAW_KEYBOARD_PRESSED(wr, key) (wr->kb_keys[rarch_keysym_lut[(enum retro_key)(key)]])
 
 static HWND winraw_create_window(WNDPROC wnd_proc)
 {
    HWND wnd;
    WNDCLASSA wc     = {0};
-
    if (!(wc.hInstance = GetModuleHandleA(NULL)))
       return NULL;
-
    wc.lpfnWndProc   = wnd_proc;
    wc.lpszClassName = "winraw-input";
    if (     !RegisterClassA(&wc)
          &&  GetLastError() != ERROR_CLASS_ALREADY_EXISTS)
       return NULL;
-
    if (!(wnd = CreateWindowExA(0, wc.lpszClassName,
                NULL, 0, 0, 0, 0, 0,
                HWND_MESSAGE, NULL, NULL, NULL)))
@@ -113,42 +119,13 @@ static HWND winraw_create_window(WNDPROC wnd_proc)
       UnregisterClassA(wc.lpszClassName, NULL);
       return NULL;
    }
-
    return wnd;
 }
 
-static void winraw_destroy_window(HWND wnd)
-{
-   if (!wnd)
-      return;
-
-   DestroyWindow(wnd);
-   UnregisterClassA("winraw-input", NULL);
-}
-
-static BOOL winraw_set_keyboard_input(HWND window)
-{
-   RAWINPUTDEVICE rid;
-   settings_t *settings;
-
-   settings        = config_get_ptr();
-
-   rid.dwFlags     = window ? 0 : RIDEV_REMOVE;
-   rid.hwndTarget  = window;
-   rid.usUsagePage = 0x01; /* Generic desktop */
-   rid.usUsage     = 0x06; /* Keyboard */
-   if (settings->bools.input_nowinkey_enable)
-      rid.dwFlags |= RIDEV_NOHOTKEYS; /* Disable win keys while focused */
-
-   return RegisterRawInputDevices(&rid, 1, sizeof(RAWINPUTDEVICE));
-}
-
 static void winraw_log_mice_info(winraw_mouse_t *mice, unsigned mouse_cnt)
 {
    unsigned i;
    char name[256];
-   char prod_name[128];
-   wchar_t prod_buf[128];
    UINT name_size = sizeof(name);
 
    name[0]        = '\0';
@@ -158,10 +135,8 @@ static void winraw_log_mice_info(winraw_mouse_t *mice, unsigned mouse_cnt)
       UINT r = GetRawInputDeviceInfoA(mice[i].hnd, RIDI_DEVICENAME,
             name, &name_size);
       if (r == (UINT)-1 || r == 0)
-         name[0] = '\0';
+         name[0]   = '\0';
 
-      prod_name[0] = '\0';
-      prod_buf[0]  = '\0';
       if (name[0])
       {
          HANDLE hhid = CreateFile(name,
@@ -170,13 +145,13 @@ static void winraw_log_mice_info(winraw_mouse_t *mice, unsigned mouse_cnt)
 
          if (hhid != INVALID_HANDLE_VALUE)
          {
-            if (HidD_GetProductString (hhid, prod_buf, sizeof(prod_buf)))
-               wcstombs(prod_name, prod_buf, sizeof(prod_name));
+            wchar_t prod_buf[128];
+            prod_buf[0]  = '\0';
+            if (HidD_GetProductString(hhid, prod_buf, sizeof(prod_buf)))
+               wcstombs(name, prod_buf, sizeof(name));
          }
          CloseHandle(hhid);
       }
-      if (prod_name[0])
-         strlcpy(name, prod_name, sizeof(name));
 
       if (!name[0])
          strlcpy(name, "<name not found>", sizeof(name));
@@ -251,61 +226,31 @@ error:
    return false;
 }
 
-static BOOL winraw_set_mouse_input(HWND window)
-{
-   RAWINPUTDEVICE rid;
-
-   rid.dwFlags     = (window) ? 0 : RIDEV_REMOVE;
-   rid.hwndTarget  = window;
-   rid.usUsagePage = 0x01; /* generic desktop */
-   rid.usUsage     = 0x02; /* mouse */
-
-   return RegisterRawInputDevices(&rid, 1, sizeof(RAWINPUTDEVICE));
-}
-
 static int16_t winraw_lightgun_aiming_state(winraw_input_t *wr,
       winraw_mouse_t *mouse,
       unsigned port, unsigned id)
 {
-   struct video_viewport vp;
-   const int edge_detect = 32700;
-   bool inside           = false;
+   struct video_viewport vp = {0};
    int16_t res_x         = 0;
    int16_t res_y         = 0;
    int16_t res_screen_x  = 0;
    int16_t res_screen_y  = 0;
 
-   vp.x                  = 0;
-   vp.y                  = 0;
-   vp.width              = 0;
-   vp.height             = 0;
-   vp.full_width         = 0;
-   vp.full_height        = 0;
-
-   if (!(video_driver_translate_coord_viewport_wrap(
+   if ((video_driver_translate_coord_viewport_wrap(
                &vp, mouse->x, mouse->y,
                &res_x, &res_y, &res_screen_x, &res_screen_y)))
-      return 0;
-
-   inside =    (res_x >= -edge_detect)
-            && (res_y >= -edge_detect)
-            && (res_x <=  edge_detect)
-            && (res_y <=  edge_detect);
-
-   switch (id)
    {
-      case RETRO_DEVICE_ID_LIGHTGUN_SCREEN_X:
-         if (inside)
+      switch (id)
+      {
+         case RETRO_DEVICE_ID_LIGHTGUN_SCREEN_X:
             return res_x;
-         break;
-      case RETRO_DEVICE_ID_LIGHTGUN_SCREEN_Y:
-         if (inside)
+         case RETRO_DEVICE_ID_LIGHTGUN_SCREEN_Y:
             return res_y;
-         break;
-      case RETRO_DEVICE_ID_LIGHTGUN_IS_OFFSCREEN:
-         return !inside;
-      default:
-         break;
+         case RETRO_DEVICE_ID_LIGHTGUN_IS_OFFSCREEN:
+            return input_driver_pointer_is_offscreen(res_x, res_y);
+         default:
+            break;
+      }
    }
 
    return 0;
@@ -319,15 +264,15 @@ static bool winraw_mouse_button_pressed(
    switch (key)
    {
       case RETRO_DEVICE_ID_MOUSE_LEFT:
-         return mouse->btn_l;
+         return ((mouse->flags & WRAW_MOUSE_FLG_BTN_L) > 0);
       case RETRO_DEVICE_ID_MOUSE_RIGHT:
-         return mouse->btn_r;
+         return ((mouse->flags & WRAW_MOUSE_FLG_BTN_R) > 0);
       case RETRO_DEVICE_ID_MOUSE_MIDDLE:
-         return mouse->btn_m;
+         return ((mouse->flags & WRAW_MOUSE_FLG_BTN_M) > 0);
       case RETRO_DEVICE_ID_MOUSE_BUTTON_4:
-         return mouse->btn_b4;
+         return ((mouse->flags & WRAW_MOUSE_FLG_BTN_B4) > 0);
       case RETRO_DEVICE_ID_MOUSE_BUTTON_5:
-         return mouse->btn_b5;
+         return ((mouse->flags & WRAW_MOUSE_FLG_BTN_B5) > 0);
       case RETRO_DEVICE_ID_MOUSE_WHEELUP:
          return mouse->whl_u;
       case RETRO_DEVICE_ID_MOUSE_WHEELDOWN:
@@ -356,7 +301,7 @@ static void winraw_init_mouse_xy_mapping(winraw_input_t *wr)
       wr->view_abs_ratio_x       = (double)viewport.full_width  / 65535.0f;
       wr->view_abs_ratio_y       = (double)viewport.full_height / 65535.0f;
 
-      wr->mouse_xy_mapping_ready = true;
+      wr->flags                 |= WRAW_INP_FLG_MOUSE_XY_MAPPING_READY;
    }
 }
 
@@ -388,7 +333,7 @@ static void winraw_update_mouse_state(winraw_input_t *wr,
 
    if (state->usFlags & MOUSE_MOVE_ABSOLUTE)
    {
-      if (wr->mouse_xy_mapping_ready)
+      if ((wr->flags & WRAW_INP_FLG_MOUSE_XY_MAPPING_READY) > 0)
       {
          state->lLastX = (LONG)(wr->view_abs_ratio_x * state->lLastX);
          state->lLastY = (LONG)(wr->view_abs_ratio_y * state->lLastY);
@@ -465,42 +410,42 @@ static void winraw_update_mouse_state(winraw_input_t *wr,
    if (swap_mouse_buttons)
    {
       if (state->usButtonFlags & RI_MOUSE_LEFT_BUTTON_DOWN)
-         mouse->btn_r = true;
+         mouse->flags |=  (WRAW_MOUSE_FLG_BTN_R);
       else if (state->usButtonFlags & RI_MOUSE_LEFT_BUTTON_UP)
-         mouse->btn_r = false;
+         mouse->flags &= ~(WRAW_MOUSE_FLG_BTN_R);
 
       if (state->usButtonFlags & RI_MOUSE_RIGHT_BUTTON_DOWN)
-         mouse->btn_l = true;
+         mouse->flags |=  (WRAW_MOUSE_FLG_BTN_L);
       else if (state->usButtonFlags & RI_MOUSE_RIGHT_BUTTON_UP)
-         mouse->btn_l = false;
+         mouse->flags &= ~(WRAW_MOUSE_FLG_BTN_L);
    }
    else
    {
       if (state->usButtonFlags & RI_MOUSE_LEFT_BUTTON_DOWN)
-         mouse->btn_l = true;
+         mouse->flags |=  (WRAW_MOUSE_FLG_BTN_L);
       else if (state->usButtonFlags & RI_MOUSE_LEFT_BUTTON_UP)
-         mouse->btn_l = false;
+         mouse->flags &= ~(WRAW_MOUSE_FLG_BTN_L);
 
       if (state->usButtonFlags & RI_MOUSE_RIGHT_BUTTON_DOWN)
-         mouse->btn_r = true;
+         mouse->flags |=  (WRAW_MOUSE_FLG_BTN_R);
       else if (state->usButtonFlags & RI_MOUSE_RIGHT_BUTTON_UP)
-         mouse->btn_r = false;
+         mouse->flags &= ~(WRAW_MOUSE_FLG_BTN_R);
    }
 
    if (state->usButtonFlags & RI_MOUSE_MIDDLE_BUTTON_DOWN)
-      mouse->btn_m = true;
+      mouse->flags |=  (WRAW_MOUSE_FLG_BTN_M);
    else if (state->usButtonFlags & RI_MOUSE_MIDDLE_BUTTON_UP)
-      mouse->btn_m = false;
+      mouse->flags &= ~(WRAW_MOUSE_FLG_BTN_M);
 
    if (state->usButtonFlags & RI_MOUSE_BUTTON_4_DOWN)
-      mouse->btn_b4 = true;
+      mouse->flags |=  (WRAW_MOUSE_FLG_BTN_B4);
    else if (state->usButtonFlags & RI_MOUSE_BUTTON_4_UP)
-      mouse->btn_b4 = false;
+      mouse->flags &= ~(WRAW_MOUSE_FLG_BTN_B4);
 
    if (state->usButtonFlags & RI_MOUSE_BUTTON_5_DOWN)
-      mouse->btn_b5 = true;
+      mouse->flags |=  (WRAW_MOUSE_FLG_BTN_B5);
    else if (state->usButtonFlags & RI_MOUSE_BUTTON_5_UP)
-      mouse->btn_b5 = false;
+      mouse->flags &= ~(WRAW_MOUSE_FLG_BTN_B5);
 
    if (state->usButtonFlags & RI_MOUSE_WHEEL)
    {
@@ -514,92 +459,92 @@ static void winraw_update_mouse_state(winraw_input_t *wr,
 static LRESULT CALLBACK winraw_callback(
       HWND wnd, UINT msg, WPARAM wpar, LPARAM lpar)
 {
-   unsigned i;
-   unsigned mcode, flags, down, mod;
    static uint8_t data[1024];
    RAWINPUT       *ri = (RAWINPUT*)data;
    UINT size          = sizeof(data);
-   winraw_input_t *wr = (winraw_input_t*)(LONG_PTR)
-      GetWindowLongPtr(wnd, GWLP_USERDATA);
 
    if (msg != WM_INPUT)
       return DefWindowProcA(wnd, msg, wpar, lpar);
 
-   if (
+   if (!(
           GET_RAWINPUT_CODE_WPARAM(wpar) != RIM_INPUT  /* app is in the background */
        || GetRawInputData((HRAWINPUT)lpar, RID_INPUT,
-         data, &size, sizeof(RAWINPUTHEADER)) == (UINT)-1)
+         data, &size, sizeof(RAWINPUTHEADER)) == (UINT)-1))
    {
-      DefWindowProcA(wnd, msg, wpar, lpar);
-      return 0;
-   }
+      unsigned i;
+      unsigned mcode, flags, down, mod;
+      winraw_input_t *wr = (winraw_input_t*)(LONG_PTR)
+         GetWindowLongPtr(wnd, GWLP_USERDATA);
 
-   switch (ri->header.dwType)
-   {
-      case RIM_TYPEKEYBOARD:
-         mcode = ri->data.keyboard.MakeCode;
-         flags = ri->data.keyboard.Flags;
-         down  = (flags & RI_KEY_BREAK) ? 0 : 1;
-         mod   = 0;
+      switch (ri->header.dwType)
+      {
+         case RIM_TYPEKEYBOARD:
+            mcode = ri->data.keyboard.MakeCode;
+            flags = ri->data.keyboard.Flags;
+            down  = (flags & RI_KEY_BREAK) ? 0 : 1;
+            mod   = 0;
 
-         /* Extended scancodes */
-         if (flags & RI_KEY_E0)
-            mcode |= 0xE000;
-         else if (flags & RI_KEY_E1)
-            mcode |= 0xE100;
+            /* Extended scancodes */
+            if (flags & RI_KEY_E0)
+               mcode |= 0xE000;
+            else if (flags & RI_KEY_E1)
+               mcode |= 0xE100;
 
-         /* Special pause-key handling due to
-          * scancode 0xE11D45 incoming separately */
-         if (wr->keyboard.pause)
-         {
-            wr->keyboard.pause = false;
-            if (mcode == SC_NUMLOCK)
-               mcode = SC_PAUSE;
-         }
-         else if (mcode == 0xE11D)
-            wr->keyboard.pause = true;
-
-         /* Ignored scancodes */
-         switch (mcode)
-         {
-            case RETROK_UNKNOWN:
-            case 0xE11D:
-            case 0xE02A:
-            case 0xE036:
-            case 0xE0AA:
-            case 0xE0B6:
-               return 0;
-         }
-
-         if (GetKeyState(VK_SHIFT)   & 0x80)
-            mod |= RETROKMOD_SHIFT;
-         if (GetKeyState(VK_CONTROL) & 0x80)
-            mod |= RETROKMOD_CTRL;
-         if (GetKeyState(VK_MENU)    & 0x80)
-            mod |= RETROKMOD_ALT;
-         if (GetKeyState(VK_CAPITAL) & 0x81)
-            mod |= RETROKMOD_CAPSLOCK;
-         if (GetKeyState(VK_SCROLL)  & 0x81)
-            mod |= RETROKMOD_SCROLLOCK;
-         if ((GetKeyState(VK_LWIN) | GetKeyState(VK_RWIN)) & 0x80)
-            mod |= RETROKMOD_META;
-
-         wr->keyboard.keys[mcode] = down;
-         input_keyboard_event(down,
-               input_keymaps_translate_keysym_to_rk(mcode),
-               0, mod, RETRO_DEVICE_KEYBOARD);
-         break;
-      case RIM_TYPEMOUSE:
-         for (i = 0; i < wr->mouse_cnt; ++i)
-         {
-            if (g_mice[i].hnd == ri->header.hDevice)
+            /* Special pause-key handling due to
+             * scancode 0xE11D45 incoming separately */
+            if ((wr->flags & WRAW_INP_FLG_KB_PAUSE) > 0)
             {
-               winraw_update_mouse_state(wr,
-                     &g_mice[i], &ri->data.mouse);
-               break;
+               wr->flags &= ~(WRAW_INP_FLG_KB_PAUSE);
+               if (mcode == SC_NUMLOCK)
+                  mcode = SC_PAUSE;
             }
-         }
-         break;
+            else if (mcode == 0xE11D)
+               wr->flags |=  (WRAW_INP_FLG_KB_PAUSE);
+
+            /* Ignored scancodes */
+            switch (mcode)
+            {
+               case RETROK_UNKNOWN:
+               case 0xE11D:
+               case 0xE02A:
+               case 0xE036:
+               case 0xE0AA:
+               case 0xE0B6:
+                  return 0;
+            }
+
+            if (GetKeyState(VK_SHIFT)   & 0x80)
+               mod |= RETROKMOD_SHIFT;
+            if (GetKeyState(VK_CONTROL) & 0x80)
+               mod |= RETROKMOD_CTRL;
+            if (GetKeyState(VK_MENU)    & 0x80)
+               mod |= RETROKMOD_ALT;
+            if (GetKeyState(VK_CAPITAL) & 0x81)
+               mod |= RETROKMOD_CAPSLOCK;
+            if (GetKeyState(VK_SCROLL)  & 0x81)
+               mod |= RETROKMOD_SCROLLOCK;
+            if (GetKeyState(VK_NUMLOCK) & 0x81)
+               mod |= RETROKMOD_NUMLOCK;
+            if ((GetKeyState(VK_LWIN) | GetKeyState(VK_RWIN)) & 0x80)
+               mod |= RETROKMOD_META;
+
+            wr->kb_keys[mcode] = down;
+            input_keyboard_event(down,
+                  input_keymaps_translate_keysym_to_rk(mcode),
+                  0, mod, RETRO_DEVICE_KEYBOARD);
+            break;
+         case RIM_TYPEMOUSE:
+            for (i = 0; i < wr->mouse_cnt; ++i)
+            {
+               if (g_mice[i].hnd == ri->header.hDevice)
+               {
+                  winraw_update_mouse_state(wr,
+                        &g_mice[i], &ri->data.mouse);
+                  break;
+               }
+            }
+            break;
+      }
    }
 
    DefWindowProcA(wnd, msg, wpar, lpar);
@@ -608,7 +553,9 @@ static LRESULT CALLBACK winraw_callback(
 
 static void *winraw_init(const char *joypad_driver)
 {
-   winraw_input_t *wr = (winraw_input_t *)
+   RAWINPUTDEVICE rid;
+   settings_t *settings = config_get_ptr();
+   winraw_input_t *wr   = (winraw_input_t *)
       calloc(1, sizeof(winraw_input_t));
 
    if (!wr)
@@ -630,10 +577,22 @@ static void *winraw_init(const char *joypad_driver)
       memcpy(wr->mice, g_mice, wr->mouse_cnt * sizeof(winraw_mouse_t));
    }
 
-   if (!winraw_set_keyboard_input(wr->window))
+   rid.dwFlags     = (wr->window) ? 0 : RIDEV_REMOVE;
+   rid.hwndTarget  = wr->window;
+   rid.usUsagePage = 0x01; /* Generic desktop */
+   rid.usUsage     = 0x06; /* Keyboard */
+   if (settings->bools.input_nowinkey_enable)
+      rid.dwFlags |= RIDEV_NOHOTKEYS; /* Disable win keys while focused */
+
+   if (!RegisterRawInputDevices(&rid, 1, sizeof(RAWINPUTDEVICE)))
       goto error;
 
-   if (!winraw_set_mouse_input(wr->window))
+   rid.dwFlags     = wr->window ? 0 : RIDEV_REMOVE;
+   rid.hwndTarget  = wr->window;
+   rid.usUsagePage = 0x01; /* generic desktop */
+   rid.usUsage     = 0x02; /* mouse */
+
+   if (!RegisterRawInputDevices(&rid, 1, sizeof(RAWINPUTDEVICE)))
       goto error;
 
    SetWindowLongPtr(wr->window, GWLP_USERDATA, (LONG_PTR)wr);
@@ -643,9 +602,23 @@ static void *winraw_init(const char *joypad_driver)
 error:
    if (wr && wr->window)
    {
-      winraw_set_mouse_input(NULL);
-      winraw_set_keyboard_input(NULL);
-      winraw_destroy_window(wr->window);
+      rid.dwFlags     = RIDEV_REMOVE;
+      rid.hwndTarget  = NULL;
+      rid.usUsagePage = 0x01; /* generic desktop */
+      rid.usUsage     = 0x02; /* mouse */
+
+      RegisterRawInputDevices(&rid, 1, sizeof(RAWINPUTDEVICE));
+
+      rid.dwFlags     = RIDEV_REMOVE;
+      rid.hwndTarget  = NULL;
+      rid.usUsagePage = 0x01; /* Generic desktop */
+      rid.usUsage     = 0x06; /* Keyboard */
+      if (settings->bools.input_nowinkey_enable)
+         rid.dwFlags |= RIDEV_NOHOTKEYS; /* Disable win keys while focused */
+
+      RegisterRawInputDevices(&rid, 1, sizeof(RAWINPUTDEVICE));
+      DestroyWindow(wr->window);
+      UnregisterClassA("winraw-input", NULL);
    }
    free(g_mice);
    if (wr)
@@ -667,61 +640,22 @@ static void winraw_poll(void *data)
       wr->mice[i].dlt_y   = InterlockedExchange(&g_mice[i].dlt_y, 0);
       wr->mice[i].whl_u   = InterlockedExchange(&g_mice[i].whl_u, 0);
       wr->mice[i].whl_d   = InterlockedExchange(&g_mice[i].whl_d, 0);
-      wr->mice[i].btn_l   = g_mice[i].btn_l;
-      wr->mice[i].btn_m   = g_mice[i].btn_m;
-      wr->mice[i].btn_r   = g_mice[i].btn_r;
-      wr->mice[i].btn_b4  = g_mice[i].btn_b4;
-      wr->mice[i].btn_b5  = g_mice[i].btn_b5;
+      wr->mice[i].flags   = g_mice[i].flags;
    }
 
    /* Prevent LAlt sticky after unfocusing with Alt-Tab */
    if (     !winraw_focus
-         && wr->keyboard.keys[SC_LALT]
+         && wr->kb_keys[SC_LALT]
          && !(GetKeyState(VK_MENU) & 0x8000))
    {
-      wr->keyboard.keys[SC_LALT] = 0;
+      wr->kb_keys[SC_LALT] = 0;
       input_keyboard_event(0,
             input_keymaps_translate_keysym_to_rk(SC_LALT),
             0, 0, RETRO_DEVICE_KEYBOARD);
    }
    /* Clear all keyboard key states when unfocused */
    else if (!winraw_focus && !(GetKeyState(VK_MENU) & 0x8000))
-      memset(wr->keyboard.keys, 0, SC_LAST);
-}
-
-static unsigned winraw_retro_id_to_rarch(unsigned id)
-{
-   switch (id)
-   {
-      case RETRO_DEVICE_ID_LIGHTGUN_DPAD_RIGHT:
-         return RARCH_LIGHTGUN_DPAD_RIGHT;
-      case RETRO_DEVICE_ID_LIGHTGUN_DPAD_LEFT:
-         return RARCH_LIGHTGUN_DPAD_LEFT;
-      case RETRO_DEVICE_ID_LIGHTGUN_DPAD_UP:
-         return RARCH_LIGHTGUN_DPAD_UP;
-      case RETRO_DEVICE_ID_LIGHTGUN_DPAD_DOWN:
-         return RARCH_LIGHTGUN_DPAD_DOWN;
-      case RETRO_DEVICE_ID_LIGHTGUN_SELECT:
-         return RARCH_LIGHTGUN_SELECT;
-      case RETRO_DEVICE_ID_LIGHTGUN_PAUSE:
-         return RARCH_LIGHTGUN_START;
-      case RETRO_DEVICE_ID_LIGHTGUN_RELOAD:
-         return RARCH_LIGHTGUN_RELOAD;
-      case RETRO_DEVICE_ID_LIGHTGUN_TRIGGER:
-         return RARCH_LIGHTGUN_TRIGGER;
-      case RETRO_DEVICE_ID_LIGHTGUN_AUX_A:
-         return RARCH_LIGHTGUN_AUX_A;
-      case RETRO_DEVICE_ID_LIGHTGUN_AUX_B:
-         return RARCH_LIGHTGUN_AUX_B;
-      case RETRO_DEVICE_ID_LIGHTGUN_AUX_C:
-         return RARCH_LIGHTGUN_AUX_C;
-      case RETRO_DEVICE_ID_LIGHTGUN_START:
-         return RARCH_LIGHTGUN_START;
-      default:
-         break;
-   }
-
-   return 0;
+      memset(wr->kb_keys, 0, SC_LAST);
 }
 
 static int16_t winraw_input_state(
@@ -736,13 +670,12 @@ static int16_t winraw_input_state(
       unsigned idx,
       unsigned id)
 {
-   int16_t ret           = 0;
-   settings_t *settings  = NULL;
    winraw_mouse_t *mouse = NULL;
-   winraw_input_t *wr    = (winraw_input_t*)data;
 
    if (port < MAX_USERS)
    {
+      int16_t ret           = 0;
+      winraw_input_t *wr    = (winraw_input_t*)data;
       bool process_mouse    =
          (device == RETRO_DEVICE_JOYPAD)
          || (device == RETRO_DEVICE_MOUSE)
@@ -754,7 +687,7 @@ static int16_t winraw_input_state(
       if (process_mouse)
       {
          unsigned i;
-         settings        = config_get_ptr();
+         settings_t *settings = config_get_ptr();
          for (i = 0; i < wr->mouse_cnt; ++i)
          {
             if (i == settings->uints.input_mouse_index[port])
@@ -858,11 +791,11 @@ static int16_t winraw_input_state(
                   case RETRO_DEVICE_ID_MOUSE_Y:
                      return abs ? mouse->y : mouse->dlt_y;
                   case RETRO_DEVICE_ID_MOUSE_LEFT:
-                     if (mouse->btn_l)
+                     if ((mouse->flags & WRAW_MOUSE_FLG_BTN_L) > 0)
                         return 1;
                      break;
                   case RETRO_DEVICE_ID_MOUSE_RIGHT:
-                     if (mouse->btn_r)
+                     if ((mouse->flags & WRAW_MOUSE_FLG_BTN_R) > 0)
                         return 1;
                      break;
                   case RETRO_DEVICE_ID_MOUSE_WHEELUP:
@@ -874,15 +807,15 @@ static int16_t winraw_input_state(
                         return 1;
                      break;
                   case RETRO_DEVICE_ID_MOUSE_MIDDLE:
-                     if (mouse->btn_m)
+                     if ((mouse->flags & WRAW_MOUSE_FLG_BTN_M) > 0)
                         return 1;
                      break;
                   case RETRO_DEVICE_ID_MOUSE_BUTTON_4:
-                     if (mouse->btn_b4)
+                     if ((mouse->flags & WRAW_MOUSE_FLG_BTN_B4) > 0)
                         return 1;
                      break;
                   case RETRO_DEVICE_ID_MOUSE_BUTTON_5:
-                     if (mouse->btn_b5)
+                     if ((mouse->flags & WRAW_MOUSE_FLG_BTN_B5) > 0)
                         return 1;
                      break;
                }
@@ -891,9 +824,8 @@ static int16_t winraw_input_state(
          case RETRO_DEVICE_POINTER:
          case RARCH_DEVICE_POINTER_SCREEN:
             {
-               struct video_viewport vp;
+               struct video_viewport vp    = {0};
                bool pointer_down           = false;
-               bool inside                 = false;
                int x                       = 0;
                int y                       = 0;
                int16_t res_x               = 0;
@@ -904,13 +836,6 @@ static int16_t winraw_input_state(
                struct winraw_pointer_status *
                   check_pos                = wr->pointer_head.next;
 
-               vp.x                        = 0;
-               vp.y                        = 0;
-               vp.width                    = 0;
-               vp.height                   = 0;
-               vp.full_width               = 0;
-               vp.full_height              = 0;
-
                while (check_pos && num < idx)
                {
                   num++;
@@ -923,7 +848,7 @@ static int16_t winraw_input_state(
                {
                   x            = mouse->x;
                   y            = mouse->y;
-                  pointer_down = mouse->btn_l;
+                  pointer_down = (mouse->flags & (WRAW_MOUSE_FLG_BTN_L)) > 0;
                }
 
                if (check_pos)
@@ -933,7 +858,7 @@ static int16_t winraw_input_state(
                   pointer_down = true;
                }
 
-               if (!(video_driver_translate_coord_viewport_wrap(&vp, x, y,
+               if (!(video_driver_translate_coord_viewport_confined_wrap(&vp, x, y,
                            &res_x, &res_y, &res_screen_x, &res_screen_y)))
                   return 0;
 
@@ -943,9 +868,6 @@ static int16_t winraw_input_state(
                   res_y        = res_screen_y;
                }
 
-               if (!(inside = (res_x >= -0x7fff) && (res_y >= -0x7fff)))
-                  return 0;
-
                switch (id)
                {
                   case RETRO_DEVICE_ID_POINTER_X:
@@ -954,6 +876,8 @@ static int16_t winraw_input_state(
                      return res_y;
                   case RETRO_DEVICE_ID_POINTER_PRESSED:
                      return pointer_down;
+                  case RETRO_DEVICE_ID_POINTER_IS_OFFSCREEN:
+                     return input_driver_pointer_is_offscreen(res_x, res_y);
                   default:
                      break;
                }
@@ -981,7 +905,7 @@ static int16_t winraw_input_state(
                case RETRO_DEVICE_ID_LIGHTGUN_DPAD_RIGHT:
                case RETRO_DEVICE_ID_LIGHTGUN_PAUSE: /* deprecated */
                   {
-                     unsigned new_id                = winraw_retro_id_to_rarch(id);
+                     unsigned new_id                = input_driver_lightgun_id_convert(id);
                      const uint64_t bind_joykey     = input_config_binds[port][new_id].joykey;
                      const uint64_t bind_joyaxis    = input_config_binds[port][new_id].joyaxis;
                      const uint64_t autobind_joykey = input_autoconf_binds[port][new_id].joykey;
@@ -1063,12 +987,32 @@ bool winraw_handle_message(UINT msg,
 
 static void winraw_free(void *data)
 {
-   winraw_input_t *wr = (winraw_input_t*)data;
+   RAWINPUTDEVICE rid;
+   settings_t *settings = config_get_ptr();
+   winraw_input_t *wr   = (winraw_input_t*)data;
+
+   rid.dwFlags          = RIDEV_REMOVE;
+   rid.hwndTarget       = NULL;
+   rid.usUsagePage      = 0x01; /* generic desktop */
+   rid.usUsage          = 0x02; /* mouse */
+
+   RegisterRawInputDevices(&rid, 1, sizeof(RAWINPUTDEVICE));
+
+   rid.dwFlags          = RIDEV_REMOVE;
+   rid.hwndTarget       = NULL;
+   rid.usUsagePage      = 0x01; /* Generic desktop */
+   rid.usUsage          = 0x06; /* Keyboard */
+   if (settings->bools.input_nowinkey_enable)
+      rid.dwFlags      |= RIDEV_NOHOTKEYS; /* Disable win keys while focused */
+
+   RegisterRawInputDevices(&rid, 1, sizeof(RAWINPUTDEVICE));
 
-   winraw_set_mouse_input(NULL);
-   winraw_set_keyboard_input(NULL);
    SetWindowLongPtr(wr->window, GWLP_USERDATA, 0);
-   winraw_destroy_window(wr->window);
+   if (wr->window)
+   {
+      DestroyWindow(wr->window);
+      UnregisterClassA("winraw-input", NULL);
+   }
    free(g_mice);
    free(wr->mice);
 
@@ -1087,19 +1031,28 @@ static uint64_t winraw_get_capabilities(void *u)
 
 static void winraw_grab_mouse(void *d, bool state)
 {
+   RAWINPUTDEVICE rid;
    winraw_input_t *wr = (winraw_input_t*)d;
+   bool curr_state    = (wr->flags & WRAW_INP_FLG_MOUSE_GRAB) > 0;
 
-   if (state == wr->mouse_grab)
+   if (curr_state == state)
       return;
 
-   if (!winraw_set_mouse_input(wr->window))
-      return;
-
-   wr->mouse_grab = state;
+   rid.dwFlags        = (wr->window) ? 0 : RIDEV_REMOVE;
+   rid.hwndTarget     = wr->window;
+   rid.usUsagePage    = 0x01; /* generic desktop */
+   rid.usUsage        = 0x02; /* mouse */
 
+   if (RegisterRawInputDevices(&rid, 1, sizeof(RAWINPUTDEVICE)))
+   {
+      if (state)
+         wr->flags |=  WRAW_INP_FLG_MOUSE_GRAB;
+      else
+         wr->flags &= ~WRAW_INP_FLG_MOUSE_GRAB;
 #ifndef _XBOX
-   win32_clip_window(state);
+      win32_clip_window(state);
 #endif
+   }
 }
 
 input_driver_t input_winraw = {
