@@ -26,6 +26,7 @@
 #include <compat/strl.h>
 #include <queues/fifo_queue.h>
 #include <string/stdstring.h>
+#include <retro_miscellaneous.h>
 
 #include "../connect/joypad_connection.h"
 #include "../input_defines.h"
@@ -63,8 +64,8 @@ struct libusb_adapter
    int endpoint_in_max_size;
    int endpoint_out_max_size;
 
-   uint8_t manufacturer_name[255];
-   uint8_t name[255];
+   uint8_t manufacturer_name[NAME_MAX_LENGTH];
+   uint8_t name[NAME_MAX_LENGTH];
    uint8_t data[2048];
 
    int slot;
@@ -523,11 +524,11 @@ static int16_t libusb_hid_joypad_state(
       const uint32_t joyaxis = (binds[i].joyaxis != AXIS_NONE)
          ? binds[i].joyaxis : joypad_info->auto_binds[i].joyaxis;
       if (
-               (uint16_t)joykey != NO_BTN 
+               (uint16_t)joykey != NO_BTN
             && libusb_hid_joypad_button(data, port_idx, (uint16_t)joykey))
          ret |= ( 1 << i);
       else if (joyaxis != AXIS_NONE &&
-            ((float)abs(libusb_hid_joypad_axis(data, port_idx, joyaxis)) 
+            ((float)abs(libusb_hid_joypad_axis(data, port_idx, joyaxis))
              / 0x8000) > joypad_info->axis_threshold)
          ret |= (1 << i);
    }
