@@ -212,8 +212,10 @@ input_device_driver_t ctr_joypad = {
    ctr_joypad_get_buttons,
    ctr_joypad_axis,
    ctr_joypad_poll,
-   NULL,
-   NULL,
+   NULL, /* set_rumble */
+   NULL, /* set_rumble_gain */
+   NULL, /* set_sensor_state */
+   NULL, /* get_sensor_input */
    ctr_joypad_name,
    "ctr",
 };
