@@ -31,7 +31,7 @@ static HidVibrationDeviceHandle vibration_handles[DEFAULT_MAX_PADS][2];
 static HidVibrationDeviceHandle vibration_handleheld[2];
 static HidVibrationValue vibration_values[DEFAULT_MAX_PADS][2];
 static HidVibrationValue vibration_stop;
-static int previous_handheld                         = -1; 
+static int previous_handheld                         = -1;
 /* 1 = handheld, 0 = docked, -1 = first use */
 static uint previous_split_joycon_setting[MAX_USERS] = { 0 };
 #endif
@@ -59,7 +59,7 @@ static void *switch_joypad_init(void *data)
    hidSetNpadJoyHoldType(HidNpadJoyHoldType_Horizontal);
    padConfigureInput(DEFAULT_MAX_PADS, HidNpadStyleSet_NpadStandard);
 
-   /* Switch like stop behavior with muted band channels 
+   /* Switch like stop behavior with muted band channels
     * and frequencies set to default. */
    vibration_stop.amp_low   = 0.0f;
    vibration_stop.freq_low  = 160.0f;
@@ -181,12 +181,12 @@ static int16_t switch_joypad_state(
       const uint32_t joyaxis = (binds[i].joyaxis != AXIS_NONE)
          ? binds[i].joyaxis : joypad_info->auto_binds[i].joyaxis;
       if (
-               (uint16_t)joykey != NO_BTN 
+               (uint16_t)joykey != NO_BTN
             && (button_state[port_idx] & (1 << (uint16_t)joykey))
          )
          ret |= ( 1 << i);
       else if (joyaxis != AXIS_NONE &&
-            ((float)abs(switch_joypad_axis_state(port_idx, joyaxis)) 
+            ((float)abs(switch_joypad_axis_state(port_idx, joyaxis))
              / 0x8000) > joypad_info->axis_threshold)
          ret |= (1 << i);
    }
@@ -237,20 +237,20 @@ static void switch_joypad_poll(void)
 
    if (previous_handheld == -1)
    {
-      /* First call of this function, apply joycon settings 
+      /* First call of this function, apply joycon settings
        * according to preferences, init variables */
       if (!handheld)
       {
          for (i = 0; i < MAX_USERS; i += 2)
          {
-            unsigned input_split_joycon = 
+            unsigned input_split_joycon =
                settings->uints.input_split_joycon[i];
 
             if (input_split_joycon)
             {
                hidSetNpadJoyAssignmentModeSingleByDefault(i);
                hidSetNpadJoyAssignmentModeSingleByDefault(i + 1);
-            } 
+            }
             else if (!input_split_joycon)
             {
                hidSetNpadJoyAssignmentModeDual(i);
@@ -266,7 +266,7 @@ static void switch_joypad_poll(void)
 
    if (!handheld && previous_handheld)
    {
-      /* switching out of handheld, so make sure 
+      /* switching out of handheld, so make sure
        * joycons are correctly split. */
       for (i = 0; i < MAX_USERS; i += 2)
       {
@@ -297,7 +297,7 @@ static void switch_joypad_poll(void)
          {
             hidSetNpadJoyAssignmentModeSingleByDefault(i);
             hidSetNpadJoyAssignmentModeSingleByDefault(i + 1);
-         } 
+         }
          else if (!input_split_joycon
                && previous_split_joycon_setting[i])
          {
@@ -310,19 +310,20 @@ static void switch_joypad_poll(void)
 
    for (i = 0; i < MAX_USERS; i += 2)
       previous_split_joycon_setting[i] = settings->uints.input_split_joycon[i];
-   
+
    previous_handheld = handheld;
 
    for (i = 0; i < DEFAULT_MAX_PADS; i++)
    {
-      HidAnalogStickState stick_left_state = padGetStickPos(&pad_states[i], 0);
+      HidAnalogStickState stick_left_state  = padGetStickPos(&pad_states[i], 0);
       HidAnalogStickState stick_right_state = padGetStickPos(&pad_states[i], 1);
       unsigned input_split_joycon = settings->uints.input_split_joycon[i];
-      int pad_button = padGetButtons(&pad_states[i]);
-      if (input_split_joycon && !handheld) {
+      int pad_button              = padGetButtons(&pad_states[i]);
+      if (input_split_joycon && !handheld)
+      {
          button_state[i] = 0;
-
-         if (hidGetNpadDeviceType((HidNpadIdType)i) & HidDeviceTypeBits_JoyLeft) {
+         if (hidGetNpadDeviceType((HidNpadIdType)i) & HidDeviceTypeBits_JoyLeft)
+         {
             if (pad_button & HidNpadButton_Left)
                button_state[i] |= (uint16_t)HidNpadButton_B;
             if (pad_button & HidNpadButton_Up)
@@ -342,7 +343,9 @@ static void switch_joypad_poll(void)
 
             analog_state[i][RETRO_DEVICE_INDEX_ANALOG_LEFT][RETRO_DEVICE_ID_ANALOG_X] = -stick_left_state.y;
             analog_state[i][RETRO_DEVICE_INDEX_ANALOG_LEFT][RETRO_DEVICE_ID_ANALOG_Y] = -stick_left_state.x;
-         } else if (hidGetNpadDeviceType((HidNpadIdType)i) & HidDeviceTypeBits_JoyRight) {
+         }
+         else if (hidGetNpadDeviceType((HidNpadIdType)i) & HidDeviceTypeBits_JoyRight)
+         {
             if (pad_button & HidNpadButton_A)
                button_state[i] |= (uint16_t)HidNpadButton_B;
             if (pad_button & HidNpadButton_B)
@@ -363,10 +366,9 @@ static void switch_joypad_poll(void)
             /* Throw JoyRight state into retro left analog */
             analog_state[i][RETRO_DEVICE_INDEX_ANALOG_LEFT][RETRO_DEVICE_ID_ANALOG_X] = stick_right_state.y;
             analog_state[i][RETRO_DEVICE_INDEX_ANALOG_LEFT][RETRO_DEVICE_ID_ANALOG_Y] = stick_right_state.x;
-         } else {
-            /* Handle other types via Default Input Handling */
-            goto lblDefaultInputHandling;
          }
+         else /* Handle other types via Default Input Handling */
+            goto lblDefaultInputHandling;
       }
       else
       {
@@ -375,7 +377,7 @@ lblDefaultInputHandling:
          button_state[i] = pad_button;
          analog_state[i][RETRO_DEVICE_INDEX_ANALOG_LEFT][RETRO_DEVICE_ID_ANALOG_X] = stick_left_state.x;
          analog_state[i][RETRO_DEVICE_INDEX_ANALOG_LEFT][RETRO_DEVICE_ID_ANALOG_Y] = -stick_left_state.y;
-         
+
          analog_state[i][RETRO_DEVICE_INDEX_ANALOG_RIGHT][RETRO_DEVICE_ID_ANALOG_X] = stick_right_state.x;
          analog_state[i][RETRO_DEVICE_INDEX_ANALOG_RIGHT][RETRO_DEVICE_ID_ANALOG_Y] = -stick_right_state.y;
       }
@@ -465,7 +467,9 @@ input_device_driver_t switch_joypad = {
 #else
    NULL, /* set_rumble */
 #endif
-   NULL,
+   NULL, /* set_rumble_gain */
+   NULL, /* set_sensor_state */
+   NULL, /* get_sensor_input */
    switch_joypad_name,
    "switch"
 };
