@@ -361,8 +361,10 @@ input_device_driver_t wpad_driver =
   wpad_get_buttons,
   wpad_axis,
   wpad_poll,
-  NULL,
-  NULL,
+  NULL, /* set_rumble */
+  NULL, /* set_rumble_gain */
+  NULL, /* set_sensor_state */
+  NULL, /* get_sensor_input */
   wpad_name,
   "gamepad",
 };
