@@ -101,15 +101,15 @@ DECL_BTN(b, 96) \
 DECL_BTN(x, 100) \
 DECL_BTN(y, 99) \
 DECL_BTN(start, 108) \
-DECL_BTN(select, 4) \
+DECL_BTN(select, 109) \
 DECL_BTN(up, h0up) \
 DECL_BTN(down, h0down) \
 DECL_BTN(left, h0left) \
 DECL_BTN(right, h0right) \
 DECL_BTN(l, 102) \
 DECL_BTN(r, 103) \
-DECL_AXIS(l2, +6) \
-DECL_AXIS(r2, +7) \
+DECL_BTN(l2, 104) \
+DECL_BTN(r2, 105) \
 DECL_BTN(l3, 106) \
 DECL_BTN(r3, 107) \
 DECL_AXIS(l_x_plus,  +0) \
@@ -703,7 +703,7 @@ DECL_AXIS(r_x_minus, -2) \
 DECL_AXIS(r_y_plus,  +3) \
 DECL_AXIS(r_y_minus, -3)
 
-#define IOS_MFI_DEFAULT_BINDS \
+#define MFI_DEFAULT_BINDS \
 DECL_BTN(a, 8) \
 DECL_BTN(b, 0) \
 DECL_BTN(x, 9) \
@@ -716,8 +716,6 @@ DECL_BTN(l, 10) \
 DECL_BTN(r, 11) \
 DECL_BTN(start, 3) \
 DECL_BTN(select, 2) \
-DECL_BTN(l2, 12) \
-DECL_BTN(r2, 13) \
 DECL_BTN(l3, 14) \
 DECL_BTN(r3, 15) \
 DECL_AXIS(l_x_plus,  +0) \
@@ -727,7 +725,9 @@ DECL_AXIS(l_y_minus, +1) \
 DECL_AXIS(r_x_plus,  +2) \
 DECL_AXIS(r_x_minus, -2) \
 DECL_AXIS(r_y_plus,  -3) \
-DECL_AXIS(r_y_minus, +3)
+DECL_AXIS(r_y_minus, +3) \
+DECL_AXIS(l2, +4) \
+DECL_AXIS(r2, +5)
 
 const char* const input_builtin_autoconfs[] =
 {
@@ -802,8 +802,8 @@ const char* const input_builtin_autoconfs[] =
 #ifdef EMSCRIPTEN
    DECL_AUTOCONF_PID(1, 1, "rwebpad", EMSCRIPTEN_DEFAULT_BINDS),
 #endif
-#if TARGET_OS_IPHONE
-   DECL_AUTOCONF_DEVICE("mFi Controller", "mfi", IOS_MFI_DEFAULT_BINDS),
+#if HAVE_MFI
+   DECL_AUTOCONF_DEVICE("mFi Controller", "mfi", MFI_DEFAULT_BINDS),
 #endif
    NULL
 };
