@@ -45,7 +45,7 @@
 
 #if defined(_XBOX360)
 #include <PPCIntrinsics.h>
-#elif !defined(__MACH__) && (defined(__POWERPC__) || defined(__powerpc__) || defined(__ppc__) || defined(__PPC64__) || defined(__powerpc64__))
+#elif !defined(__MACH__) && !defined(__FreeBSD__) && (defined(__POWERPC__) || defined(__powerpc__) || defined(__ppc__) || defined(__PPC64__) || defined(__powerpc64__))
 #ifndef _PPU_INTRINSICS_H
 #include <ppu_intrinsics.h>
 #endif
@@ -123,6 +123,7 @@
 /**
  * TODO/FIXME: clock_gettime function is part of iOS 10 now
  **/
+#if __IPHONE_OS_VERSION_MIN_REQUIRED < 100000
 static int ra_clock_gettime(int clk_ik, struct timespec *t)
 {
    struct timeval now;
@@ -134,6 +135,7 @@ static int ra_clock_gettime(int clk_ik, struct timespec *t)
    return 0;
 }
 #endif
+#endif
 
 #if defined(__MACH__) && __IPHONE_OS_VERSION_MIN_REQUIRED < 100000
 #else
@@ -150,13 +152,6 @@ static int ra_clock_gettime(int clk_ik, struct timespec *t)
 
 #include <string.h>
 
-/**
- * cpu_features_get_perf_counter:
- *
- * Gets performance counter.
- *
- * @return Performance counter.
- **/
 retro_perf_tick_t cpu_features_get_perf_counter(void)
 {
    retro_perf_tick_t time_ticks = 0;
@@ -181,7 +176,7 @@ retro_perf_tick_t cpu_features_get_perf_counter(void)
    time_ticks = (1000000 * tv_sec + tv_usec);
 #elif defined(GEKKO)
    time_ticks = gettime();
-#elif !defined(__MACH__) && (defined(_XBOX360) || defined(__powerpc__) || defined(__ppc__) || defined(__POWERPC__) || defined(__PSL1GHT__) || defined(__PPC64__) || defined(__powerpc64__))
+#elif !defined(__MACH__) && !defined(__FreeBSD__) && (defined(_XBOX360) || defined(__powerpc__) || defined(__ppc__) || defined(__POWERPC__) || defined(__PSL1GHT__) || defined(__PPC64__) || defined(__powerpc64__))
    time_ticks = __mftb();
 #elif (defined(_POSIX_MONOTONIC_CLOCK) && _POSIX_MONOTONIC_CLOCK > 0) || defined(__QNX__) || defined(ANDROID)
    struct timespec tv;
@@ -218,13 +213,6 @@ retro_perf_tick_t cpu_features_get_perf_counter(void)
    return time_ticks;
 }
 
-/**
- * cpu_features_get_time_usec:
- *
- * Gets time in microseconds.
- *
- * @return Time in microseconds.
- **/
 retro_time_t cpu_features_get_time_usec(void)
 {
 #if defined(_WIN32)
@@ -433,10 +421,10 @@ static const char *parse_decimal(const char* input,
  *             2,4-127,128-143
  *             0-1
  **/
-static void cpulist_parse(CpuList* list, char **buf, ssize_t length)
+static void cpulist_parse(CpuList* list, char **buf, ssize_t len)
 {
    const char* p   = (const char*)buf;
-   const char* end = p + length;
+   const char* end = p + len;
 
    /* NOTE: the input line coming from sysfs typically contains a
     * trailing newline, so take care of it in the code below
@@ -486,15 +474,15 @@ static void cpulist_parse(CpuList* list, char **buf, ssize_t length)
  **/
 static void cpulist_read_from(CpuList* list, const char* filename)
 {
-   ssize_t length;
+   ssize_t _len;
    char *buf  = NULL;
 
    list->mask = 0;
 
-   if (filestream_read_file(filename, (void**)&buf, &length) != 1)
+   if (filestream_read_file(filename, (void**)&buf, &_len) != 1)
       return;
 
-   cpulist_parse(list, &buf, length);
+   cpulist_parse(list, &buf, _len);
    if (buf)
       free(buf);
    buf = NULL;
@@ -503,13 +491,6 @@ static void cpulist_read_from(CpuList* list, const char* filename)
 
 #endif
 
-/**
- * cpu_features_get_core_amount:
- *
- * Gets the amount of available CPU cores.
- *
- * @return Amount of CPU cores available.
- **/
 unsigned cpu_features_get_core_amount(void)
 {
 #if defined(_WIN32) && !defined(_XBOX)
@@ -566,15 +547,15 @@ unsigned cpu_features_get_core_amount(void)
    /* Copypasta from stackoverflow, dunno if it works. */
    int num_cpu = 0;
    int mib[4];
-   size_t len = sizeof(num_cpu);
+   size_t _len = sizeof(num_cpu);
 
    mib[0] = CTL_HW;
    mib[1] = HW_AVAILCPU;
-   sysctl(mib, 2, &num_cpu, &len, NULL, 0);
+   sysctl(mib, 2, &num_cpu, &_len, NULL, 0);
    if (num_cpu < 1)
    {
       mib[1] = HW_NCPU;
-      sysctl(mib, 2, &num_cpu, &len, NULL, 0);
+      sysctl(mib, 2, &num_cpu, &_len, NULL, 0);
       if (num_cpu < 1)
          num_cpu = 1;
    }
@@ -609,13 +590,6 @@ unsigned cpu_features_get_core_amount(void)
 #define VENDOR_INTEL_c  0x6c65746e
 #define VENDOR_INTEL_d  0x49656e69
 
-/**
- * cpu_features_get:
- *
- * Gets CPU features..
- *
- * @return Bitmask of all CPU features available.
- **/
 uint64_t cpu_features_get(void)
 {
    uint64_t cpu        = 0;
@@ -624,67 +598,53 @@ uint64_t cpu_features_get(void)
    const int avx_flags = (1 << 27) | (1 << 28);
 #endif
 #if defined(__MACH__)
-   size_t len          = sizeof(size_t);
-
-   if (sysctlbyname("hw.optional.floatingpoint", NULL, &len, NULL, 0) == 0)
+   size_t _len          = sizeof(size_t);
+   if (sysctlbyname("hw.optional.floatingpoint", NULL, &_len, NULL, 0) == 0)
       cpu |= RETRO_SIMD_CMOV;
 
 #if defined(CPU_X86)
-   len            = sizeof(size_t);
-   if (sysctlbyname("hw.optional.mmx", NULL, &len, NULL, 0) == 0)
+   _len            = sizeof(size_t);
+   if (sysctlbyname("hw.optional.mmx", NULL, &_len, NULL, 0) == 0)
       cpu |= RETRO_SIMD_MMX | RETRO_SIMD_MMXEXT;
-
-   len            = sizeof(size_t);
-   if (sysctlbyname("hw.optional.sse", NULL, &len, NULL, 0) == 0)
+   _len            = sizeof(size_t);
+   if (sysctlbyname("hw.optional.sse", NULL, &_len, NULL, 0) == 0)
       cpu |= RETRO_SIMD_SSE;
-
-   len            = sizeof(size_t);
-   if (sysctlbyname("hw.optional.sse2", NULL, &len, NULL, 0) == 0)
+   _len            = sizeof(size_t);
+   if (sysctlbyname("hw.optional.sse2", NULL, &_len, NULL, 0) == 0)
       cpu |= RETRO_SIMD_SSE2;
-
-   len            = sizeof(size_t);
-   if (sysctlbyname("hw.optional.sse3", NULL, &len, NULL, 0) == 0)
+   _len            = sizeof(size_t);
+   if (sysctlbyname("hw.optional.sse3", NULL, &_len, NULL, 0) == 0)
       cpu |= RETRO_SIMD_SSE3;
-
-   len            = sizeof(size_t);
-   if (sysctlbyname("hw.optional.supplementalsse3", NULL, &len, NULL, 0) == 0)
+   _len            = sizeof(size_t);
+   if (sysctlbyname("hw.optional.supplementalsse3", NULL, &_len, NULL, 0) == 0)
       cpu |= RETRO_SIMD_SSSE3;
-
-   len            = sizeof(size_t);
-   if (sysctlbyname("hw.optional.sse4_1", NULL, &len, NULL, 0) == 0)
+   _len            = sizeof(size_t);
+   if (sysctlbyname("hw.optional.sse4_1", NULL, &_len, NULL, 0) == 0)
       cpu |= RETRO_SIMD_SSE4;
-
-   len            = sizeof(size_t);
-   if (sysctlbyname("hw.optional.sse4_2", NULL, &len, NULL, 0) == 0)
+   _len            = sizeof(size_t);
+   if (sysctlbyname("hw.optional.sse4_2", NULL, &_len, NULL, 0) == 0)
       cpu |= RETRO_SIMD_SSE42;
-
-   len            = sizeof(size_t);
-   if (sysctlbyname("hw.optional.aes", NULL, &len, NULL, 0) == 0)
+   _len            = sizeof(size_t);
+   if (sysctlbyname("hw.optional.aes", NULL, &_len, NULL, 0) == 0)
       cpu |= RETRO_SIMD_AES;
-
-   len            = sizeof(size_t);
-   if (sysctlbyname("hw.optional.avx1_0", NULL, &len, NULL, 0) == 0)
+   _len            = sizeof(size_t);
+   if (sysctlbyname("hw.optional.avx1_0", NULL, &_len, NULL, 0) == 0)
       cpu |= RETRO_SIMD_AVX;
-
-   len            = sizeof(size_t);
-   if (sysctlbyname("hw.optional.avx2_0", NULL, &len, NULL, 0) == 0)
+   _len            = sizeof(size_t);
+   if (sysctlbyname("hw.optional.avx2_0", NULL, &_len, NULL, 0) == 0)
       cpu |= RETRO_SIMD_AVX2;
-
-   len            = sizeof(size_t);
-   if (sysctlbyname("hw.optional.altivec", NULL, &len, NULL, 0) == 0)
+   _len            = sizeof(size_t);
+   if (sysctlbyname("hw.optional.altivec", NULL, &_len, NULL, 0) == 0)
       cpu |= RETRO_SIMD_VMX;
-
 #else
-   len            = sizeof(size_t);
-   if (sysctlbyname("hw.optional.neon", NULL, &len, NULL, 0) == 0)
+   _len            = sizeof(size_t);
+   if (sysctlbyname("hw.optional.neon", NULL, &_len, NULL, 0) == 0)
       cpu |= RETRO_SIMD_NEON;
-
-   len            = sizeof(size_t);
-   if (sysctlbyname("hw.optional.neon_fp16", NULL, &len, NULL, 0) == 0)
+   _len            = sizeof(size_t);
+   if (sysctlbyname("hw.optional.neon_fp16", NULL, &_len, NULL, 0) == 0)
       cpu |= RETRO_SIMD_VFPV3;
-
-   len            = sizeof(size_t);
-   if (sysctlbyname("hw.optional.neon_hpfp", NULL, &len, NULL, 0) == 0)
+   _len            = sizeof(size_t);
+   if (sysctlbyname("hw.optional.neon_hpfp", NULL, &_len, NULL, 0) == 0)
       cpu |= RETRO_SIMD_VFPV4;
 #endif
 #elif defined(_XBOX1)
@@ -694,7 +654,6 @@ uint64_t cpu_features_get(void)
    int flags[4];
    int vendor_shuffle[3];
    char vendor[13];
-   uint64_t cpu_flags  = 0;
    x86_cpuid(0, flags);
    vendor_shuffle[0] = flags[1];
    vendor_shuffle[1] = flags[3];
@@ -830,23 +789,25 @@ uint64_t cpu_features_get(void)
    return cpu;
 }
 
-void cpu_features_get_model_name(char *name, int len)
+void cpu_features_get_model_name(char *s, int len)
 {
 #if defined(CPU_X86) && !defined(__MACH__)
    union {
-      int i[4];
-      unsigned char s[16];
+      int32_t i[4];
+      uint32_t u[4];
+      uint8_t s[16];
    } flags;
    int i, j;
-   size_t pos = 0;
+   int pos = 0;
    bool start = false;
 
-   if (!name)
+   if (!s)
       return;
 
    x86_cpuid(0x80000000, flags.i);
 
-   if (flags.i[0] < 0x80000004)
+   /* Check for additional cpuid attributes availability */
+   if (flags.u[0] < 0x80000004)
       return;
 
    for (i = 0; i < 3; i++)
@@ -854,7 +815,7 @@ void cpu_features_get_model_name(char *name, int len)
       memset(flags.i, 0, sizeof(flags.i));
       x86_cpuid(0x80000002 + i, flags.i);
 
-      for (j = 0; j < sizeof(flags.s); j++)
+      for (j = 0; j < (int)sizeof(flags.s); j++)
       {
          if (!start && flags.s[j] == ' ')
             continue;
@@ -864,26 +825,26 @@ void cpu_features_get_model_name(char *name, int len)
          if (pos == len - 1)
          {
             /* truncate if we ran out of room */
-            name[pos] = '\0';
+            s[pos] = '\0';
             goto end;
          }
 
-         name[pos++] = flags.s[j];
+         s[pos++] = flags.s[j];
       }
    }
 end:
    /* terminate our string */
-   if (pos < (size_t)len)
-      name[pos] = '\0';
+   if (pos < len)
+      s[pos] = '\0';
 #elif defined(__MACH__)
-   if (!name)
+   if (!s)
       return;
    {
       size_t len_size = len;
-      sysctlbyname("machdep.cpu.brand_string", name, &len_size, NULL, 0);
+      sysctlbyname("machdep.cpu.brand_string", s, &len_size, NULL, 0);
    }
 #elif defined(__linux__)
-   if (!name)
+   if (!s)
       return;
    {
       char *model_name, line[128];
@@ -902,8 +863,8 @@ end:
          if ((model_name = strstr(line + 10, ": ")))
          {
             model_name += 2;
-            strncpy(name, model_name, len);
-            name[len - 1] = '\0';
+            strncpy(s, model_name, len);
+            s[len - 1] = '\0';
          }
 
          break;
@@ -911,9 +872,5 @@ end:
 
       filestream_close(fp);
    }
-#else
-   if (!name)
-      return;
-   return;
 #endif
 }
