@@ -207,12 +207,13 @@ static char *config_file_strip_comment(char *str)
 
 static char *config_file_extract_value(char *line)
 {
+   char *dst = NULL;
    while (ISSPACE((int)*line))
       line++;
 
    /* Note: From this point on, an empty value
     * string is valid - and in this case, strldup("", sizeof(""))
-    * will be returned
+    * will be returned (see Note 2)
     * > If we instead return NULL, the the entry
     *   is ignored completely - which means we cannot
     *   track *changes* in entry value */
@@ -254,7 +255,13 @@ static char *config_file_extract_value(char *line)
          return strdup(value);
    }
 
-   return strldup("", sizeof(""));
+   /* Note 2: This is an unrolled strldup call
+    * to avoid an unnecessary dependency -
+    * call is strldup("", sizeof(""))
+    **/
+   dst = (char*)malloc(sizeof(char) * 2);
+   strlcpy(dst, "", 1);
+   return dst;
 }
 
 /* Move semantics? */
@@ -348,32 +355,29 @@ static void config_file_add_child_list(config_file_t *parent,
 static void config_file_get_realpath(char *s, size_t len,
       char *path, const char *config_path)
 {
-#ifdef _WIN32
-   if (!string_is_empty(config_path))
-      fill_pathname_resolve_relative(s, config_path,
-            path, len);
-#else
-#if !defined(__PSL1GHT__) && !defined(__PS3__)
+#if !defined(_WIN32) && !defined(__PSL1GHT__) && !defined(__PS3__)
    if (*path == '~')
    {
       const char *home = getenv("HOME");
       if (home)
       {
-         strlcpy(s, home,     len);
-         strlcat(s, path + 1, len);
+         size_t _len = strlcpy(s, home,     len);
+         strlcpy(s + _len, path + 1, len - _len);
       }
       else
          strlcpy(s, path + 1, len);
    }
    else
 #endif
+   {
       if (!string_is_empty(config_path))
-         fill_pathname_resolve_relative(s, config_path, path, len);
-#endif
+         fill_pathname_resolve_relative(s, config_path,
+            path, len);
+   }
 }
 
 static void config_file_add_sub_conf(config_file_t *conf, char *path,
-      char *real_path, size_t len, config_file_cb_t *cb)
+      char *s, size_t len, config_file_cb_t *cb)
 {
    struct config_include_list *head = conf->includes;
    struct config_include_list *node = (struct config_include_list*)
@@ -396,18 +400,24 @@ static void config_file_add_sub_conf(config_file_t *conf, char *path,
          conf->includes = node;
    }
 
-   config_file_get_realpath(real_path, len, path,
+   config_file_get_realpath(s, len, path,
          conf->path);
 }
 
-void config_file_add_reference(config_file_t *conf, char *path)
+size_t config_file_add_reference(config_file_t *conf, char *path)
 {
+   size_t _len;
    /* It is expected that the conf has it's path already set */
-   char short_path[PATH_MAX_LENGTH];
+   char short_path[NAME_MAX_LENGTH];
    if (!conf->references)
-      conf->references = path_linked_list_new();
-   fill_pathname_abbreviated_or_relative(short_path, conf->path, path, sizeof(short_path));
+   {
+      conf->references       = (struct path_linked_list*)malloc(sizeof(*conf->references));
+      conf->references->next = NULL;
+      conf->references->path = NULL;
+   }
+   _len = fill_pathname_abbreviated_or_relative(short_path, conf->path, path, sizeof(short_path));
    path_linked_list_add_path(conf->references, short_path);
+   return _len;
 }
 
 static int config_file_load_internal(
@@ -455,8 +465,8 @@ static int config_file_load_internal(
          continue;
       }
 
-      if ( 
-              !string_is_empty(line) 
+      if (
+              !string_is_empty(line)
             && config_file_parse_line(conf, list, line, cb))
       {
          if (conf->entries)
@@ -509,13 +519,11 @@ static bool config_file_parse_line(config_file_t *conf,
    {
       char *path               = NULL;
       bool include_found       = string_starts_with_size(comment,
-            "include ",
-            STRLEN_CONST("include "));
+            "include ",   STRLEN_CONST("include "));
       bool reference_found     = string_starts_with_size(comment,
-            "reference ",
-            STRLEN_CONST("reference "));
+            "reference ", STRLEN_CONST("reference "));
 
-      /* All comments except those starting with the include or 
+      /* All comments except those starting with the include or
        * reference directive are ignored */
       if (!include_found && !reference_found)
          return false;
@@ -701,7 +709,7 @@ static int config_file_from_string_internal(
       /* Get next line of config file */
       line = strtok_r(NULL, "\n", &save_ptr);
    }
-   
+
    return 0;
 }
 
@@ -819,7 +827,7 @@ config_file_t *config_file_new_from_string(char *from_string,
       const char *path)
 {
    struct config_file *conf      = config_file_new_alloc();
-   if (     conf 
+   if (     conf
          && config_file_from_string_internal(
             conf, from_string, path) != -1)
       return conf;
@@ -927,8 +935,7 @@ void config_file_initialize(struct config_file *conf)
    conf->references               = NULL;
    conf->includes                 = NULL;
    conf->include_depth            = 0;
-   conf->guaranteed_no_duplicates = false;
-   conf->modified                 = false;
+   conf->flags                    = 0;
 }
 
 config_file_t *config_file_new_alloc(void)
@@ -1153,11 +1160,11 @@ bool config_get_string(config_file_t *conf, const char *key, char **str)
   * Extracts a string to a preallocated buffer.
   * Avoid memory allocation.
   **/
-bool config_get_config_path(config_file_t *conf, char *s, size_t len)
+size_t config_get_config_path(config_file_t *conf, char *s, size_t len)
 {
    if (conf)
       return strlcpy(s, conf->path, len);
-   return false;
+   return 0;
 }
 
 bool config_get_array(config_file_t *conf, const char *key,
@@ -1173,8 +1180,7 @@ bool config_get_path(config_file_t *conf, const char *key,
       char *buf, size_t size)
 {
 #if defined(RARCH_CONSOLE) || !defined(RARCH_INTERNAL)
-   if (config_get_array(conf, key, buf, size))
-      return true;
+   return config_get_array(conf, key, buf, size);
 #else
    const struct config_entry_list *entry = config_get_entry(conf, key);
    if (entry)
@@ -1182,13 +1188,13 @@ bool config_get_path(config_file_t *conf, const char *key,
       fill_pathname_expand_special(buf, entry->value, size);
       return true;
    }
-#endif
    return false;
+#endif
 }
 
 /**
  * config_get_bool:
- * 
+ *
  * Extracts a boolean from config.
  * Valid boolean true are "true" and "1". Valid false are "false" and "0".
  * Other values will be treated as an error.
@@ -1234,7 +1240,7 @@ void config_set_string(config_file_t *conf, const char *key, const char *val)
 
    last                            = conf->entries;
 
-   if (conf->guaranteed_no_duplicates)
+   if (conf->flags & CONF_FILE_FLG_GUARANTEED_NO_DUPLICATES)
    {
       if (conf->last)
          last                      = conf->last;
@@ -1261,7 +1267,7 @@ void config_set_string(config_file_t *conf, const char *key, const char *val)
           *   is no longer considered 'read only' */
          entry->value    = strdup(val);
          entry->readonly = false;
-         conf->modified  = true;
+         conf->flags    |= CONF_FILE_FLG_MODIFIED;
          return;
       }
    }
@@ -1275,7 +1281,7 @@ void config_set_string(config_file_t *conf, const char *key, const char *val)
    entry->key       = strdup(key);
    entry->value     = strdup(val);
    entry->next      = NULL;
-   conf->modified   = true;
+   conf->flags     |= CONF_FILE_FLG_MODIFIED;
 
    if (last)
       last->next    = entry;
@@ -1310,7 +1316,7 @@ void config_unset(config_file_t *conf, const char *key)
 
    entry->key     = NULL;
    entry->value   = NULL;
-   conf->modified = true;
+   conf->flags   |= CONF_FILE_FLG_MODIFIED;
 }
 
 void config_set_path(config_file_t *conf, const char *entry, const char *val)
@@ -1324,69 +1330,66 @@ void config_set_path(config_file_t *conf, const char *entry, const char *val)
 #endif
 }
 
-void config_set_double(config_file_t *conf, const char *key, double val)
+size_t config_set_double(config_file_t *conf, const char *key, double val)
 {
    char buf[320];
 #ifdef __cplusplus
-   snprintf(buf, sizeof(buf), "%f", (float)val);
+   size_t _len = snprintf(buf, sizeof(buf), "%f", (float)val);
 #elif defined(__STDC_VERSION__) && __STDC_VERSION__>=199901L
-   snprintf(buf, sizeof(buf), "%lf", val);
+   size_t _len = snprintf(buf, sizeof(buf), "%lf", val);
 #else
-   snprintf(buf, sizeof(buf), "%f", (float)val);
+   size_t _len = snprintf(buf, sizeof(buf), "%f", (float)val);
 #endif
    config_set_string(conf, key, buf);
+   return _len;
 }
 
-void config_set_float(config_file_t *conf, const char *key, float val)
+size_t config_set_float(config_file_t *conf, const char *key, float val)
 {
    char buf[64];
-   snprintf(buf, sizeof(buf), "%f", val);
+   size_t _len = snprintf(buf, sizeof(buf), "%f", val);
    config_set_string(conf, key, buf);
+   return _len;
 }
 
-void config_set_int(config_file_t *conf, const char *key, int val)
+size_t config_set_int(config_file_t *conf, const char *key, int val)
 {
    char buf[16];
-   snprintf(buf, sizeof(buf), "%d", val);
+   size_t _len = snprintf(buf, sizeof(buf), "%d", val);
    config_set_string(conf, key, buf);
+   return _len;
 }
 
-void config_set_uint(config_file_t *conf, const char *key, unsigned int val)
+size_t config_set_uint(config_file_t *conf, const char *key, unsigned int val)
 {
    char buf[16];
-   snprintf(buf, sizeof(buf), "%u", val);
+   size_t _len = snprintf(buf, sizeof(buf), "%u", val);
    config_set_string(conf, key, buf);
+   return _len;
 }
 
-void config_set_hex(config_file_t *conf, const char *key, unsigned val)
+size_t config_set_hex(config_file_t *conf, const char *key, unsigned val)
 {
    char buf[16];
-   snprintf(buf, sizeof(buf), "%x", val);
+   size_t _len = snprintf(buf, sizeof(buf), "%x", val);
    config_set_string(conf, key, buf);
+   return _len;
 }
 
-void config_set_uint64(config_file_t *conf, const char *key, uint64_t val)
+size_t config_set_uint64(config_file_t *conf, const char *key, uint64_t val)
 {
    char buf[32];
-   snprintf(buf, sizeof(buf), "%" PRIu64, val);
+   size_t _len = snprintf(buf, sizeof(buf), "%" PRIu64, val);
    config_set_string(conf, key, buf);
+   return _len;
 }
 
-void config_set_char(config_file_t *conf, const char *key, char val)
+size_t config_set_char(config_file_t *conf, const char *key, char val)
 {
    char buf[2];
-   snprintf(buf, sizeof(buf), "%c", val);
+   size_t _len = snprintf(buf, sizeof(buf), "%c", val);
    config_set_string(conf, key, buf);
-}
-
-/**
- * config_set_bool:
-
- * TODO/FIXME - could be turned into a trivial macro or removed
- **/
-void config_set_bool(config_file_t *conf, const char *key, bool val)
-{
-   config_set_string(conf, key, val ? "true" : "false");
+   return _len;
 }
 
 /**
@@ -1399,32 +1402,32 @@ bool config_file_write(config_file_t *conf, const char *path, bool sort)
    if (!conf)
       return false;
 
-   if (!conf->modified)
-      return true;
-
-   if (!string_is_empty(path))
+   if (conf->flags & CONF_FILE_FLG_MODIFIED)
    {
-      void* buf  = NULL;
-      FILE *file = (FILE*)fopen_utf8(path, "wb");
-      if (!file)
-         return false;
+      if (string_is_empty(path))
+         config_file_dump(conf, stdout, sort);
+      else
+      {
+         void* buf  = NULL;
+         FILE *file = (FILE*)fopen_utf8(path, "wb");
+         if (!file)
+            return false;
 
-      buf        = calloc(1, 0x4000);
-      setvbuf(file, (char*)buf, _IOFBF, 0x4000);
+         buf        = calloc(1, 0x4000);
+         setvbuf(file, (char*)buf, _IOFBF, 0x4000);
 
-      config_file_dump(conf, file, sort);
+         config_file_dump(conf, file, sort);
 
-      if (file != stdout)
-         fclose(file);
-      if (buf)
-         free(buf);
+         if (file != stdout)
+            fclose(file);
+         if (buf)
+            free(buf);
 
-      /* Only update modified flag if config file
-       * is actually written to disk */
-      conf->modified = false;
+         /* Only update modified flag if config file
+          * is actually written to disk */
+         conf->flags &= ~CONF_FILE_FLG_MODIFIED;
+      }
    }
-   else
-      config_file_dump(conf, stdout, sort);
 
    return true;
 }
