@@ -302,4 +302,4 @@ static INLINE int pthread_equal(pthread_t t1, pthread_t t2)
 	 return t1 == t2;
 }
 
-#endif //_PSP_PTHREAD_WRAP__
+#endif /* _PSP_PTHREAD_WRAP__ */
