@@ -48,18 +48,6 @@ const uint8_t lr_char_props[256] = {
 	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00, /* Fx                  */
 };
 
-char *string_init(const char *src)
-{
-   return src ? strdup(src) : NULL;
-}
-
-void string_set(char **string, const char *src)
-{
-   free(*string);
-   *string = string_init(src);
-}
-
-
 char *string_to_upper(char *s)
 {
    char *cs = (char *)s;
@@ -89,8 +77,9 @@ char *string_ucwords(char *s)
    return s;
 }
 
-char *string_replace_substring(const char *in,
-      const char *pattern, size_t pattern_len,
+char *string_replace_substring(
+      const char *in,          size_t in_len,
+      const char *pattern,     size_t pattern_len,
       const char *replacement, size_t replacement_len)
 {
    size_t outlen;
@@ -113,7 +102,7 @@ char *string_replace_substring(const char *in,
       numhits++;
    }
 
-   outlen          = strlen(in) - pattern_len*numhits + replacement_len*numhits;
+   outlen = in_len - pattern_len * numhits + replacement_len*numhits;
 
    if (!(out = (char *)malloc(outlen+1)))
       return NULL;
@@ -145,17 +134,17 @@ char *string_trim_whitespace_left(char *const s)
 {
    if (s && *s)
    {
-      size_t len     = strlen(s);
+      size_t _len    = strlen(s);
       char *current  = s;
 
       while (*current && ISSPACE((unsigned char)*current))
       {
          ++current;
-         --len;
+         --_len;
       }
 
       if (s != current)
-         memmove(s, current, len + 1);
+         memmove(s, current, _len + 1);
    }
 
    return s;
@@ -170,13 +159,13 @@ char *string_trim_whitespace_right(char *const s)
 {
    if (s && *s)
    {
-      size_t len     = strlen(s);
-      char  *current = s + len - 1;
+      size_t _len    = strlen(s);
+      char  *current = s + _len - 1;
 
       while (current != s && ISSPACE((unsigned char)*current))
       {
          --current;
-         --len;
+         --_len;
       }
 
       current[ISSPACE((unsigned char)*current) ? 0 : 1] = '\0';
@@ -217,27 +206,24 @@ char *string_trim_whitespace(char *const s)
  * correctly any text containing so-called 'wide' Unicode
  * characters (e.g. CJK languages, emojis, etc.).
  **/
-void word_wrap(
+size_t word_wrap(
       char *dst,       size_t dst_size,
       const char *src, size_t src_len,
       int line_width,  int wideglyph_width, unsigned max_lines)
 {
-   char *lastspace     = NULL;
+   char *last_space    = NULL;
    unsigned counter    = 0;
    unsigned lines      = 1;
    const char *src_end = src + src_len;
 
    /* Prevent buffer overflow */
    if (dst_size < src_len + 1)
-      return;
+      return 0;
 
    /* Early return if src string length is less
     * than line width */
    if (src_len < (size_t)line_width)
-   {
-      strlcpy(dst, src, dst_size);
-      return;
-   }
+      return strlcpy(dst, src, dst_size);
 
    while (*src != '\0')
    {
@@ -245,21 +231,18 @@ void word_wrap(
       counter++;
 
       if (*src == ' ')
-         lastspace = dst; /* Remember the location of the whitespace */
+         last_space = dst; /* Remember the location of the whitespace */
       else if (*src == '\n')
       {
          /* If newlines embedded in the input,
           * reset the index */
          lines++;
-         counter = 0;
+         counter   = 0;
 
          /* Early return if remaining src string
           * length is less than line width */
          if (src_end - src <= line_width)
-         {
-            strlcpy(dst, src, dst_size);
-            return;
-         }
+            return strlcpy(dst, src, dst_size);
      }
 
       while (char_len--)
@@ -269,29 +252,27 @@ void word_wrap(
       {
          counter = 0;
 
-         if (lastspace && (max_lines == 0 || lines < max_lines))
+         if (last_space && (max_lines == 0 || lines < max_lines))
          {
             /* Replace nearest (previous) whitespace
              * with newline character */
-            *lastspace = '\n';
+            *last_space = '\n';
             lines++;
 
-            src -= dst - lastspace - 1;
-            dst = lastspace + 1;
-            lastspace  = NULL;
+            src        -= dst - last_space - 1;
+            dst         = last_space + 1;
+            last_space  = NULL;
 
             /* Early return if remaining src string
              * length is less than line width */
             if (src_end - src < line_width)
-            {
-               strlcpy(dst, src, dst_size);
-               return;
-            }
+               return strlcpy(dst, src, dst_size);
          }
       }
    }
 
    *dst = '\0';
+   return 0;
 }
 
 /**
@@ -327,7 +308,7 @@ void word_wrap(
  * on-screen pixel width deviates greatly from the set
  * @wideglyph_width value.
  **/
-void word_wrap_wideglyph(char *dst, size_t dst_size,
+size_t word_wrap_wideglyph(char *dst, size_t dst_size,
       const char *src, size_t src_len, int line_width,
       int wideglyph_width, unsigned max_lines)
 {
@@ -359,14 +340,11 @@ void word_wrap_wideglyph(char *dst, size_t dst_size,
    unsigned counter_normalized       = 0;
    int line_width_normalized         = line_width * 100;
    int additional_counter_normalized = wideglyph_width - 100;
- 
+
    /* Early return if src string length is less
     * than line width */
    if (src_end - src < line_width)
-   {
-      strlcpy(dst, src, dst_size);
-      return;
-   }
+      return strlcpy(dst, src, dst_size);
 
    while (*src != '\0')
    {
@@ -389,10 +367,7 @@ void word_wrap_wideglyph(char *dst, size_t dst_size,
          /* Early return if remaining src string
           * length is less than line width */
          if (src_end - src <= line_width)
-         {
-            strlcpy(dst, src, dst_size);
-            return;
-         }
+            return strlcpy(dst, src, dst_size);
       }
       else if (char_len >= 3)
       {
@@ -424,10 +399,7 @@ void word_wrap_wideglyph(char *dst, size_t dst_size,
             /* Early return if remaining src string
              * length is less than line width */
             if (src_end - src <= line_width)
-            {
-               strlcpy(dst, src, dst_size);
-               return;
-            }
+               return strlcpy(dst, src, dst_size);
          }
          else if (lastspace)
          {
@@ -442,21 +414,19 @@ void word_wrap_wideglyph(char *dst, size_t dst_size,
             /* Early return if remaining src string
              * length is less than line width */
             if (src_end - src < line_width)
-            {
-               strlcpy(dst, src, dst_size);
-               return;
-            }
+               return strlcpy(dst, src, dst_size);
          }
       }
    }
 
    *dst = '\0';
+   return 0;
 }
 
 /**
  * string_tokenize:
  *
- * Splits string into tokens seperated by @delim
+ * Splits string into tokens separated by @delim
  * > Returned token string must be free()'d
  * > Returns NULL if token is not found
  * > After each call, @str is set to the position after the
@@ -592,7 +562,7 @@ unsigned string_hex_to_unsigned(const char *str)
    if (str[0] != '\0' && str[1] != '\0')
    {
       if ( (str[0] == '0') &&
-          ((str[1] == 'x') || 
+          ((str[1] == 'x') ||
            (str[1] == 'X')))
       {
          hex_str = str + 2;
@@ -635,7 +605,7 @@ int string_count_occurrences_single_character(const char *str, char c)
 
 /**
  * string_replace_whitespace_with_single_character:
- * 
+ *
  * Leaf function.
  *
  * Replaces all spaces with given character @c.
