@@ -66,183 +66,165 @@
 #define _MPF_NIL        0xc0
 
 static const uint8_t MPF_FIXMAP   = _MPF_FIXMAP;
-static const uint8_t MPF_MAP16    = _MPF_MAP16;
 static const uint8_t MPF_MAP32    = _MPF_MAP32;
 
 static const uint8_t MPF_FIXARRAY = _MPF_FIXARRAY;
-static const uint8_t MPF_ARRAY16  = _MPF_ARRAY16;
-static const uint8_t MPF_ARRAY32  = _MPF_ARRAY32;
 
 static const uint8_t MPF_FIXSTR   = _MPF_FIXSTR;
-static const uint8_t MPF_STR8     = _MPF_STR8;
-static const uint8_t MPF_STR16    = _MPF_STR16;
-static const uint8_t MPF_STR32    = _MPF_STR32;
-
-static const uint8_t MPF_BIN8     = _MPF_BIN8;
-static const uint8_t MPF_BIN16    = _MPF_BIN16;
-static const uint8_t MPF_BIN32    = _MPF_BIN32;
-
-static const uint8_t MPF_FALSE    = _MPF_FALSE;
-static const uint8_t MPF_TRUE     = _MPF_TRUE;
-
-static const uint8_t MPF_INT8     = _MPF_INT8;
-static const uint8_t MPF_INT16    = _MPF_INT16;
-static const uint8_t MPF_INT32    = _MPF_INT32;
-static const uint8_t MPF_INT64    = _MPF_INT64;
-
-static const uint8_t MPF_UINT8    = _MPF_UINT8;
-static const uint8_t MPF_UINT16   = _MPF_UINT16;
-static const uint8_t MPF_UINT32   = _MPF_UINT32;
-static const uint8_t MPF_UINT64   = _MPF_UINT64;
 
 static const uint8_t MPF_NIL      = _MPF_NIL;
 
 int rmsgpack_write_array_header(RFILE *fd, uint32_t size)
 {
-   uint16_t tmp_i16;
-   uint32_t tmp_i32;
-
    if (size < 16)
    {
       size = (size | MPF_FIXARRAY);
-      if (filestream_write(fd, &size, sizeof(int8_t)) == -1)
-         return -1;
-      return sizeof(int8_t);
+      if (filestream_write(fd, &size, sizeof(int8_t)) != -1)
+         return sizeof(int8_t);
    }
    else if (size == (uint16_t)size)
    {
-      if (filestream_write(fd, &MPF_ARRAY16, sizeof(MPF_ARRAY16)) == -1)
-         return -1;
-      tmp_i16 = swap_if_little16(size);
-      if (filestream_write(fd, (void *)(&tmp_i16), sizeof(uint16_t)) == -1)
-         return -1;
-      return sizeof(int8_t) + sizeof(uint16_t);
+      static const uint8_t MPF_ARRAY16  = _MPF_ARRAY16;
+      if (filestream_write(fd, &MPF_ARRAY16, sizeof(MPF_ARRAY16)) != -1)
+      {
+         uint16_t tmp_i16 = swap_if_little16(size);
+         if (filestream_write(fd, (void *)(&tmp_i16), sizeof(uint16_t)) != -1)
+            return sizeof(int8_t) + sizeof(uint16_t);
+      }
    }
-
-   if (filestream_write(fd, &MPF_ARRAY32, sizeof(MPF_ARRAY32)) == -1)
-      return -1;
-
-   tmp_i32 = swap_if_little32(size);
-
-   if (filestream_write(fd, (void *)(&tmp_i32), sizeof(uint32_t)) == -1)
-      return -1;
-
-   return sizeof(int8_t) + sizeof(uint32_t);
+   else
+   {
+      static const uint8_t MPF_ARRAY32  = _MPF_ARRAY32;
+      if (filestream_write(fd, &MPF_ARRAY32, sizeof(MPF_ARRAY32)) != -1)
+      {
+         uint32_t tmp_i32 = swap_if_little32(size);
+         if (filestream_write(fd, (void *)(&tmp_i32), sizeof(uint32_t)) != -1)
+            return sizeof(int8_t) + sizeof(uint32_t);
+      }
+   }
+   return -1;
 }
 
 int rmsgpack_write_map_header(RFILE *fd, uint32_t size)
 {
-   uint16_t tmp_i16;
-   uint32_t tmp_i32;
-
    if (size < 16)
    {
       size = (size | MPF_FIXMAP);
-      if (filestream_write(fd, &size, sizeof(int8_t)) == -1)
-         return -1;
-      return sizeof(int8_t);
+      if (filestream_write(fd, &size, sizeof(int8_t)) != -1)
+         return sizeof(int8_t);
    }
    else if (size == (uint16_t)size)
    {
-      if (filestream_write(fd, &MPF_MAP16, sizeof(MPF_MAP16)) == -1)
-         return -1;
-      tmp_i16 = swap_if_little16(size);
-      if (filestream_write(fd, (void *)(&tmp_i16), sizeof(uint16_t)) == -1)
-         return -1;
-      return sizeof(uint8_t) + sizeof(uint16_t);
+      static const uint8_t MPF_MAP16    = _MPF_MAP16;
+      if (filestream_write(fd, &MPF_MAP16, sizeof(MPF_MAP16)) != -1)
+      {
+         uint16_t tmp_i16 = swap_if_little16(size);
+         if (filestream_write(fd, (void *)(&tmp_i16), sizeof(uint16_t)) != -1)
+            return sizeof(uint8_t) + sizeof(uint16_t);
+      }
    }
-
-   tmp_i32 = swap_if_little32(size);
-   if (filestream_write(fd, &MPF_MAP32, sizeof(MPF_MAP32)) == -1)
-      return -1;
-   if (filestream_write(fd, (void *)(&tmp_i32), sizeof(uint32_t)) == -1)
-      return -1;
-
-   return sizeof(int8_t) + sizeof(uint32_t);
+   else
+   {
+      if (filestream_write(fd, &MPF_MAP32, sizeof(MPF_MAP32)) != -1)
+      {
+         uint32_t tmp_i32 = swap_if_little32(size);
+         if (filestream_write(fd, (void *)(&tmp_i32), sizeof(uint32_t)) != -1)
+            return sizeof(int8_t) + sizeof(uint32_t);
+      }
+   }
+   return -1;
 }
 
 int rmsgpack_write_string(RFILE *fd, const char *s, uint32_t len)
 {
-   uint8_t tmp_i8;
-   uint16_t tmp_i16;
-   uint32_t tmp_i32;
-   int written   = sizeof(uint8_t);
-
    if (len < 32)
    {
-      tmp_i8 = len | MPF_FIXSTR;
-      if (filestream_write(fd, &tmp_i8, sizeof(uint8_t)) == -1)
-         return -1;
+      uint8_t tmp_i8 = len | MPF_FIXSTR;
+      if (filestream_write(fd, &tmp_i8, sizeof(uint8_t)) != -1)
+         if (filestream_write(fd, s, len) != -1)
+            return (sizeof(uint8_t) + len);
    }
    else if (len == (uint8_t)len)
    {
-      if (filestream_write(fd, &MPF_STR8, sizeof(MPF_STR8)) == -1)
-         return -1;
-      tmp_i8 = (uint8_t)len;
-      if (filestream_write(fd, &tmp_i8, sizeof(uint8_t)) == -1)
-         return -1;
-      written += sizeof(uint8_t);
+      static const uint8_t MPF_STR8     = _MPF_STR8;
+      if (filestream_write(fd, &MPF_STR8, sizeof(MPF_STR8)) != -1)
+      {
+         uint8_t tmp_i8 = (uint8_t)len;
+         if (filestream_write(fd, &tmp_i8, sizeof(uint8_t)) != -1)
+         {
+            int written = sizeof(uint8_t) + sizeof(uint8_t);
+            if (filestream_write(fd, s, len) != -1)
+               return written + len;
+         }
+      }
    }
    else if (len == (uint16_t)len)
    {
-      if (filestream_write(fd, &MPF_STR16, sizeof(MPF_STR16)) == -1)
-         return -1;
-      tmp_i16 = swap_if_little16(len);
-      if (filestream_write(fd, &tmp_i16, sizeof(uint16_t)) == -1)
-         return -1;
-      written += sizeof(uint16_t);
+      static const uint8_t MPF_STR16    = _MPF_STR16;
+      if (filestream_write(fd, &MPF_STR16, sizeof(MPF_STR16)) != -1)
+      {
+         uint16_t tmp_i16 = swap_if_little16(len);
+         if (filestream_write(fd, &tmp_i16, sizeof(uint16_t)) != -1)
+         {
+            int written = sizeof(uint8_t) + sizeof(uint16_t);
+            if (filestream_write(fd, s, len) != -1)
+               return written + len;
+         }
+      }
    }
    else
    {
-      if (filestream_write(fd, &MPF_STR32, sizeof(MPF_STR32)) == -1)
-         return -1;
-      tmp_i32 = swap_if_little32(len);
-      if (filestream_write(fd, &tmp_i32, sizeof(uint32_t)) == -1)
-         return -1;
-      written += sizeof(uint32_t);
+      static const uint8_t MPF_STR32    = _MPF_STR32;
+      if (filestream_write(fd, &MPF_STR32, sizeof(MPF_STR32)) != -1)
+      {
+         uint32_t tmp_i32 = swap_if_little32(len);
+         if (filestream_write(fd, &tmp_i32, sizeof(uint32_t)) != -1)
+         {
+            int written = sizeof(uint8_t) + sizeof(uint32_t);
+            if (filestream_write(fd, s, len) != -1)
+               return written + len;
+         }
+      }
    }
-
-   if (filestream_write(fd, s, len) == -1)
-      return -1;
-
-   written += len;
-
-   return written;
+   return -1;
 }
 
 int rmsgpack_write_bin(RFILE *fd, const void *s, uint32_t len)
 {
-   uint8_t tmp_i8;
-   uint16_t tmp_i16;
-   uint32_t tmp_i32;
-
    if (len == (uint8_t)len)
    {
-      if (filestream_write(fd, &MPF_BIN8, sizeof(MPF_BIN8)) == -1)
-         return -1;
-      tmp_i8 = (uint8_t)len;
-      if (filestream_write(fd, &tmp_i8, sizeof(uint8_t)) == -1)
-         return -1;
+      static const uint8_t MPF_BIN8     = _MPF_BIN8;
+      if (filestream_write(fd, &MPF_BIN8, sizeof(MPF_BIN8)) != -1)
+      {
+         uint8_t tmp_i8 = (uint8_t)len;
+         if (filestream_write(fd, &tmp_i8, sizeof(uint8_t)) != -1)
+            if (filestream_write(fd, s, len) != -1)
+               return 0;
+      }
    }
    else if (len == (uint16_t)len)
    {
-      if (filestream_write(fd, &MPF_BIN16, sizeof(MPF_BIN16)) == -1)
-         return -1;
-      tmp_i16 = swap_if_little16(len);
-      if (filestream_write(fd, &tmp_i16, sizeof(uint16_t)) == -1)
-         return -1;
+      static const uint8_t MPF_BIN16    = _MPF_BIN16;
+      if (filestream_write(fd, &MPF_BIN16, sizeof(MPF_BIN16)) != -1)
+      {
+         uint16_t tmp_i16 = swap_if_little16(len);
+         if (filestream_write(fd, &tmp_i16, sizeof(uint16_t)) != -1)
+            if (filestream_write(fd, s, len) != -1)
+               return 0;
+      }
    }
    else
    {
-      if (filestream_write(fd, &MPF_BIN32, sizeof(MPF_BIN32)) == -1)
-         return -1;
-      tmp_i32 = swap_if_little32(len);
-      if (filestream_write(fd, &tmp_i32, sizeof(uint32_t)) == -1)
-         return -1;
+      static const uint8_t MPF_BIN32    = _MPF_BIN32;
+      if (filestream_write(fd, &MPF_BIN32, sizeof(MPF_BIN32)) != -1)
+      {
+         uint32_t tmp_i32 = swap_if_little32(len);
+         if (filestream_write(fd, &tmp_i32, sizeof(uint32_t)) != -1)
+            if (filestream_write(fd, s, len) != -1)
+               return 0;
+      }
    }
-   if (filestream_write(fd, s, len) == -1)
-      return -1;
-   return 0;
+   return -1;
 }
 
 int rmsgpack_write_nil(RFILE *fd)
@@ -254,8 +236,10 @@ int rmsgpack_write_nil(RFILE *fd)
 
 int rmsgpack_write_bool(RFILE *fd, int value)
 {
+   static const uint8_t MPF_FALSE    = _MPF_FALSE;
    if (value)
    {
+      static const uint8_t MPF_TRUE  = _MPF_TRUE;
       if (filestream_write(fd, &MPF_TRUE, sizeof(MPF_TRUE)) == -1)
          return -1;
    }
@@ -268,119 +252,108 @@ int rmsgpack_write_bool(RFILE *fd, int value)
 
 int rmsgpack_write_int(RFILE *fd, int64_t value)
 {
-   int8_t tmp_i8;
-   int16_t tmp_i16;
-   int32_t tmp_i32;
-   uint8_t tmpval;
-   int     written = sizeof(uint8_t);
-
    if (value >= 0 && value < 128)
    {
-      tmpval = (uint8_t)value;
-      if (filestream_write(fd, &tmpval, sizeof(uint8_t)) == -1)
-         return -1;
+      uint8_t tmpval = (uint8_t)value;
+      if (filestream_write(fd, &tmpval, sizeof(uint8_t)) != -1)
+         return sizeof(uint8_t);
    }
    else if (value >= -32 && value < 0)
    {
-      tmpval = (uint8_t)(value + 256); /* -32..-1 => 0xE0 .. 0xFF */
-      if (filestream_write(fd, &tmpval, sizeof(uint8_t)) == -1)
-         return -1;
+      uint8_t tmpval = (uint8_t)(value + 256); /* -32..-1 => 0xE0 .. 0xFF */
+      if (filestream_write(fd, &tmpval, sizeof(uint8_t)) != -1)
+         return sizeof(uint8_t);
    }
    else if (value == (int8_t)value)
    {
-      if (filestream_write(fd, &MPF_INT8, sizeof(MPF_INT8)) == -1)
-         return -1;
-
-      tmp_i8 = (int8_t)value;
-      if (filestream_write(fd, &tmp_i8, sizeof(int8_t)) == -1)
-         return -1;
-      written += sizeof(int8_t);
+      static const uint8_t MPF_INT8     = _MPF_INT8;
+      if (filestream_write(fd, &MPF_INT8, sizeof(MPF_INT8)) != -1)
+      {
+         int8_t tmp_i8 = (int8_t)value;
+         if (filestream_write(fd, &tmp_i8, sizeof(int8_t)) != -1)
+            return (sizeof(uint8_t) + sizeof(int8_t));
+      }
    }
    else if (value == (int16_t)value)
    {
-      if (filestream_write(fd, &MPF_INT16, sizeof(MPF_INT16)) == -1)
-         return -1;
-
-      tmp_i16 = swap_if_little16((uint16_t)value);
-      if (filestream_write(fd, &tmp_i16, sizeof(int16_t)) == -1)
-         return -1;
-      written += sizeof(int16_t);
+      static const uint8_t MPF_INT16    = _MPF_INT16;
+      if (filestream_write(fd, &MPF_INT16, sizeof(MPF_INT16)) != -1)
+      {
+         int16_t tmp_i16 = swap_if_little16((uint16_t)value);
+         if (filestream_write(fd, &tmp_i16, sizeof(int16_t)) != -1)
+            return (sizeof(uint8_t) + sizeof(int16_t));
+      }
    }
    else if (value == (int32_t)value)
    {
-      if (filestream_write(fd, &MPF_INT32, sizeof(MPF_INT32)) == -1)
-         return -1;
-
-      tmp_i32 = swap_if_little32((uint32_t)value);
-      if (filestream_write(fd, &tmp_i32, sizeof(int32_t)) == -1)
-         return -1;
-      written += sizeof(int32_t);
+      static const uint8_t MPF_INT32    = _MPF_INT32;
+      if (filestream_write(fd, &MPF_INT32, sizeof(MPF_INT32)) != -1)
+      {
+         int32_t tmp_i32 = swap_if_little32((uint32_t)value);
+         if (filestream_write(fd, &tmp_i32, sizeof(int32_t)) != -1)
+            return (sizeof(uint8_t) + sizeof(int32_t));
+      }
    }
    else
    {
-      if (filestream_write(fd, &MPF_INT64, sizeof(MPF_INT64)) == -1)
-         return -1;
-
-      value = swap_if_little64(value);
-      if (filestream_write(fd, &value, sizeof(int64_t)) == -1)
-         return -1;
-      written += sizeof(int64_t);
+      static const uint8_t MPF_INT64    = _MPF_INT64;
+      if (filestream_write(fd, &MPF_INT64, sizeof(MPF_INT64)) != -1)
+      {
+         value = swap_if_little64(value);
+         if (filestream_write(fd, &value, sizeof(int64_t)) != -1)
+            return (sizeof(uint8_t) + sizeof(int64_t));
+      }
    }
 
-   return written;
+   return -1;
 }
 
 int rmsgpack_write_uint(RFILE *fd, uint64_t value)
 {
-   uint8_t tmp_i8;
-   uint16_t tmp_i16;
-   uint32_t tmp_i32;
-   int written = sizeof(uint8_t);
-
    if (value == (uint8_t)value)
    {
-      if (filestream_write(fd, &MPF_UINT8, sizeof(MPF_UINT8)) == -1)
-         return -1;
-
-      tmp_i8 = (uint8_t)value;
-      if (filestream_write(fd, &tmp_i8, sizeof(uint8_t)) == -1)
-         return -1;
-      written += sizeof(uint8_t);
+      static const uint8_t MPF_UINT8    = _MPF_UINT8;
+      if (filestream_write(fd, &MPF_UINT8, sizeof(MPF_UINT8)) != -1)
+      {
+         uint8_t tmp_i8 = (uint8_t)value;
+         if (filestream_write(fd, &tmp_i8, sizeof(uint8_t)) != -1)
+            return (sizeof(uint8_t) + sizeof(uint8_t));
+      }
    }
    else if (value == (uint16_t)value)
    {
-      if (filestream_write(fd, &MPF_UINT16, sizeof(MPF_UINT16)) == -1)
-         return -1;
-
-      tmp_i16 = swap_if_little16((uint16_t)value);
-      if (filestream_write(fd, &tmp_i16, sizeof(uint16_t)) == -1)
-         return -1;
-      written += sizeof(uint16_t);
+      static const uint8_t MPF_UINT16   = _MPF_UINT16;
+      if (filestream_write(fd, &MPF_UINT16, sizeof(MPF_UINT16)) != -1)
+      {
+         uint16_t tmp_i16 = swap_if_little16((uint16_t)value);
+         if (filestream_write(fd, &tmp_i16, sizeof(uint16_t)) != -1)
+            return (sizeof(uint8_t) + sizeof(uint16_t));
+      }
    }
    else if (value == (uint32_t)value)
    {
-      if (filestream_write(fd, &MPF_UINT32, sizeof(MPF_UINT32)) == -1)
-         return -1;
-
-      tmp_i32 = swap_if_little32((uint32_t)value);
-      if (filestream_write(fd, &tmp_i32, sizeof(uint32_t)) == -1)
-         return -1;
-      written += sizeof(uint32_t);
+      static const uint8_t MPF_UINT32   = _MPF_UINT32;
+      if (filestream_write(fd, &MPF_UINT32, sizeof(MPF_UINT32)) != -1)
+      {
+         uint32_t tmp_i32 = swap_if_little32((uint32_t)value);
+         if (filestream_write(fd, &tmp_i32, sizeof(uint32_t)) != -1)
+            return (sizeof(uint8_t) + sizeof(uint32_t));
+      }
    }
    else
    {
-      if (filestream_write(fd, &MPF_UINT64, sizeof(MPF_UINT64)) == -1)
-         return -1;
-
-      value = swap_if_little64(value);
-      if (filestream_write(fd, &value, sizeof(uint64_t)) == -1)
-         return -1;
-      written += sizeof(uint64_t);
+      static const uint8_t MPF_UINT64   = _MPF_UINT64;
+      if (filestream_write(fd, &MPF_UINT64, sizeof(MPF_UINT64)) != -1)
+      {
+         value = swap_if_little64(value);
+         if (filestream_write(fd, &value, sizeof(uint64_t)) != -1)
+            return (sizeof(uint8_t) + sizeof(uint64_t));
+      }
    }
-   return written;
+   return -1;
 }
 
-static int read_uint(RFILE *fd, uint64_t *out, size_t size)
+static int rmsgpack_read_uint(RFILE *fd, uint64_t *out, size_t size)
 {
    union { uint64_t u64; uint32_t u32; uint16_t u16; uint8_t u8; } tmp;
 
@@ -405,7 +378,7 @@ static int read_uint(RFILE *fd, uint64_t *out, size_t size)
    return 0;
 }
 
-static int read_int(RFILE *fd, int64_t *out, size_t size)
+static int rmsgpack_read_int(RFILE *fd, int64_t *out, size_t size)
 {
    union { uint64_t u64; uint32_t u32; uint16_t u16; uint8_t u8; } tmp;
 
@@ -430,38 +403,38 @@ static int read_int(RFILE *fd, int64_t *out, size_t size)
    return 0;
 }
 
-static int read_buff(RFILE *fd, size_t size, char **pbuff, uint64_t *len)
+static int rmsgpack_read_buff(RFILE *fd, size_t size, char **pbuff, uint64_t *len)
 {
-   uint64_t tmp_len = 0;
-   ssize_t read_len = 0;
+   ssize_t read_len;
+   uint64_t tmp_len   = 0;
 
-   if (read_uint(fd, &tmp_len, size) == -1)
+   if (rmsgpack_read_uint(fd, &tmp_len, size) == -1)
       return -1;
 
-   *pbuff = (char *)malloc((size_t)(tmp_len + 1) * sizeof(char));
+   *pbuff             = (char *)malloc((size_t)(tmp_len + 1) * sizeof(char));
 
-   if ((read_len = filestream_read(fd, *pbuff, (size_t)tmp_len)) == -1)
+   if ((read_len      = filestream_read(fd, *pbuff, (size_t)tmp_len)) == -1)
    {
       free(*pbuff);
       *pbuff = NULL;
       return -1;
    }
 
-   *len = read_len;
+   *len               = read_len;
    (*pbuff)[read_len] = 0;
 
    /* Throw warning on read_len != tmp_len ? */
    return 0;
 }
 
-static int read_map(RFILE *fd, uint32_t len,
+static int rmsgpack_read_map(RFILE *fd, uint32_t len,
         struct rmsgpack_read_callbacks *callbacks, void *data)
 {
    int rv;
    unsigned i;
 
-   if (callbacks->read_map_start &&
-         (rv = callbacks->read_map_start(len, data)) < 0)
+   if (     (     callbacks->read_map_start)
+         && (rv = callbacks->read_map_start(len, data)) < 0)
       return rv;
 
    for (i = 0; i < len; i++)
@@ -475,14 +448,14 @@ static int read_map(RFILE *fd, uint32_t len,
    return 0;
 }
 
-static int read_array(RFILE *fd, uint32_t len,
+static int rmsgpack_read_array(RFILE *fd, uint32_t len,
       struct rmsgpack_read_callbacks *callbacks, void *data)
 {
    int rv;
    unsigned i;
 
-   if (callbacks->read_array_start &&
-         (rv = callbacks->read_array_start(len, data)) < 0)
+   if (     (     callbacks->read_array_start)
+         && (rv = callbacks->read_array_start(len, data)) < 0)
       return rv;
 
    for (i = 0; i < len; i++)
@@ -509,19 +482,19 @@ int rmsgpack_read(RFILE *fd,
 
    if (type < MPF_FIXMAP)
    {
-      if (!callbacks->read_int)
-         return 0;
-      return callbacks->read_int(type, data);
+      if (callbacks->read_int)
+         return callbacks->read_int(type, data);
+      return 0;
    }
    else if (type < MPF_FIXARRAY)
    {
       tmp_len = type - MPF_FIXMAP;
-      return read_map(fd, (uint32_t)tmp_len, callbacks, data);
+      return rmsgpack_read_map(fd, (uint32_t)tmp_len, callbacks, data);
    }
    else if (type < MPF_FIXSTR)
    {
       tmp_len = type - MPF_FIXARRAY;
-      return read_array(fd, (uint32_t)tmp_len, callbacks, data);
+      return rmsgpack_read_array(fd, (uint32_t)tmp_len, callbacks, data);
    }
    else if (type < MPF_NIL)
    {
@@ -535,18 +508,15 @@ int rmsgpack_read(RFILE *fd,
          return -1;
       }
       buff[read_len] = '\0';
-      if (!callbacks->read_string)
-      {
-         free(buff);
-         return 0;
-      }
-      return callbacks->read_string(buff, (uint32_t)read_len, data);
+      if (callbacks->read_string)
+         return callbacks->read_string(buff, (uint32_t)read_len, data);
+      goto end;
    }
    else if (type > MPF_MAP32)
    {
-      if (!callbacks->read_int)
-         return 0;
-      return callbacks->read_int(type - 0xff - 1, data);
+      if (callbacks->read_int)
+         return callbacks->read_int(type - 0xff - 1, data);
+      return 0;
    }
 
    switch (type)
@@ -566,7 +536,7 @@ int rmsgpack_read(RFILE *fd,
       case _MPF_BIN8:
       case _MPF_BIN16:
       case _MPF_BIN32:
-         if ((rv = read_buff(fd, (size_t)(1 << (type - _MPF_BIN8)),
+         if ((rv = rmsgpack_read_buff(fd, (size_t)(1 << (type - _MPF_BIN8)),
                      &buff, &tmp_len)) < 0)
             return rv;
 
@@ -579,7 +549,7 @@ int rmsgpack_read(RFILE *fd,
       case _MPF_UINT64:
          tmp_len  = UINT64_C(1) << (type - _MPF_UINT8);
          tmp_uint = 0;
-         if (read_uint(fd, &tmp_uint, (size_t)tmp_len) == -1)
+         if (rmsgpack_read_uint(fd, &tmp_uint, (size_t)tmp_len) == -1)
             return -1;
 
          if (callbacks->read_uint)
@@ -591,7 +561,7 @@ int rmsgpack_read(RFILE *fd,
       case _MPF_INT64:
          tmp_len = UINT64_C(1) << (type - _MPF_INT8);
          tmp_int = 0;
-         if (read_int(fd, &tmp_int, (size_t)tmp_len) == -1)
+         if (rmsgpack_read_int(fd, &tmp_int, (size_t)tmp_len) == -1)
             return -1;
 
          if (callbacks->read_int)
@@ -600,7 +570,7 @@ int rmsgpack_read(RFILE *fd,
       case _MPF_STR8:
       case _MPF_STR16:
       case _MPF_STR32:
-         if ((rv = read_buff(fd, (size_t)(1 << (type - _MPF_STR8)), &buff, &tmp_len)) < 0)
+         if ((rv = rmsgpack_read_buff(fd, (size_t)(1 << (type - _MPF_STR8)), &buff, &tmp_len)) < 0)
             return rv;
 
          if (callbacks->read_string)
@@ -608,16 +578,17 @@ int rmsgpack_read(RFILE *fd,
          break;
       case _MPF_ARRAY16:
       case _MPF_ARRAY32:
-         if (read_uint(fd, &tmp_len, 2<<(type - _MPF_ARRAY16)) == -1)
-            return -1;
-         return read_array(fd, (uint32_t)tmp_len, callbacks, data);
+         if (rmsgpack_read_uint(fd, &tmp_len, 2<<(type - _MPF_ARRAY16)) != -1)
+            return rmsgpack_read_array(fd, (uint32_t)tmp_len, callbacks, data);
+         return -1;
       case _MPF_MAP16:
       case _MPF_MAP32:
-         if (read_uint(fd, &tmp_len, 2<<(type - _MPF_MAP16)) == -1)
-            return -1;
-         return read_map(fd, (uint32_t)tmp_len, callbacks, data);
+         if (rmsgpack_read_uint(fd, &tmp_len, 2<<(type - _MPF_MAP16)) != -1)
+            return rmsgpack_read_map(fd, (uint32_t)tmp_len, callbacks, data);
+         return -1;
    }
 
+end:
    if (buff)
       free(buff);
    return 0;
