@@ -21,6 +21,7 @@
 
 #include <boolean.h>
 #include <retro_common_api.h>
+#include <retro_miscellaneous.h>
 
 #include <lists/file_list.h>
 
@@ -30,7 +31,7 @@
 
 RETRO_BEGIN_DECLS
 
-#define MENU_SUBLABEL_MAX_LENGTH 1024
+#define MENU_LABEL_MAX_LENGTH 512
 
 #define MENU_SEARCH_FILTER_MAX_TERMS  8
 #define MENU_SEARCH_FILTER_MAX_LENGTH 64
@@ -112,12 +113,12 @@ typedef struct menu_entry
    enum msg_hash_enums enum_idx;
    uint8_t setting_type;
    uint8_t flags;
-   char sublabel[MENU_SUBLABEL_MAX_LENGTH];
-   char path[255];
-   char label[255];
-   char rich_label[255];
-   char value[255];
-   char password_value[255];
+   char sublabel[MENU_LABEL_MAX_LENGTH];
+   char path[NAME_MAX_LENGTH];
+   char label[MENU_LABEL_MAX_LENGTH];
+   char rich_label[MENU_LABEL_MAX_LENGTH];
+   char value[NAME_MAX_LENGTH];
+   char password_value[NAME_MAX_LENGTH];
 } menu_entry_t;
 
 typedef struct menu_file_list_cbs
@@ -155,12 +156,12 @@ typedef struct menu_file_list_cbs
          char *path_buf, size_t path_buf_size);
    menu_search_terms_t search;
    enum msg_hash_enums enum_idx;
-   char action_sublabel_cache[MENU_SUBLABEL_MAX_LENGTH];
+   char action_sublabel_cache[MENU_LABEL_MAX_LENGTH];
    char action_title_cache   [512];
    bool checked;
 } menu_file_list_cbs_t;
 
-int menu_entries_get_title(char *title, size_t title_len);
+size_t menu_entries_get_title(char *s, size_t len);
 
 void menu_entries_get_core_title(char *title_msg, size_t title_msg_len);
 
