@@ -218,17 +218,17 @@ static void ex_arena_free(ex_arena *arena)
 
 /* Hash function */
 static uint32_t ex_hash32_nocase_filtered(
-      const unsigned char* str, size_t len,
+      const unsigned char *s, size_t len,
       unsigned char f_first, unsigned char f_last)
 {
    const unsigned char *end = NULL;
    uint32_t hash            = (uint32_t)0x811c9dc5;
-   for (end = str + len; str != end;)
+   for (end = s + len; s != end;)
    {
-      unsigned char c = *(str++);
+      unsigned char c = *(s++);
       if (c >= f_first && c <= f_last)
-         hash = ((hash * (uint32_t)0x01000193) 
-               ^ (uint32_t)((c >= 'A' && c <= 'Z') 
+         hash = ((hash * (uint32_t)0x01000193)
+               ^ (uint32_t)((c >= 'A' && c <= 'Z')
                   ? (c | 0x20) : c));
    }
    if (hash)
@@ -316,7 +316,7 @@ static void explore_add_unique_string(
 
    for (p = str + 1;; p++)
    {
-      size_t len              = 0;
+      size_t _len              = 0;
       uint32_t hash           = 0;
       explore_string_t* entry = NULL;
 
@@ -346,18 +346,18 @@ static void explore_add_unique_string(
             p--;
       }
 
-      len                     = p - str;
+      _len                    = p - str;
       hash                    = ex_hash32_nocase_filtered(
-            (unsigned char*)str, len, '0', 255);
+            (unsigned char*)str, _len, '0', 255);
       entry                   = RHMAP_GET(maps[cat], hash);
 
       if (!entry)
       {
          entry                = (explore_string_t*)
             ex_arena_alloc(&state->arena,
-                  sizeof(explore_string_t) + len);
-         memcpy(entry->str, str, len);
-         entry->str[len]      = '\0';
+                  sizeof(explore_string_t) + _len);
+         memcpy(entry->str, str, _len);
+         entry->str[_len]      = '\0';
          RBUF_PUSH(state->by[cat], entry);
          RHMAP_SET(maps[cat], hash, entry);
       }
@@ -400,7 +400,7 @@ static void explore_unload_icons(explore_state_t *state)
 static void explore_load_icons(explore_state_t *state)
 {
    char path[PATH_MAX_LENGTH];
-   size_t i, pathlen, system_count;
+   size_t i, _len, system_count;
    if (!state)
       return;
 
@@ -410,7 +410,7 @@ static void explore_load_icons(explore_state_t *state)
    /* unload any icons that could exist from a previous call to this */
    explore_unload_icons(state);
 
-   /* RBUF_RESIZE leaves memory uninitialised, 
+   /* RBUF_RESIZE leaves memory uninitialised,
       have to zero it 'manually' */
    RBUF_RESIZE(state->icons, system_count);
    memset(state->icons, 0, RBUF_SIZEOF(state->icons));
@@ -420,17 +420,16 @@ static void explore_load_icons(explore_state_t *state)
    if (string_is_empty(path))
       return;
 
-   fill_pathname_slash(path, sizeof(path));
-   pathlen = strlen(path);
+   _len = fill_pathname_slash(path, sizeof(path));
 
    for (i = 0; i != system_count; i++)
    {
       struct texture_image ti;
-      size_t _len = pathlen;
-      _len       += strlcpy(path       + pathlen,
+      size_t __len = _len;
+      __len       += strlcpy(path + _len,
                  state->by[EXPLORE_BY_SYSTEM][i]->str,
-                 sizeof(path) - pathlen);
-      strlcpy(path + _len, ".png", sizeof(path) - _len);
+                 sizeof(path)     - _len);
+      strlcpy(path + __len, ".png", sizeof(path) - __len);
       if (!path_is_valid(path))
          continue;
 
@@ -466,7 +465,7 @@ explore_state_t *menu_explore_build_list(const char *directory_playlist,
       struct explore_source *playlist_crcs;
       struct explore_source *playlist_names;
       size_t count;
-      char systemname[256];
+      char systemname[NAME_MAX_LENGTH];
    }
    *rdbs                                          = NULL;
    int *rdb_indices                               = NULL;
@@ -479,7 +478,7 @@ explore_state_t *menu_explore_build_list(const char *directory_playlist,
    if (!state)
       return NULL;
 
-   state->label_explore_item_str    = 
+   state->label_explore_item_str    =
       msg_hash_to_str(MENU_ENUM_LABEL_EXPLORE_ITEM);
 
    /* Index all playlists */
@@ -572,7 +571,7 @@ explore_state_t *menu_explore_build_list(const char *directory_playlist,
                   tmp, directory_database, db_name, sizeof(tmp));
 
             /* Replace the extension - change 'lpl' to 'rdb' */
-            if ((    ext_path = path_get_extension_mutable(tmp)) 
+            if ((    ext_path = path_get_extension_mutable(tmp))
                   && ext_path[0] == '.'
                   && ext_path[1] == 'l'
                   && ext_path[2] == 'p'
@@ -621,14 +620,14 @@ explore_state_t *menu_explore_build_list(const char *directory_playlist,
          playlist_free(playlist);
    }
 
-   /* Loop through all RDBs referenced in the playlists 
+   /* Loop through all RDBs referenced in the playlists
     * and load meta data strings */
    for (i = 0; i != RBUF_LEN(rdbs); i++)
    {
       struct rmsgpack_dom_value item;
       struct explore_rdb* rdb  = &rdbs[i];
       libretrodb_cursor_t *cur = libretrodb_cursor_new();
-      bool more                = 
+      bool more                =
          (
           libretrodb_cursor_open(rdb->handle, cur, NULL) == 0
           && libretrodb_cursor_read_item(cur, &item) == 0);
@@ -769,22 +768,22 @@ explore_state_t *menu_explore_build_list(const char *directory_playlist,
 #ifdef EXPLORE_SHOW_ORIGINAL_TITLE
          if (original_title && *original_title)
          {
-            size_t len        = strlen(original_title) + 1;
+            size_t _len       = strlen(original_title) + 1;
             e->original_title = (char*)
-               ex_arena_alloc(&state->arena, len);
-            memcpy(e->original_title, original_title, len);
+               ex_arena_alloc(&state->arena, _len);
+            memcpy(e->original_title, original_title, _len);
          }
 #endif
 
          if (RBUF_LEN(split_buf))
          {
-            size_t len;
+            size_t _len;
 
             RBUF_PUSH(split_buf, NULL); /* terminator */
-            len        = RBUF_SIZEOF(split_buf);
+            _len       = RBUF_SIZEOF(split_buf);
             e->split   = (explore_string_t **)
-               ex_arena_alloc(&state->arena, len);
-            memcpy(e->split, split_buf, len);
+               ex_arena_alloc(&state->arena, _len);
+            memcpy(e->split, split_buf, _len);
             RBUF_CLEAR(split_buf);
          }
 
@@ -810,14 +809,14 @@ explore_state_t *menu_explore_build_list(const char *directory_playlist,
    for (i = 0; i != EXPLORE_CAT_COUNT; i++)
    {
       uint32_t idx;
-      size_t len = RBUF_LEN(state->by[i]);
+      size_t _len = RBUF_LEN(state->by[i]);
 
       if (state->by[i])
-         qsort(state->by[i], len, sizeof(*state->by[i]),
+         qsort(state->by[i], _len, sizeof(*state->by[i]),
                (explore_by_info[i].is_numeric ?
                   explore_qsort_func_nums : explore_qsort_func_strings));
 
-      for (idx = 0; idx != len; idx++)
+      for (idx = 0; idx != _len; idx++)
          state->by[i][idx]->idx = idx;
 
       RHMAP_FREE(cat_maps[i]);
@@ -834,19 +833,18 @@ static int explore_action_get_title(
       const char *path, const char *label,
       unsigned menu_type, char *s, size_t len)
 {
-   strlcpy(s, (explore_state ? explore_state->title : 
+   strlcpy(s, (explore_state ? explore_state->title :
       msg_hash_to_str(MENU_ENUM_LABEL_VALUE_EXPLORE_TAB)), len);
    return 0;
 }
 
-static void explore_append_title(explore_state_t *state,
+static void explore_append_title(char *s, size_t len,
       const char* fmt, ...)
 {
    va_list ap;
-   size_t len = strlen(state->title);
+   size_t _len = strlen(s);
    va_start(ap, fmt);
-   vsnprintf(state->title + len,
-         sizeof(state->title) - len, fmt, ap);
+   vsnprintf(s + _len, len - _len, fmt, ap);
    va_end(ap);
 }
 
@@ -895,7 +893,7 @@ static int explore_action_ok(const char *path, const char *label,
             state->view_op[lvl] = EXPLORE_OP_EQUAL;
             state->view_use_split[lvl] = explore_by_info[cat].use_split;
             state->view_cats[lvl] = cat;
-            state->view_match[lvl] = (type == EXPLORE_TYPE_FILTERNULL ? 
+            state->view_match[lvl] = (type == EXPLORE_TYPE_FILTERNULL ?
                   NULL : state->by[cat][type-EXPLORE_TYPE_FIRSTITEM]);
             state->view_levels++;
          }
@@ -1013,8 +1011,8 @@ static const char* explore_get_view_path(struct menu_state *menu_st, menu_list_t
 
    /* check if we are opening a saved view via Content > Playlists */
    if (    (cur->type == MENU_EXPLORE_TAB)
-         && cur->path 
-         && !string_is_equal(cur->path, 
+         && cur->path
+         && !string_is_equal(cur->path,
             msg_hash_to_str(MENU_ENUM_LABEL_GOTO_EXPLORE))
       )
       return cur->path;
@@ -1024,13 +1022,12 @@ static const char* explore_get_view_path(struct menu_state *menu_st, menu_list_t
 
 static void explore_on_edit_views(enum msg_hash_enums msg)
 {
+   const char           *_msg = msg_hash_to_str(msg);
    struct menu_state *menu_st = menu_state_get_ptr();
    if (menu_st->driver_ctx->environ_cb)
       menu_st->driver_ctx->environ_cb(MENU_ENVIRON_RESET_HORIZONTAL_LIST,
                NULL, menu_st->userdata);
-
-   runloop_msg_queue_push(msg_hash_to_str(msg),
-         1, 180, true, NULL,
+   runloop_msg_queue_push(_msg, strlen(_msg), 1, 180, true, NULL,
          MESSAGE_QUEUE_ICON_DEFAULT, MESSAGE_QUEUE_CATEGORY_INFO);
 }
 
@@ -1072,15 +1069,14 @@ static void explore_action_saveview_complete(void *userdata, const char *name)
 
    if (filestream_exists(lvwpath))
    {
-      runloop_msg_queue_push(msg_hash_to_str(MENU_ENUM_LABEL_EXPLORE_VIEW_EXISTS),
-            1, 360, true, NULL,
+      const char *_msg = msg_hash_to_str(MENU_ENUM_LABEL_EXPLORE_VIEW_EXISTS);
+      runloop_msg_queue_push(_msg, strlen(_msg), 1, 360, true, NULL,
             MESSAGE_QUEUE_ICON_DEFAULT, MESSAGE_QUEUE_CATEGORY_ERROR);
       return;
    }
 
-   file = intfstream_open_file(lvwpath,
-         RETRO_VFS_FILE_ACCESS_WRITE, RETRO_VFS_FILE_ACCESS_HINT_NONE);
-   if (!file)
+   if (!(file = intfstream_open_file(lvwpath,
+         RETRO_VFS_FILE_ACCESS_WRITE, RETRO_VFS_FILE_ACCESS_HINT_NONE)))
    {
       RARCH_ERR("[explore view] Failed to write json file %s.\n", lvwpath);
       return;
@@ -1217,7 +1213,7 @@ static void explore_load_view(explore_state_t *state, const char* path)
       {
          const char* key = rjson_get_string(json, NULL);
          for (cat = 0; cat != EXPLORE_CAT_COUNT; cat++)
-            if (string_is_equal(key, explore_by_info[cat].rdbkey)) 
+            if (string_is_equal(key, explore_by_info[cat].rdbkey))
                break;
          if (cat == EXPLORE_CAT_COUNT)
             rjson_next(json); /* skip value */
@@ -1228,7 +1224,7 @@ static void explore_load_view(explore_state_t *state, const char* path)
             unsigned lvl, lvl_max      = state->view_levels;
             uint8_t valid_op           = ((uint8_t)-1);
             type                       = rjson_next(json);
-            if (     type == RJSON_STRING 
+            if (     type == RJSON_STRING
                   || type == RJSON_NUMBER)
                value = rjson_get_string(json, NULL);
             if (value && !*value)
@@ -1274,14 +1270,14 @@ static void explore_load_view(explore_state_t *state, const char* path)
                else if (op == EXPLORE_OP_MIN)
                {
                   state->view_idx_min[lvl] = (cmp ? i + 1 : i);
-                  valid_op                 = 
+                  valid_op                 =
                      ((lvl != lvl_max && state->view_op[lvl] == EXPLORE_OP_MAX)
                       ? EXPLORE_OP_RANGE : EXPLORE_OP_MIN);
                }
                else if (op == EXPLORE_OP_MAX)
                {
                   state->view_idx_max[lvl] = i;
-                  valid_op                 = 
+                  valid_op                 =
                      ((lvl != lvl_max && state->view_op[lvl] == EXPLORE_OP_MIN)
                       ? EXPLORE_OP_RANGE : EXPLORE_OP_MAX);
                }
@@ -1292,7 +1288,7 @@ static void explore_load_view(explore_state_t *state, const char* path)
                state->view_cats     [lvl] = cat;
                state->view_use_split[lvl] = explore_by_info[cat].use_split;
                if (lvl == lvl_max)
-                  state->view_levels++; 
+                  state->view_levels++;
             }
          }
       }
@@ -1368,27 +1364,27 @@ unsigned menu_displaylist_explore(file_list_t *list, settings_t *settings)
       unsigned cat               = state->view_cats[i];
       explore_string_t **entries = state->by[cat];
       explore_string_t *match    = state->view_match[i];
-      explore_append_title(state, "%s%s: ", (i ? " / " : ""),
+      explore_append_title(state->title, sizeof(state->title), "%s%s: ", (i ? " / " : ""),
             msg_hash_to_str(explore_by_info[cat].name_enum));
       switch (state->view_op[i])
       {
          case EXPLORE_OP_EQUAL:
-            explore_append_title(state, "%s", (match 
+            explore_append_title(state->title, sizeof(state->title), "%s", (match
                   ? match->str
                   : msg_hash_to_str(MENU_ENUM_LABEL_VALUE_UNKNOWN)));
             break;
          case EXPLORE_OP_MIN:
-            explore_append_title(state, "%s - %s",
+            explore_append_title(state->title, sizeof(state->title), "%s - %s",
                   entries[state->view_idx_min[i]]->str,
                   entries[RBUF_LEN(entries)-1]->str);
             break;
          case EXPLORE_OP_MAX:
-            explore_append_title(state, "%s - %s",
+            explore_append_title(state->title, sizeof(state->title), "%s - %s",
                   entries[0]->str,
                   entries[state->view_idx_max[i]]->str);
             break;
          case EXPLORE_OP_RANGE:
-            explore_append_title(state, "%s - %s",
+            explore_append_title(state->title, sizeof(state->title), "%s - %s",
                   entries[state->view_idx_min[i]]->str,
                   entries[state->view_idx_max[i]]->str);
             break;
@@ -1397,7 +1393,7 @@ unsigned menu_displaylist_explore(file_list_t *list, settings_t *settings)
 
    /* append string search to title */
    if (*state->view_search)
-      explore_append_title(state, "%s%s: '%s'",
+      explore_append_title(state->title, sizeof(state->title), "%s%s: '%s'",
             (state->view_levels ? " / " : ""),
             msg_hash_to_str(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_NAME),
             state->view_search);
@@ -1408,7 +1404,7 @@ unsigned menu_displaylist_explore(file_list_t *list, settings_t *settings)
                ? EXPLORE_ICONS_CONTENT
                : EXPLORE_ICONS_OFF;
 
-   if (     current_type == MENU_EXPLORE_TAB 
+   if (     current_type == MENU_EXPLORE_TAB
          || current_type == EXPLORE_TYPE_ADDITIONALFILTER)
    {
       /* Explore top or selecting an additional filter category */
@@ -1419,7 +1415,7 @@ unsigned menu_displaylist_explore(file_list_t *list, settings_t *settings)
                msg_hash_to_str(MENU_ENUM_LABEL_VALUE_EXPLORE_TAB),
                sizeof(state->title));
       else
-         explore_append_title(state, " / %s",
+         explore_append_title(state->title, sizeof(state->title), " / %s",
                msg_hash_to_str(MENU_ENUM_LABEL_VALUE_EXPLORE_ADDITIONAL_FILTER));
 
       if (!*state->view_search)
@@ -1489,7 +1485,7 @@ unsigned menu_displaylist_explore(file_list_t *list, settings_t *settings)
       if (is_top)
       {
          if (list->size)
-            ((menu_file_list_cbs_t*)list->list[list->size-1].actiondata)->action_sublabel = 
+            ((menu_file_list_cbs_t*)list->list[list->size-1].actiondata)->action_sublabel =
                explore_action_sublabel_spacer;
          explore_menu_entry(list, state,
                msg_hash_to_str(MENU_ENUM_LABEL_VALUE_EXPLORE_SHOW_ALL),
@@ -1509,14 +1505,14 @@ unsigned menu_displaylist_explore(file_list_t *list, settings_t *settings)
       if (state->has_unknown[current_cat])
       {
          if (list->size)
-            ((menu_file_list_cbs_t*)list->list[list->size-1].actiondata)->action_sublabel = 
+            ((menu_file_list_cbs_t*)list->list[list->size-1].actiondata)->action_sublabel =
                explore_action_sublabel_spacer;
          explore_menu_entry(list, state,
                msg_hash_to_str(MENU_ENUM_LABEL_VALUE_UNKNOWN),
                EXPLORE_TYPE_FILTERNULL, explore_action_ok);
       }
 
-      explore_append_title(state, "%s",
+      explore_append_title(state->title, sizeof(state->title), "%s",
             msg_hash_to_str(explore_by_info[current_cat].by_enum));
    }
    else if (current_type < EXPLORE_TYPE_FIRSTITEM
@@ -1540,19 +1536,19 @@ unsigned menu_displaylist_explore(file_list_t *list, settings_t *settings)
       bool filtered_category_have_unknown = false;
 
       if (is_show_all)
-         explore_append_title(state,
+         explore_append_title(state->title, sizeof(state->title),
                msg_hash_to_str(MENU_ENUM_LABEL_VALUE_EXPLORE_ALL));
 
       if (is_filtered_category)
       {
          /* List filtered items in a selected explore by category */
          if (!view_levels || view_cats[view_levels - 1] != current_cat)
-            explore_append_title(state, " / %s",
+            explore_append_title(state->title, sizeof(state->title), " / %s",
                   msg_hash_to_str(explore_by_info[current_cat].by_enum));
          else
          {
             /* List all items again when setting a range filter */
-            explore_append_title(state, " (%s)",
+            explore_append_title(state->title, sizeof(state->title), " (%s)",
                   msg_hash_to_str(MENU_ENUM_LABEL_EXPLORE_RANGE_FILTER));
             view_levels--;
          }
@@ -1569,7 +1565,7 @@ unsigned menu_displaylist_explore(file_list_t *list, settings_t *settings)
                msg_hash_to_str(MENU_ENUM_LABEL_EXPLORE_DELETE_VIEW),
                EXPLORE_TYPE_VIEW, explore_action_ok_deleteview);
          if (list->size)
-            ((menu_file_list_cbs_t*)list->list[list->size-1].actiondata)->action_sublabel = 
+            ((menu_file_list_cbs_t*)list->list[list->size-1].actiondata)->action_sublabel =
                explore_action_sublabel_spacer;
       }
       else
@@ -1587,7 +1583,7 @@ unsigned menu_displaylist_explore(file_list_t *list, settings_t *settings)
                msg_hash_to_str(MENU_ENUM_LABEL_EXPLORE_SAVE_VIEW),
                EXPLORE_TYPE_VIEW, explore_action_ok_saveview);
          if (list->size)
-            ((menu_file_list_cbs_t*)list->list[list->size-1].actiondata)->action_sublabel = 
+            ((menu_file_list_cbs_t*)list->list[list->size-1].actiondata)->action_sublabel =
                explore_action_sublabel_spacer;
       }
 
@@ -1607,7 +1603,7 @@ unsigned menu_displaylist_explore(file_list_t *list, settings_t *settings)
                      explore_string_t** split = e->split;
                      do
                      {
-                        if (*split == view_match[i]) 
+                        if (*split == view_match[i])
                            break;
                      } while (*(++split));
                      if (*split)
@@ -1662,13 +1658,13 @@ SKIP_ENTRY:;
          qsort(list->list, list->size, sizeof(*list->list),
                explore_qsort_func_menulist);
 
-      explore_append_title(state,
+      explore_append_title(state->title, sizeof(state->title),
             " (%u)", (unsigned)(list->size - first_list_entry));
 
       if (is_filtered_category && filtered_category_have_unknown)
       {
          if (list->size)
-            ((menu_file_list_cbs_t*)list->list[list->size-1].actiondata)->action_sublabel = 
+            ((menu_file_list_cbs_t*)list->list[list->size-1].actiondata)->action_sublabel =
                explore_action_sublabel_spacer;
          explore_menu_entry(list, state,
                msg_hash_to_str(MENU_ENUM_LABEL_VALUE_UNKNOWN),
@@ -1681,17 +1677,16 @@ SKIP_ENTRY:;
    {
       /* Content page of selected game */
       int pl_idx;
-      const struct playlist_entry *pl_entry = 
+      const struct playlist_entry *pl_entry =
          state->entries[current_type - EXPLORE_TYPE_FIRSTITEM].playlist_entry;
 
-      strlcpy(state->title,
-            pl_entry->label, sizeof(state->title));
+      strlcpy(state->title, pl_entry->label, sizeof(state->title));
 
       for (pl_idx = 0; pl_idx != (int)RBUF_LEN(state->playlists); pl_idx++)
       {
          menu_displaylist_info_t          info;
          const struct playlist_entry *pl_first = NULL;
-         playlist_t                       *pl  = 
+         playlist_t                       *pl  =
             state->playlists[pl_idx];
 
          playlist_get_index(pl, 0, &pl_first);
@@ -1700,7 +1695,7 @@ SKIP_ENTRY:;
                || (pl_entry >= pl_first + playlist_size(pl)))
             continue;
 
-         /* Fake all the state so the content screen 
+         /* Fake all the state so the content screen
           * and information screen think we're viewing via playlist */
          menu_displaylist_info_init(&info);
          playlist_set_cached_external(pl);
@@ -1720,7 +1715,7 @@ SKIP_ENTRY:;
 uintptr_t menu_explore_get_entry_icon(unsigned type)
 {
    unsigned i;
-   if (     !explore_state 
+   if (     !explore_state
          || !explore_state->show_icons
          || (type < EXPLORE_TYPE_FIRSTITEM))
       return 0;
@@ -1747,7 +1742,7 @@ ssize_t menu_explore_get_entry_playlist_index(unsigned type,
    int              pl_idx;
    explore_entry_t* entry;
 
-   if (     !explore_state 
+   if (     !explore_state
          || (type < EXPLORE_TYPE_FIRSTITEM)
          || (explore_state->show_icons != EXPLORE_ICONS_CONTENT))
       return -1;
@@ -1773,7 +1768,7 @@ ssize_t menu_explore_get_entry_playlist_index(unsigned type,
       if (playlist_entry)
          *playlist_entry = entry->playlist_entry;
 
-      /* correct numbers of list pos and list size */ 
+      /* correct numbers of list pos and list size */
       if (list && list_pos && list_size)
          while (*list_size && list->list[list->size-*list_size].type < EXPLORE_TYPE_FIRSTITEM)
             { (*list_size)--; (*list_pos)--; }
@@ -1793,7 +1788,7 @@ ssize_t menu_explore_set_playlist_thumbnail(unsigned type,
    ssize_t playlist_index = -1;
    playlist_t *playlist   = NULL;
 
-   if (     !explore_state 
+   if (     !explore_state
          || (type < EXPLORE_TYPE_FIRSTITEM)
          || (explore_state->show_icons != EXPLORE_ICONS_CONTENT))
       return -1;
