@@ -12,6 +12,7 @@ if [ "$HAVE_C99" = 'no' ]; then
 fi
 
 check_switch cxx CXX11 -std=c++11 ''
+check_switch cxx CXX17 -std=c++17 ''
 check_switch '' NOUNUSED -Wno-unused-result ''
 check_switch '' NOUNUSED_VARIABLE -Wno-unused-variable ''
 
@@ -268,6 +269,7 @@ check_pkgconf RSOUND rsound 1.1
 check_pkgconf ROAR libroar 1.0.12
 check_val '' JACK -ljack '' jack 0.120.1 '' false
 check_val '' PULSE -lpulse '' libpulse '' '' false
+check_val '' PIPEWIRE -lpipewire-0.3 '' libpipewire-0.3 '' '' false
 check_val '' SDL -lSDL SDL sdl 1.2.10 '' false
 check_val '' SDL2 -lSDL2 SDL2 sdl2 2.0.0 '' false
 
@@ -277,27 +279,59 @@ if [ "$HAVE_SDL2" = 'yes' ] && [ "$HAVE_SDL" = 'yes' ]; then
 fi
 
 check_enabled CXX11 CXX C++ 'C++11 support is' false
+check_enabled CXX17 CXX C++ 'C++17 support is' false
 
 check_platform Haiku DISCORD 'Discord is' false
 check_enabled CXX DISCORD discord 'The C++ compiler is' false
 check_enabled CXX QT 'Qt companion' 'The C++ compiler is' false
 
 if [ "$HAVE_QT" != 'no' ]; then
-   check_pkgconf QT5CORE Qt5Core 5.2
-   check_pkgconf QT5GUI Qt5Gui 5.2
-   check_pkgconf QT5WIDGETS Qt5Widgets 5.2
-   check_pkgconf QT5CONCURRENT Qt5Concurrent 5.2
-   check_pkgconf QT5NETWORK Qt5Network 5.2
-   #check_pkgconf QT5WEBENGINE Qt5WebEngine 5.4
+   _have_qt=$HAVE_QT
+   if [ "$HAVE_CXX17" = 'yes' ]; then
+      check_pkgconf QT6CORE Qt6Core 6.2
+      check_pkgconf QT6GUI Qt6Gui 6.2
+      check_pkgconf QT6WIDGETS Qt6Widgets 6.2
+      check_pkgconf QT6CONCURRENT Qt6Concurrent 6.2
+      check_pkgconf QT6NETWORK Qt6Network 6.2
+      #check_pkgconf QT6WEBENGINE Qt6WebEngine 6.2
 
-   # pkg-config is needed to reliably find Qt5 libraries.
+      # pkg-config is needed to reliably find Qt6 libraries.
 
-   check_enabled QT5CORE QT Qt 'Qt5Core is' true
-   check_enabled QT5GUI QT Qt 'Qt5GUI is' true
-   check_enabled QT5WIDGETS QT Qt 'Qt5Widgets is' true
-   check_enabled QT5CONCURRENT QT Qt 'Qt5Concurrent is' true
-   check_enabled QT5NETWORK QT Qt 'Qt5Network is' true
-   #check_enabled QT5WEBENGINE QT Qt 'Qt5Webengine is' true
+      check_enabled QT6CORE QT Qt 'Qt6Core is' user
+      check_enabled QT6GUI QT Qt 'Qt6GUI is' user
+      check_enabled QT6WIDGETS QT Qt 'Qt6Widgets is' user
+      check_enabled QT6CONCURRENT QT Qt 'Qt6Concurrent is' user
+      check_enabled QT6NETWORK QT Qt 'Qt6Network is' user
+      #check_enabled QT6WEBENGINE QT Qt 'Qt6Webengine is' user
+
+      if [ "$HAVE_QT6CORE" == 'yes' ] && \
+         [ "$HAVE_QT6GUI" == 'yes' ] &&  \
+         [ "$HAVE_QT6WIDGETS" == 'yes' ] &&  \
+         [ "$HAVE_QT6CONCURRENT" == 'yes' ] && \
+         [ "$HAVE_QT6NETWORK" == 'yes' ]
+      then
+         HAVE_QT6='yes'
+         add_define MAKEFILE HAVE_QT6 1
+      fi
+   fi
+   if [ "$HAVE_QT6" != 'yes' ]; then
+      HAVE_QT=$_have_qt
+      check_pkgconf QT5CORE Qt5Core 5.2
+      check_pkgconf QT5GUI Qt5Gui 5.2
+      check_pkgconf QT5WIDGETS Qt5Widgets 5.2
+      check_pkgconf QT5CONCURRENT Qt5Concurrent 5.2
+      check_pkgconf QT5NETWORK Qt5Network 5.2
+      #check_pkgconf QT5WEBENGINE Qt6WebEngine 5.2
+
+      # pkg-config is needed to reliably find Qt5 libraries.
+
+      check_enabled QT5CORE QT Qt 'Qt5Core is' true
+      check_enabled QT5GUI QT Qt 'Qt5GUI is' true
+      check_enabled QT5WIDGETS QT Qt 'Qt5Widgets is' true
+      check_enabled QT5CONCURRENT QT Qt 'Qt5Concurrent is' true
+      check_enabled QT5NETWORK QT Qt 'Qt5Network is' true
+      #check_enabled QT5WEBENGINE QT Qt 'Qt5Webengine is' true
+   fi
 
    if [ "$HAVE_QT" != yes ]; then
       die : 'Notice: Qt support disabled, required libraries were not found.'
@@ -316,16 +350,15 @@ check_enabled SSL BUILTINMBEDTLS 'builtin mbedtls' 'ssl is' false
 check_enabled SSL BUILTINBEARSSL 'builtin bearssl' 'ssl is' false
 
 if [ "$HAVE_SYSTEMMBEDTLS" = "auto" ]; then SYSTEMMBEDTLS_IS_AUTO=yes; else SYSTEMMBEDTLS_IS_AUTO=no; fi
-check_lib '' SYSTEMMBEDTLS '-lmbedtls -lmbedx509 -lmbedcrypto'
-check_header '' SYSTEMMBEDTLS \
-   mbedtls/config.h \
-   mbedtls/certs.h \
-   mbedtls/debug.h \
-   mbedtls/platform.h \
-   mbedtls/net_sockets.h \
-   mbedtls/ssl.h \
-   mbedtls/ctr_drbg.h \
-   mbedtls/entropy.h
+check_val '' SYSTEMMBEDTLS '-lmbedtls' 'mbedtls' mbedtls 2.5.1 '' true
+check_val '' SYSTEMMBEDX509 '-lmbedx509' 'mbedtls' mbedx509 2.5.1 '' true
+check_val '' SYSTEMMBEDCRYPTO '-lmbedcrypto' 'mbedtls' mbedcrypto 2.5.1 '' true
+if [ "$HAVE_SYSTEMMBEDTLS" = 'yes' ] && [ -z "$SYSTEMMBEDTLS_VERSION" ]; then
+  # Ancient versions (such as the one included in the Ubuntu version used for
+  # build checks) don't have this header
+  check_header '' SYSTEMMBEDTLS mbedtls/net_sockets.h
+fi
+if [ "$HAVE_SYSTEMMBEDX509" = 'no' ] || [ "$HAVE_SYSTEMMBEDCRYPTO" = 'no' ]; then HAVE_SYSTEMMBEDTLS=no; fi
 if [ "$SYSTEMMBEDTLS_IS_AUTO" = "yes" ] && [ "$HAVE_SYSTEMMBEDTLS" = "yes" ]; then HAVE_SYSTEMMBEDTLS=auto; fi
 
 SSL_BACKEND_CHOSEN=no
@@ -400,6 +433,10 @@ if [ "$HAVE_OPENGL" != 'no' ] && [ "$HAVE_OPENGLES" != 'yes' ]; then
    elif [ "$OS" = 'Win32' ]; then
       check_header '' OPENGL "GL/gl.h"
       check_lib '' OPENGL -lopengl32
+   elif [ "$HAVE_GLX" = 'no' ]; then
+      # Use vendor-neutral OpenGL implementation instead of GLX
+      check_header '' OPENGL "GL/gl.h"
+      check_lib '' OPENGL -lOpenGL
    else
       check_header '' OPENGL "GL/gl.h"
       check_lib '' OPENGL -lGL
@@ -505,6 +542,7 @@ if [ "$HAVE_X11" != 'no' ]; then
    check_val '' XCB -lxcb '' xcb '' '' false
    check_val '' XEXT -lXext '' xext '' '' false
    check_val '' XF86VM -lXxf86vm '' xxf86vm '' '' false
+   check_val '' XSCRNSAVER -lXss '' xscrnsaver '' '' false
 else
    die : 'Notice: X11 not present. Skipping X11 code paths.'
 fi
@@ -523,7 +561,7 @@ check_header '' XSHM X11/Xlib.h X11/extensions/XShm.h
 check_val '' XKBCOMMON -lxkbcommon '' xkbcommon 0.3.2 '' false
 check_val '' WAYLAND '-lwayland-egl -lwayland-client' '' wayland-egl 10.1.0 '' false
 check_val '' WAYLAND_CURSOR -lwayland-cursor '' wayland-cursor 1.12 '' false
-check_pkgconf WAYLAND_PROTOS wayland-protocols 1.31
+check_pkgconf WAYLAND_PROTOS wayland-protocols 1.32
 check_pkgconf WAYLAND_SCANNER wayland-scanner '1.15 1.12'
 
 if [ "$HAVE_WAYLAND_SCANNER" = yes ] &&
