@@ -92,6 +92,7 @@ HAVE_OPENGLES3_1=no        # OpenGLES3.1 support
 HAVE_OPENGLES3_2=no        # OpenGLES3.2 support
 HAVE_X11=auto              # everything X11.
 HAVE_XRANDR=auto           # Xrandr support.
+HAVE_XSCRNSAVER=auto       # Xss support.
 HAVE_OMAP=no               # OMAP video support
 HAVE_XINERAMA=auto         # Xinerama support.
 HAVE_KMS=auto              # KMS context support
@@ -123,6 +124,7 @@ HAVE_AL=no                 # OpenAL support
 HAVE_JACK=auto             # JACK support
 HAVE_COREAUDIO=auto        # CoreAudio support
 HAVE_COREAUDIO3=no         # CoreAudio3 support
+HAVE_PIPEWIRE=auto         # PipeWire support
 HAVE_PULSE=auto            # PulseAudio support
 C89_PULSE=no
 HAVE_FREETYPE=auto         # FreeType support
@@ -182,6 +184,7 @@ HAVE_VIDEOCORE=auto        # Broadcom Videocore 4 support
 HAVE_DRMINGW=no            # DrMingw exception handler
 HAVE_CDROM=auto            # CD-ROM support
 HAVE_GLSL=yes              # GLSL shaders support
+HAVE_GLX=auto              # GLX support (set this to 'off' for vendor-neutral OpenGL impl)
 HAVE_SLANG=auto            # slang support
 C89_SLANG=no
 HAVE_GLSLANG=auto          # glslang support (requires C++11)
