@@ -5,6 +5,7 @@
 #include <boolean.h>
 #include <retro_inline.h>
 #include <retro_common_api.h>
+#include <retro_miscellaneous.h>
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -127,6 +128,7 @@ enum rarch_override_setting
    RARCH_OVERRIDE_SETTING_LIBRETRO_DEVICE,
    RARCH_OVERRIDE_SETTING_LOG_TO_FILE,
    RARCH_OVERRIDE_SETTING_DATABASE_SCAN,
+   RARCH_OVERRIDE_SETTING_OVERLAY_PRESET,
    RARCH_OVERRIDE_SETTING_LAST
 };
 
@@ -183,7 +185,7 @@ typedef struct rarch_system_info
    unsigned rotation;
    unsigned core_requested_rotation;
    unsigned performance_level;
-   char valid_extensions[255];
+   char valid_extensions[256];
    bool load_no_content;
    bool supports_vfs;
 } rarch_system_info_t;
@@ -249,11 +251,16 @@ struct rarch_main_wrap
 };
 
 /* All run-time- / command line flag-related globals go here. */
+enum global_flags
+{
+   GLOB_FLG_ERR_ON_INIT          = (1 << 0),
+   GLOB_FLG_LAUNCHED_FROM_CLI    = (1 << 1),
+   GLOB_FLG_CLI_LOAD_MENU_ON_ERR = (1 << 2)
+};
 
 typedef struct global
 {
-   jmp_buf error_sjlj_context;              /* 4-byte alignment,
-                                               put it right before long */
+   jmp_buf error_sjlj_context; /* 4-byte alignment, put it right before long */
 
    /* Settings and/or global state that is specific to
     * a console-style implementation. */
@@ -289,10 +296,8 @@ typedef struct global
 
    } console;
 
-   char error_string[255];
-   bool launched_from_cli;
-   bool cli_load_menu_on_error;
-   bool error_on_init;
+   char error_string[NAME_MAX_LENGTH];
+   uint8_t flags;
 } global_t;
 
 typedef struct content_file_override
@@ -340,7 +345,7 @@ typedef struct content_state
    uint8_t flags;
 
    char companion_ui_crc32[32];
-   char pending_subsystem_ident[255];
+   char pending_subsystem_ident[NAME_MAX_LENGTH];
    char pending_rom_crc_path[PATH_MAX_LENGTH];
    char companion_ui_db_name[PATH_MAX_LENGTH];
 } content_state_t;
