@@ -258,7 +258,7 @@ static const blissbox_pad_type_t* input_autoconfigure_get_blissbox_pad_type_win3
          /* Check for some other error */
          if (!bResult)
          {
-            if (     (ERROR_INSUFFICIENT_BUFFER == GetLastError()) 
+            if (     (ERROR_INSUFFICIENT_BUFFER == GetLastError())
                   && (required_length > 0))
             {
                /* we got the size, now allocate buffer */
@@ -354,8 +354,11 @@ found:
 
       if (hDeviceHandle == INVALID_HANDLE_VALUE)
       {
+         /* TODO/FIXME - localize */
+         const char *_msg = "Bliss-Box already in use. Please make sure other programs are not using it.";
          RARCH_ERR("[Autoconf]: Can't open device for reading and writing: %d.", GetLastError());
-         runloop_msg_queue_push("Bliss-Box already in use. Please make sure other programs are not using it.", 2, 300, false, NULL, MESSAGE_QUEUE_ICON_DEFAULT, MESSAGE_QUEUE_CATEGORY_INFO);
+         runloop_msg_queue_push(_msg, strlen(_msg), 2, 300, false, NULL,
+               MESSAGE_QUEUE_ICON_DEFAULT, MESSAGE_QUEUE_CATEGORY_INFO);
          goto done;
       }
    }
