@@ -188,6 +188,7 @@ static void task_manual_content_scan_free(retro_task_t *task)
 
 static void task_manual_content_scan_handler(retro_task_t *task)
 {
+   uint8_t flg;
    manual_scan_handle_t *manual_scan = NULL;
 
    if (!task)
@@ -196,7 +197,9 @@ static void task_manual_content_scan_handler(retro_task_t *task)
    if (!(manual_scan = (manual_scan_handle_t*)task->state))
       goto task_finished;
 
-   if (task_get_cancelled(task))
+   flg = task_get_flags(task);
+
+   if ((flg & RETRO_TASK_FLG_CANCELLED) > 0)
       goto task_finished;
 
    switch (manual_scan->status)
@@ -213,10 +216,9 @@ static void task_manual_content_scan_handler(retro_task_t *task)
                      = manual_content_scan_get_content_list(
                         manual_scan->task_config)))
             {
-               runloop_msg_queue_push(
-                     msg_hash_to_str(MSG_MANUAL_CONTENT_SCAN_INVALID_CONTENT),
-                     1, 100, true,
-                     NULL, MESSAGE_QUEUE_ICON_DEFAULT, MESSAGE_QUEUE_CATEGORY_INFO);
+               const char *_msg = msg_hash_to_str(MSG_MANUAL_CONTENT_SCAN_INVALID_CONTENT);
+               runloop_msg_queue_push(_msg, strlen(_msg), 1, 100, true, NULL,\
+                     MESSAGE_QUEUE_ICON_DEFAULT, MESSAGE_QUEUE_CATEGORY_INFO);
                goto task_finished;
             }
 
@@ -229,10 +231,9 @@ static void task_manual_content_scan_handler(retro_task_t *task)
                      logiqx_dat_init(
                         manual_scan->task_config->dat_file_path)))
                {
-                  runloop_msg_queue_push(
-                        msg_hash_to_str(MSG_MANUAL_CONTENT_SCAN_DAT_FILE_LOAD_ERROR),
-                        1, 100, true,
-                        NULL, MESSAGE_QUEUE_ICON_DEFAULT, MESSAGE_QUEUE_CATEGORY_INFO);
+                  const char *_msg = msg_hash_to_str(MSG_MANUAL_CONTENT_SCAN_DAT_FILE_LOAD_ERROR);
+                  runloop_msg_queue_push(_msg, strlen(_msg), 1, 100, true, NULL,
+                        MESSAGE_QUEUE_ICON_DEFAULT, MESSAGE_QUEUE_CATEGORY_INFO);
                   goto task_finished;
                }
             }
@@ -508,9 +509,8 @@ static void task_manual_content_scan_handler(retro_task_t *task)
    return;
 
 task_finished:
-
    if (task)
-      task_set_finished(task, true);
+      task_set_flags(task, RETRO_TASK_FLG_FINISHED, true);
 }
 
 static bool task_manual_content_scan_finder(retro_task_t *task, void *user_data)
@@ -568,13 +568,12 @@ bool task_push_manual_content_scan(
          calloc(1, sizeof(manual_content_scan_task_config_t))))
       goto error;
 
-   if ( !manual_content_scan_get_task_config(
+   if (!manual_content_scan_get_task_config(
          manual_scan->task_config, playlist_directory))
    {
-      runloop_msg_queue_push(
-            msg_hash_to_str(MSG_MANUAL_CONTENT_SCAN_INVALID_CONFIG),
-            1, 100, true,
-            NULL, MESSAGE_QUEUE_ICON_DEFAULT, MESSAGE_QUEUE_CATEGORY_INFO);
+      const char *_msg = msg_hash_to_str(MSG_MANUAL_CONTENT_SCAN_INVALID_CONFIG);
+      runloop_msg_queue_push(_msg, strlen(_msg), 1, 100, true, NULL,
+            MESSAGE_QUEUE_ICON_DEFAULT, MESSAGE_QUEUE_CATEGORY_INFO);
       goto error;
    }
 
@@ -611,10 +610,10 @@ bool task_push_manual_content_scan(
    task->handler                 = task_manual_content_scan_handler;
    task->state                   = manual_scan;
    task->title                   = strdup(task_title);
-   task->alternative_look        = true;
    task->progress                = 0;
    task->callback                = cb_task_manual_content_scan;
    task->cleanup                 = task_manual_content_scan_free;
+   task->flags                  |= RETRO_TASK_FLG_ALTERNATIVE_LOOK;
 
    /* > Push task */
    task_queue_push(task);
