@@ -20,7 +20,6 @@
 #include <retro_miscellaneous.h>
 #include <file/file_path.h>
 #include <file/config_file.h>
-#include <lists/string_list.h>
 #include <streams/file_stream.h>
 #include <string/stdstring.h>
 #include <lrc_hash.h>
@@ -125,7 +124,6 @@ static void task_overlay_desc_populate_eightway_config(
    size_t _len;
    input_driver_state_t *input_st = input_state_get_ptr();
    overlay_eightway_config_t *eightway;
-   char conf_key_base[20];
    char conf_key[64];
    char *str;
 
@@ -163,11 +161,10 @@ static void task_overlay_desc_populate_eightway_config(
          return;
    }
 
-   snprintf(conf_key_base, sizeof(conf_key_base), "overlay%u_desc%u", ol_idx, desc_idx);
+   _len = snprintf(conf_key, sizeof(conf_key), "overlay%u_desc%u", ol_idx, desc_idx);
 
    /* Redefine eightway vals if specified in conf
     */
-   _len = strlcpy(conf_key, conf_key_base, sizeof(conf_key));
    strlcpy(conf_key + _len, "_up", sizeof(conf_key) - _len);
    if (config_get_string(loader->conf, conf_key, &str))
    {
@@ -233,12 +230,20 @@ static bool task_overlay_load_desc(
    char overlay_desc_key[32];
    char overlay_key[64];
    char overlay[256];
+   char *tok, *save;
+   unsigned list_size                   = 0;
+   char *elem0                          = NULL;
+   char *elem1                          = NULL;
+   char *elem2                          = NULL;
+   char *elem3                          = NULL;
+   char *elem4                          = NULL;
+   char *elem5                          = NULL;
+   char *overlay_cpy                    = NULL;
    float tmp_float                      = 0.0f;
    bool tmp_bool                        = false;
    bool ret                             = true;
    bool by_pixel                        = false;
    char *key                            = NULL;
-   struct string_list list              = {0};
    const char *x                        = NULL;
    const char *y                        = NULL;
    const char *box                      = NULL;
@@ -273,25 +278,50 @@ static bool task_overlay_load_desc(
       goto end;
    }
 
-   string_list_initialize(&list);
-   if (!string_split_noalloc(&list, overlay, ", "))
+   overlay_cpy = strdup(overlay);
+   if ((tok = strtok_r(overlay_cpy, ", ", &save)))
    {
-      RARCH_ERR("[Overlay]: Failed to split overlay desc.\n");
-      ret = false;
-      goto end;
+      elem0 = strdup(tok);
+      list_size++;
    }
+   if ((tok = strtok_r(NULL, ", ", &save)))
+   {
+      elem1 = strdup(tok);
+      list_size++;
+   }
+   if ((tok = strtok_r(NULL, ", ", &save)))
+   {
+      elem2 = strdup(tok);
+      list_size++;
+   }
+   if ((tok = strtok_r(NULL, ", ", &save))) /* box */
+   {
+      elem3 = strdup(tok);
+      list_size++;
+   }
+   if ((tok = strtok_r(NULL, ", ", &save)))
+   {
+      elem4 = strdup(tok);
+      list_size++;
+   }
+   if ((tok = strtok_r(NULL, ", ", &save)))
+   {
+      elem5 = strdup(tok);
+      list_size++;
+   }
+   free(overlay_cpy);
 
-   if (list.size < 6)
+   if (list_size < 6)
    {
       RARCH_ERR("[Overlay]: Overlay desc is invalid. Requires at least 6 tokens.\n");
       ret = false;
       goto end;
    }
 
-   key            = list.elems[0].data;
-   x              = list.elems[1].data;
-   y              = list.elems[2].data;
-   box            = list.elems[3].data;
+   key                 = elem0;
+   x                   = elem1;
+   y                   = elem2;
+   box                 = elem3;
 
    desc->retro_key_idx = 0;
    BIT256_CLEAR_ALL(desc->button_mask);
@@ -390,8 +420,8 @@ static bool task_overlay_load_desc(
          break;
    }
 
-   desc->range_x = (float)strtod(list.elems[4].data, NULL) * width_mod;
-   desc->range_y = (float)strtod(list.elems[5].data, NULL) * height_mod;
+   desc->range_x = (float)strtod(elem4, NULL) * width_mod;
+   desc->range_y = (float)strtod(elem5, NULL) * height_mod;
 
    _len = strlcpy(conf_key, overlay_desc_key, sizeof(conf_key));
 
@@ -471,7 +501,18 @@ static bool task_overlay_load_desc(
    input_overlay->pos ++;
 
 end:
-   string_list_deinitialize(&list);
+   if (elem0)
+      free(elem0);
+   if (elem1)
+      free(elem1);
+   if (elem2)
+      free(elem2);
+   if (elem3)
+      free(elem3);
+   if (elem4)
+      free(elem4);
+   if (elem5)
+      free(elem5);
    return ret;
 }
 
@@ -537,7 +578,7 @@ static void task_overlay_resolve_iterate(retro_task_t *task)
             loader->resolve_pos, loader->size))
    {
       RARCH_ERR("[Overlay]: Failed to resolve next targets.\n");
-      task_set_cancelled(task, true);
+      task_set_flags(task, RETRO_TASK_FLG_CANCELLED, true);
       loader->state   = OVERLAY_STATUS_DEFERRED_ERROR;
       return;
    }
@@ -604,7 +645,7 @@ static void task_overlay_deferred_loading(retro_task_t *task)
                {
                   RARCH_ERR("[Overlay]: Failed to load overlay descs for overlay #%u.\n",
                         (unsigned)overlay->pos);
-                  task_set_cancelled(task, true);
+                  task_set_flags(task, RETRO_TASK_FLG_CANCELLED, true);
                   loader->state   = OVERLAY_STATUS_DEFERRED_ERROR;
                   break;
                }
@@ -625,7 +666,7 @@ static void task_overlay_deferred_loading(retro_task_t *task)
          loader->loading_status = OVERLAY_IMAGE_TRANSFER_NONE;
          break;
       case OVERLAY_IMAGE_TRANSFER_ERROR:
-         task_set_cancelled(task, true);
+         task_set_flags(task, RETRO_TASK_FLG_CANCELLED, true);
          loader->state   = OVERLAY_STATUS_DEFERRED_ERROR;
          break;
    }
@@ -640,7 +681,6 @@ static void task_overlay_deferred_load(retro_task_t *task)
    for (i = 0; i < loader->pos_increment; i++, loader->pos++)
    {
       size_t _len;
-      char conf_key_base[10];
       char conf_key[32];
       char tmp_str[PATH_MAX_LENGTH];
       float tmp_float                   = 0.0;
@@ -661,8 +701,7 @@ static void task_overlay_deferred_load(retro_task_t *task)
 
       overlay = &loader->overlays[loader->pos];
 
-      snprintf(conf_key_base, sizeof(conf_key_base), "overlay%u", loader->pos);
-      _len = strlcpy(conf_key, conf_key_base,  sizeof(conf_key));
+      _len = snprintf(conf_key, sizeof(conf_key), "overlay%u", loader->pos);
 
       strlcpy(conf_key + _len, "_rect", sizeof(conf_key) - _len);
       strlcpy(overlay->config.rect.key, conf_key,
@@ -799,25 +838,55 @@ static void task_overlay_deferred_load(retro_task_t *task)
       if (config_get_array(conf, overlay->config.rect.key,
                overlay->config.rect.array, sizeof(overlay->config.rect.array)))
       {
-         struct string_list  list = {0};
+         char *tok, *save;
+         char *elem0              = NULL;
+         char *elem1              = NULL;
+         char *elem2              = NULL;
+         char *elem3              = NULL;
+         unsigned list_size       = 0;
+         char *cfg_rect_array_cpy = strdup(overlay->config.rect.array);
 
-         string_list_initialize(&list);
+         if ((tok = strtok_r(cfg_rect_array_cpy, ", ", &save)))
+         {
+            elem0 = strdup(tok);
+            list_size++;
+         }
+         if ((tok = strtok_r(NULL, ", ", &save)))
+         {
+            elem1 = strdup(tok);
+            list_size++;
+         }
+         if ((tok = strtok_r(NULL, ", ", &save)))
+         {
+            elem2 = strdup(tok);
+            list_size++;
+         }
+         if ((tok = strtok_r(NULL, ", ", &save)))
+         {
+            elem3 = strdup(tok);
+            list_size++;
+         }
+         free(cfg_rect_array_cpy);
 
-         if (     !string_split_noalloc(
-                  &list, overlay->config.rect.array, ", ")
-               || list.size < 4)
+         if (list_size < 4)
          {
             RARCH_ERR("[Overlay]: Failed to split rect \"%s\" into at least four tokens.\n",
                   overlay->config.rect.array);
-            string_list_deinitialize(&list);
+            free(elem0);
+            free(elem1);
+            free(elem2);
+            free(elem3);
             goto error;
          }
 
-         overlay->x = (float)strtod(list.elems[0].data, NULL);
-         overlay->y = (float)strtod(list.elems[1].data, NULL);
-         overlay->w = (float)strtod(list.elems[2].data, NULL);
-         overlay->h = (float)strtod(list.elems[3].data, NULL);
-         string_list_deinitialize(&list);
+         overlay->x = (float)strtod(elem0, NULL);
+         overlay->y = (float)strtod(elem1, NULL);
+         overlay->w = (float)strtod(elem2, NULL);
+         overlay->h = (float)strtod(elem3, NULL);
+         free(elem0);
+         free(elem1);
+         free(elem2);
+         free(elem3);
       }
 
       /* Assume for now that scaling center is in the middle.
@@ -869,7 +938,8 @@ static void task_overlay_deferred_load(retro_task_t *task)
    return;
 
 error:
-   task_set_cancelled(task, true);
+   if (task)
+      task_set_flags(task, RETRO_TASK_FLG_CANCELLED, true);
    loader->pos     = 0;
    loader->state   = OVERLAY_STATUS_DEFERRED_ERROR;
 }
@@ -879,8 +949,9 @@ static void task_overlay_free(retro_task_t *task)
    unsigned i;
    overlay_loader_t *loader  = (overlay_loader_t*)task->state;
    struct overlay *overlay   = &loader->overlays[loader->pos];
+   uint8_t flg               = task_get_flags(task);
 
-   if (task_get_cancelled(task))
+   if ((flg & RETRO_TASK_FLG_CANCELLED) > 0)
    {
       if (loader->overlay_path)
          free(loader->overlay_path);
@@ -905,6 +976,7 @@ static void task_overlay_free(retro_task_t *task)
 
 static void task_overlay_handler(retro_task_t *task)
 {
+   uint8_t flg;
    overlay_loader_t *loader  = (overlay_loader_t*)task->state;
 
    switch (loader->state)
@@ -919,16 +991,19 @@ static void task_overlay_handler(retro_task_t *task)
          task_overlay_resolve_iterate(task);
          break;
       case OVERLAY_STATUS_DEFERRED_ERROR:
-         task_set_cancelled(task, true);
+         task_set_flags(task, RETRO_TASK_FLG_CANCELLED, true);
          break;
       case OVERLAY_STATUS_DEFERRED_DONE:
       default:
       case OVERLAY_STATUS_NONE:
-         task_set_finished(task, true);
+         task_set_flags(task, RETRO_TASK_FLG_FINISHED, true);
          break;
    }
 
-   if (task_get_finished(task) && !task_get_cancelled(task))
+   flg = task_get_flags(task);
+
+   if (       ((flg & RETRO_TASK_FLG_FINISHED)  > 0)
+         && (!((flg & RETRO_TASK_FLG_CANCELLED) > 0)))
    {
       overlay_task_data_t *data = (overlay_task_data_t*)
          calloc(1, sizeof(*data));
@@ -947,17 +1022,10 @@ static void task_overlay_handler(retro_task_t *task)
 static bool task_overlay_finder(retro_task_t *task, void *user_data)
 {
    overlay_loader_t *loader = NULL;
-
-   if (!task || (task->handler != task_overlay_handler))
+   if (!task || (task->handler != task_overlay_handler) || !user_data)
       return false;
-
-   if (!user_data)
+   if (!(loader = (overlay_loader_t*)task->state))
       return false;
-
-   loader = (overlay_loader_t*)task->state;
-   if (!loader)
-      return false;
-
    return string_is_equal(loader->overlay_path, (const char*)user_data);
 }
 
@@ -995,7 +1063,7 @@ bool task_push_overlay_load_default(
 
    if (!config_get_uint(conf, "overlays", &loader->size))
    {
-      /* Error - overlays varaible not defined in config. */
+      /* Error - overlays variable not defined in config. */
       config_file_free(conf);
       free(loader);
       return false;
