@@ -15,9 +15,10 @@
  *  If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include <stdio.h>
+#include <stdint.h>
 #include <stdlib.h>
 #include <string.h>
-#include <stdio.h>
 #include <ctype.h>
 
 #include <string/stdstring.h>
@@ -27,7 +28,6 @@
 
 #include "tasks_internal.h"
 
-#include "../configuration.h"
 #include "../msg_hash.h"
 #include "../file_path_special.h"
 #include "../playlist.h"
@@ -66,25 +66,25 @@ static void free_pl_manager_handle(pl_manager_handle_t *pl_manager)
 {
    if (!pl_manager)
       return;
-   
+
    if (pl_manager->m3u_list)
    {
       string_list_free(pl_manager->m3u_list);
       pl_manager->m3u_list = NULL;
    }
-   
+
    if (!string_is_empty(pl_manager->playlist_name))
    {
       free(pl_manager->playlist_name);
       pl_manager->playlist_name = NULL;
    }
-   
+
    if (pl_manager->playlist)
    {
       playlist_free(pl_manager->playlist);
       pl_manager->playlist = NULL;
    }
-   
+
    free(pl_manager);
    pl_manager = NULL;
 }
@@ -149,19 +149,22 @@ static void task_pl_manager_free(retro_task_t *task)
 
 static void task_pl_manager_reset_cores_handler(retro_task_t *task)
 {
+   uint8_t flg;
    pl_manager_handle_t *pl_manager = NULL;
-   
+
    if (!task)
       goto task_finished;
-   
+
    pl_manager = (pl_manager_handle_t*)task->state;
-   
+
    if (!pl_manager)
       goto task_finished;
-   
-   if (task_get_cancelled(task))
+
+   flg = task_get_flags(task);
+
+   if ((flg & RETRO_TASK_FLG_CANCELLED) > 0)
       goto task_finished;
-   
+
    switch (pl_manager->status)
    {
       case PL_MANAGER_BEGIN:
@@ -185,45 +188,41 @@ static void task_pl_manager_reset_cores_handler(retro_task_t *task)
       case PL_MANAGER_ITERATE_ENTRY_RESET_CORE:
          {
             const struct playlist_entry *entry = NULL;
-            
+
             /* Get current entry */
             playlist_get_index(
                   pl_manager->playlist, pl_manager->list_index, &entry);
-            
+
             if (entry)
             {
+               size_t _len;
+               char task_title[128];
                struct playlist_entry update_entry = {0};
-               char task_title[PATH_MAX_LENGTH];
                /* Update progress display */
                task_free_title(task);
-               strlcpy(
-                     task_title,
-		     msg_hash_to_str(MSG_PLAYLIST_MANAGER_RESETTING_CORES),
+               _len = strlcpy(task_title,
+                     msg_hash_to_str(MSG_PLAYLIST_MANAGER_RESETTING_CORES),
                      sizeof(task_title));
-               
+
                if (!string_is_empty(entry->label))
-                  strlcat(task_title, entry->label, sizeof(task_title));
+                  strlcpy(task_title + _len, entry->label, sizeof(task_title) - _len);
                else if (!string_is_empty(entry->path))
-               {
-                  char entry_name[PATH_MAX_LENGTH];
-                  fill_pathname_base(entry_name, entry->path, sizeof(entry_name));
-                  path_remove_extension(entry_name);
-                  strlcat(task_title, entry_name, sizeof(task_title));
-               }
-               
+                  fill_pathname(task_title + _len, path_basename(entry->path), "",
+                        sizeof(task_title) - _len);
+
                task_set_title(task, strdup(task_title));
                task_set_progress(task, (pl_manager->list_index * 100) / pl_manager->list_size);
-               
+
                /* Reset core association
                 * > The update function reads our entry as const,
                 *   so these casts are safe */
                update_entry.core_path = (char*)"DETECT";
                update_entry.core_name = (char*)"DETECT";
-               
+
                playlist_update(
                      pl_manager->playlist, pl_manager->list_index, &update_entry);
             }
-            
+
             /* Increment entry index */
             pl_manager->list_index++;
             if (pl_manager->list_index >= pl_manager->list_size)
@@ -232,16 +231,17 @@ static void task_pl_manager_reset_cores_handler(retro_task_t *task)
          break;
       case PL_MANAGER_END:
          {
-            char task_title[PATH_MAX_LENGTH];
+            size_t _len;
+            char task_title[128];
             /* Save playlist changes to disk */
             playlist_write_file(pl_manager->playlist);
             /* Update progress display */
             task_free_title(task);
-            strlcpy(
-                  task_title, msg_hash_to_str(MSG_PLAYLIST_MANAGER_CORES_RESET),
+            _len = strlcpy(task_title,
+                  msg_hash_to_str(MSG_PLAYLIST_MANAGER_CORES_RESET),
                   sizeof(task_title));
-            strlcat(task_title, pl_manager->playlist_name, sizeof(task_title));
-            
+            strlcpy(task_title + _len, pl_manager->playlist_name, sizeof(task_title) - _len);
+
             task_set_title(task, strdup(task_title));
          }
          /* fall-through */
@@ -249,38 +249,38 @@ static void task_pl_manager_reset_cores_handler(retro_task_t *task)
          task_set_progress(task, 100);
          goto task_finished;
    }
-   
+
    return;
-   
+
 task_finished:
-   
    if (task)
-      task_set_finished(task, true);
+      task_set_flags(task, RETRO_TASK_FLG_FINISHED, true);
 }
 
 static bool task_pl_manager_reset_cores_finder(
       retro_task_t *task, void *user_data)
 {
    pl_manager_handle_t *pl_manager = NULL;
-   
+
    if (!task || !user_data)
       return false;
-   
+
    if (task->handler != task_pl_manager_reset_cores_handler)
       return false;
-   
+
    if (!(pl_manager = (pl_manager_handle_t*)task->state))
       return false;
-   
+
    return string_is_equal((const char*)user_data,
          pl_manager->playlist_config.path);
 }
 
 bool task_push_pl_manager_reset_cores(const playlist_config_t *playlist_config)
 {
+   size_t _len;
    task_finder_data_t find_data;
-   char playlist_name[PATH_MAX_LENGTH];
-   char task_title[PATH_MAX_LENGTH];
+   char task_title[128];
+   char playlist_name[NAME_MAX_LENGTH];
    retro_task_t *task              = task_init();
    pl_manager_handle_t *pl_manager = (pl_manager_handle_t*)
       calloc(1, sizeof(pl_manager_handle_t));
@@ -289,26 +289,26 @@ bool task_push_pl_manager_reset_cores(const playlist_config_t *playlist_config)
       goto error;
    if (string_is_empty(playlist_config->path))
       goto error;
-   
-   fill_pathname_base(playlist_name,
-         playlist_config->path, sizeof(playlist_name));
-   path_remove_extension(playlist_name);
-   
+
+   fill_pathname(playlist_name,
+         path_basename(playlist_config->path), "",
+         sizeof(playlist_name));
+
    if (string_is_empty(playlist_name))
       goto error;
-   
+
    /* Concurrent management of the same playlist
     * is not allowed */
    find_data.func                = task_pl_manager_reset_cores_finder;
    find_data.userdata            = (void*)playlist_config->path;
-   
+
    if (task_queue_find(&find_data))
       goto error;
-   
+
    /* Configure handle */
    if (!playlist_config_copy(playlist_config, &pl_manager->playlist_config))
       goto error;
-   
+
    pl_manager->playlist_name       = strdup(playlist_name);
    pl_manager->playlist            = NULL;
    pl_manager->list_size           = 0;
@@ -316,37 +316,37 @@ bool task_push_pl_manager_reset_cores(const playlist_config_t *playlist_config)
    pl_manager->m3u_list            = NULL;
    pl_manager->m3u_index           = 0;
    pl_manager->status              = PL_MANAGER_BEGIN;
-   
+
    /* Configure task */
-   strlcpy(
-         task_title,
-	 msg_hash_to_str(MSG_PLAYLIST_MANAGER_RESETTING_CORES),
+   _len = strlcpy(task_title,
+         msg_hash_to_str(MSG_PLAYLIST_MANAGER_RESETTING_CORES),
          sizeof(task_title));
-   strlcat(task_title, playlist_name, sizeof(task_title));
-   
+   strlcpy(task_title + _len, playlist_name, sizeof(task_title) - _len);
+
    task->handler                 = task_pl_manager_reset_cores_handler;
    task->state                   = pl_manager;
    task->title                   = strdup(task_title);
-   task->alternative_look        = true;
    task->progress                = 0;
    task->callback                = cb_task_pl_manager;
    task->cleanup                 = task_pl_manager_free;
-   
+
+   task->flags                  |= (RETRO_TASK_FLG_ALTERNATIVE_LOOK);
+
    task_queue_push(task);
-   
+
    return true;
-   
+
 error:
-   
+
    if (task)
    {
       free(task);
       task = NULL;
    }
-   
+
    free_pl_manager_handle(pl_manager);
    pl_manager = NULL;
-   
+
    return false;
 }
 
@@ -359,17 +359,17 @@ static void pl_manager_validate_core_association(
       const char *core_path, const char *core_name)
 {
    struct playlist_entry update_entry = {0};
-   
+
    /* Sanity check */
    if (!playlist)
       return;
-   
+
    if (entry_index >= playlist_size(playlist))
       return;
-   
+
    if (string_is_empty(core_path))
       goto reset_core;
-   
+
    /* Handle 'DETECT' entries */
    if (string_is_equal(core_path, "DETECT"))
    {
@@ -387,22 +387,22 @@ static void pl_manager_validate_core_association(
       goto reset_core;
    else
    {
-      char core_display_name[PATH_MAX_LENGTH];
+      char core_display_name[NAME_MAX_LENGTH];
       core_info_t *core_info = NULL;
-      
+
       /* Search core info */
-      if (core_info_find(core_path, &core_info) &&
-          !string_is_empty(core_info->display_name))
+      if (    core_info_find(core_path, &core_info)
+          && !string_is_empty(core_info->display_name))
          strlcpy(core_display_name, core_info->display_name,
                sizeof(core_display_name));
       else
          core_display_name[0] = '\0';
-      
+
       /* If core_display_name string is empty, it means the
        * core wasn't found -> reset association */
       if (string_is_empty(core_display_name))
          goto reset_core;
-      
+
       /* ...Otherwise, check that playlist entry
        * core name is correct */
       if (!string_is_equal(core_name, core_display_name))
@@ -411,33 +411,36 @@ static void pl_manager_validate_core_association(
          playlist_update(playlist, entry_index, &update_entry);
       }
    }
-   
+
    return;
-   
+
 reset_core:
    /* The update function reads our entry as const,
     * so these casts are safe */
    update_entry.core_path = (char*)"DETECT";
    update_entry.core_name = (char*)"DETECT";
-   
+
    playlist_update(playlist, entry_index, &update_entry);
 }
 
 static void task_pl_manager_clean_playlist_handler(retro_task_t *task)
 {
+   uint8_t flg;
    pl_manager_handle_t *pl_manager = NULL;
-   
+
    if (!task)
       goto task_finished;
-   
+
    pl_manager = (pl_manager_handle_t*)task->state;
-   
+
    if (!pl_manager)
       goto task_finished;
-   
-   if (task_get_cancelled(task))
+
+   flg        = task_get_flags(task);
+
+   if ((flg & RETRO_TASK_FLG_CANCELLED) > 0)
       goto task_finished;
-   
+
    switch (pl_manager->status)
    {
       case PL_MANAGER_BEGIN:
@@ -445,17 +448,17 @@ static void task_pl_manager_clean_playlist_handler(retro_task_t *task)
             /* Load playlist */
             if (!path_is_valid(pl_manager->playlist_config.path))
                goto task_finished;
-            
+
             pl_manager->playlist = playlist_init(&pl_manager->playlist_config);
-            
+
             if (!pl_manager->playlist)
                goto task_finished;
-            
+
             pl_manager->list_size = playlist_size(pl_manager->playlist);
-            
+
             if (pl_manager->list_size < 1)
                goto task_finished;
-            
+
             /* All good - can start iterating */
             pl_manager->status = PL_MANAGER_ITERATE_ENTRY_VALIDATE;
          }
@@ -464,14 +467,14 @@ static void task_pl_manager_clean_playlist_handler(retro_task_t *task)
          {
             const struct playlist_entry *entry = NULL;
             bool entry_deleted                 = false;
-            
+
             /* Update progress display */
             task_set_progress(task, (pl_manager->list_index * 100) / pl_manager->list_size);
-            
+
             /* Get current entry */
             playlist_get_index(
                   pl_manager->playlist, pl_manager->list_index, &entry);
-            
+
             if (entry)
             {
                /* Check whether playlist content exists on
@@ -481,7 +484,7 @@ static void task_pl_manager_clean_playlist_handler(retro_task_t *task)
                   /* Invalid content - delete entry */
                   playlist_delete_index(pl_manager->playlist, pl_manager->list_index);
                   entry_deleted = true;
-                  
+
                   /* Update list_size */
                   pl_manager->list_size = playlist_size(pl_manager->playlist);
                }
@@ -491,13 +494,13 @@ static void task_pl_manager_clean_playlist_handler(retro_task_t *task)
                         pl_manager->playlist, pl_manager->list_index,
                         entry->core_path, entry->core_name);
             }
-            
+
             /* Increment entry index *if* current entry still
              * exists (i.e. if entry was deleted, current index
              * will already point to the *next* entry) */
             if (!entry_deleted)
                pl_manager->list_index++;
-            
+
             if (pl_manager->list_index >= pl_manager->list_size)
                pl_manager->status = PL_MANAGER_VALIDATE_END;
          }
@@ -521,10 +524,10 @@ static void task_pl_manager_clean_playlist_handler(retro_task_t *task)
          {
             bool entry_deleted = false;
             size_t i;
-            
+
             /* Update progress display */
             task_set_progress(task, (pl_manager->list_index * 100) / pl_manager->list_size);
-            
+
             /* Check whether the content + core paths of the
              * current entry match those of any subsequent
              * entry */
@@ -536,19 +539,19 @@ static void task_pl_manager_clean_playlist_handler(retro_task_t *task)
                   /* Duplicate found - delete entry */
                   playlist_delete_index(pl_manager->playlist, pl_manager->list_index);
                   entry_deleted = true;
-                  
+
                   /* Update list_size */
                   pl_manager->list_size = playlist_size(pl_manager->playlist);
                   break;
                }
             }
-            
+
             /* Increment entry index *if* current entry still
              * exists (i.e. if entry was deleted, current index
              * will already point to the *next* entry) */
             if (!entry_deleted)
                pl_manager->list_index++;
-            
+
             if (pl_manager->list_index + 1 >= pl_manager->list_size)
                pl_manager->status = PL_MANAGER_CHECK_DUPLICATE_END;
          }
@@ -571,14 +574,14 @@ static void task_pl_manager_clean_playlist_handler(retro_task_t *task)
       case PL_MANAGER_ITERATE_FETCH_M3U:
          {
             const struct playlist_entry *entry = NULL;
-            
+
             /* Update progress display */
             task_set_progress(task, (pl_manager->list_index * 100) / pl_manager->list_size);
-            
+
             /* Get current entry */
             playlist_get_index(
                   pl_manager->playlist, pl_manager->list_index, &entry);
-            
+
             if (entry)
             {
                /* If this is an M3U file, add it to the
@@ -594,10 +597,10 @@ static void task_pl_manager_clean_playlist_handler(retro_task_t *task)
                         pl_manager->m3u_list, entry->path, attr);
                }
             }
-            
+
             /* Increment entry index */
             pl_manager->list_index++;
-            
+
             if (pl_manager->list_index >= pl_manager->list_size)
             {
                /* Check whether we have any M3U files
@@ -613,21 +616,21 @@ static void task_pl_manager_clean_playlist_handler(retro_task_t *task)
          {
             const char *m3u_path =
                   pl_manager->m3u_list->elems[pl_manager->m3u_index].data;
-            
+
             if (!string_is_empty(m3u_path))
             {
                m3u_file_t *m3u_file = NULL;
-               
+
                /* Update progress display */
                task_set_progress(task, (pl_manager->m3u_index * 100) / pl_manager->m3u_list->size);
-               
+
                /* Load M3U file */
                m3u_file = m3u_file_init(m3u_path);
-               
+
                if (m3u_file)
                {
                   size_t i;
-                  
+
                   /* Loop over M3U entries */
                   for (i = 0; i < m3u_file_get_size(m3u_file); i++)
                   {
@@ -639,11 +642,11 @@ static void task_pl_manager_clean_playlist_handler(retro_task_t *task)
                         playlist_delete_by_path(
                               pl_manager->playlist, m3u_entry->full_path);
                   }
-                  
+
                   m3u_file_free(m3u_file);
                }
             }
-            
+
             /* Increment M3U file index */
             pl_manager->m3u_index++;
             if (pl_manager->m3u_index >= pl_manager->m3u_list->size)
@@ -652,16 +655,18 @@ static void task_pl_manager_clean_playlist_handler(retro_task_t *task)
          break;
       case PL_MANAGER_END:
          {
-            char task_title[PATH_MAX_LENGTH];
+            size_t _len;
+            char task_title[128];
             /* Save playlist changes to disk */
             playlist_write_file(pl_manager->playlist);
             /* Update progress display */
             task_free_title(task);
-            strlcpy(
-                  task_title, msg_hash_to_str(MSG_PLAYLIST_MANAGER_PLAYLIST_CLEANED),
+            _len = strlcpy(task_title,
+                  msg_hash_to_str(MSG_PLAYLIST_MANAGER_PLAYLIST_CLEANED),
                   sizeof(task_title));
-            strlcat(task_title, pl_manager->playlist_name, sizeof(task_title));
-            
+            strlcpy(task_title + _len, pl_manager->playlist_name,
+                  sizeof(task_title) - _len);
+
             task_set_title(task, strdup(task_title));
          }
          /* fall-through */
@@ -669,30 +674,29 @@ static void task_pl_manager_clean_playlist_handler(retro_task_t *task)
          task_set_progress(task, 100);
          goto task_finished;
    }
-   
+
    return;
-   
+
 task_finished:
-   
    if (task)
-      task_set_finished(task, true);
+      task_set_flags(task, RETRO_TASK_FLG_FINISHED, true);
 }
 
 static bool task_pl_manager_clean_playlist_finder(
       retro_task_t *task, void *user_data)
 {
    pl_manager_handle_t *pl_manager = NULL;
-   
+
    if (!task || !user_data)
       return false;
-   
+
    if (task->handler != task_pl_manager_clean_playlist_handler)
       return false;
-   
+
    pl_manager = (pl_manager_handle_t*)task->state;
    if (!pl_manager)
       return false;
-   
+
    return string_is_equal((const char*)user_data,
          pl_manager->playlist_config.path);
 }
@@ -700,9 +704,10 @@ static bool task_pl_manager_clean_playlist_finder(
 bool task_push_pl_manager_clean_playlist(
       const playlist_config_t *playlist_config)
 {
+   size_t _len;
    task_finder_data_t find_data;
-   char playlist_name[PATH_MAX_LENGTH];
-   char task_title[PATH_MAX_LENGTH];
+   char task_title[128];
+   char playlist_name[NAME_MAX_LENGTH];
    retro_task_t *task              = task_init();
    pl_manager_handle_t *pl_manager = (pl_manager_handle_t*)
       calloc(1, sizeof(pl_manager_handle_t));
@@ -711,26 +716,26 @@ bool task_push_pl_manager_clean_playlist(
       goto error;
    if (string_is_empty(playlist_config->path))
       goto error;
-   
-   fill_pathname_base(playlist_name,
-         playlist_config->path, sizeof(playlist_name));
-   path_remove_extension(playlist_name);
-   
+
+   fill_pathname(playlist_name,
+         path_basename(playlist_config->path), "",
+         sizeof(playlist_name));
+
    if (string_is_empty(playlist_name))
       goto error;
-   
+
    /* Concurrent management of the same playlist
     * is not allowed */
    find_data.func                = task_pl_manager_clean_playlist_finder;
    find_data.userdata            = (void*)playlist_config->path;
-   
+
    if (task_queue_find(&find_data))
       goto error;
-   
+
    /* Configure handle */
    if (!playlist_config_copy(playlist_config, &pl_manager->playlist_config))
       goto error;
-   
+
    pl_manager->playlist_name       = strdup(playlist_name);
    pl_manager->playlist            = NULL;
    pl_manager->list_size           = 0;
@@ -738,39 +743,39 @@ bool task_push_pl_manager_clean_playlist(
    pl_manager->m3u_list            = string_list_new();
    pl_manager->m3u_index           = 0;
    pl_manager->status              = PL_MANAGER_BEGIN;
-   
+
    if (!pl_manager->m3u_list)
       goto error;
-   
+
    /* Configure task */
-   strlcpy(
-         task_title,
-	 msg_hash_to_str(MSG_PLAYLIST_MANAGER_CLEANING_PLAYLIST),
+   _len = strlcpy(task_title,
+         msg_hash_to_str(MSG_PLAYLIST_MANAGER_CLEANING_PLAYLIST),
          sizeof(task_title));
-   strlcat(task_title, playlist_name, sizeof(task_title));
-   
+   strlcpy(task_title + _len, playlist_name, sizeof(task_title) - _len);
+
    task->handler                 = task_pl_manager_clean_playlist_handler;
    task->state                   = pl_manager;
    task->title                   = strdup(task_title);
-   task->alternative_look        = true;
    task->progress                = 0;
    task->callback                = cb_task_pl_manager;
    task->cleanup                 = task_pl_manager_free;
-   
+
+   task->flags                  |= RETRO_TASK_FLG_ALTERNATIVE_LOOK;
+
    task_queue_push(task);
-   
+
    return true;
-   
+
 error:
-   
+
    if (task)
    {
       free(task);
       task = NULL;
    }
-   
+
    free_pl_manager_handle(pl_manager);
    pl_manager = NULL;
-   
+
    return false;
 }
