@@ -54,12 +54,12 @@
    read/write is a possible suspend to JS code */
 #define SAVE_STATE_CHUNK 4096 * 4096
 #else
-/* A low common denominator write chunk size.  On a slow 
-  (speed class 6) SD card, we can write 6MB/s.  That gives us 
-  roughly 100KB/frame.  
-  This means we can write savestates with one syscall for cores 
-  with less than 100KB of state. Class 10 is the standard now 
-  even for lousy cards and supports 10MB/s, so you may prefer 
+/* A low common denominator write chunk size.  On a slow
+  (speed class 6) SD card, we can write 6MB/s.  That gives us
+  roughly 100KB/frame.
+  This means we can write savestates with one syscall for cores
+  with less than 100KB of state. Class 10 is the standard now
+  even for lousy cards and supports 10MB/s, so you may prefer
   to put this to 170KB. This all assumes that task_save's loop
   is iterated once per frame at 60 FPS; if it's updated less
   frequently this number could be doubled or quadrupled depending
@@ -306,14 +306,17 @@ static void undo_save_state_cb(retro_task_t *task,
 static void task_save_handler_finished(retro_task_t *task,
       save_task_state_t *state)
 {
+   uint8_t flg;
    save_task_state_t *task_data = NULL;
 
-   task_set_finished(task, true);
+   task_set_flags(task, RETRO_TASK_FLG_FINISHED, true);
 
    intfstream_close(state->file);
    free(state->file);
 
-   if (!task_get_error(task) && task_get_cancelled(task))
+   flg = task_get_flags(task);
+
+   if (!task_get_error(task) && ((flg & RETRO_TASK_FLG_CANCELLED) > 0))
       task_set_error(task, strdup("Task canceled"));
 
    task_data = (save_task_state_t*)calloc(1, sizeof(*task_data));
@@ -447,18 +450,30 @@ static bool content_write_serialized_state(void* buffer,
 bool content_serialize_state_rewind(void* buffer, size_t buffer_size)
 {
    rastate_size_info_t size;
-   size_t len = content_get_rastate_size(&size, true);
-   if (len == 0 || len > buffer_size)
+   size_t _len = content_get_rastate_size(&size, true);
+   if (_len == 0)
       return false;
+   if (_len > buffer_size)
+   {
+#ifdef DEBUG
+      static size_t last_reported_len = 0;
+      if (_len != last_reported_len)
+      {
+         last_reported_len = _len;
+         RARCH_WARN("Rewind state size exceeds frame size (%zu > %zu).\n", _len, buffer_size);
+      }
+#endif
+      return false;
+   }
    return content_write_serialized_state(buffer, &size, true);
 }
 
-static void *content_get_serialized_data(size_t* serial_size)
+static void *content_get_serialized_data(size_t *serial_size)
 {
-   size_t len;
+   size_t _len;
    void* data;
    rastate_size_info_t size;
-   if ((len = content_get_rastate_size(&size, false)) == 0)
+   if ((_len = content_get_rastate_size(&size, false)) == 0)
       return NULL;
 
    /* Ensure buffer is initialised to zero
@@ -466,7 +481,7 @@ static void *content_get_serialized_data(size_t* serial_size)
     *   sizes when core requests a larger buffer
     *   than it needs (and leaves the excess
     *   as uninitialised garbage) */
-   if (!(data = calloc(len, 1)))
+   if (!(data = calloc(_len, 1)))
       return NULL;
 
    if (!content_write_serialized_state(data, &size, false))
@@ -487,6 +502,7 @@ static void *content_get_serialized_data(size_t* serial_size)
  **/
 static void task_save_handler(retro_task_t *task)
 {
+   uint8_t flg;
    ssize_t remaining;
    int written              = 0;
    save_task_state_t *state = (save_task_state_t*)task->state;
@@ -523,10 +539,11 @@ static void task_save_handler(retro_task_t *task)
 
    task_set_progress(task, (state->written / (float)state->size) * 100);
 
-   if (task_get_cancelled(task) || written != remaining)
+   flg = task_get_flags(task);
+
+   if (((flg & RETRO_TASK_FLG_CANCELLED) > 0) || written != remaining)
    {
-      size_t err_size = 8192 * sizeof(char);
-      char *err       = (char*)malloc(err_size);
+      char msg[128];
 
       if (state->flags & SAVE_TASK_FLAG_UNDO_SAVE)
       {
@@ -534,21 +551,19 @@ static void task_save_handler(retro_task_t *task)
                MSG_FAILED_TO_UNDO_SAVE_STATE);
          RARCH_ERR("[State]: %s \"%s\".\n", failed_undo_str,
                undo_save_buf.path);
-         err[0]      = '\0';
-         snprintf(err, err_size - 1, "%s \"RAM\".", failed_undo_str);
+         snprintf(msg, sizeof(msg), "%s \"RAM\".", failed_undo_str);
       }
       else
       {
-         size_t _len = strlcpy(err,
+         size_t _len = strlcpy(msg,
                msg_hash_to_str(MSG_FAILED_TO_SAVE_STATE_TO),
-               err_size - 1);
-         err[  _len] = ' ';
-         err[++_len] = '\0';
-         strlcat(err, state->path, err_size - 1);
+               sizeof(msg));
+         msg[  _len] = ' ';
+         msg[++_len] = '\0';
+         strlcpy(msg + _len, state->path, sizeof(msg) - _len);
       }
 
-      task_set_error(task, strdup(err));
-      free(err);
+      task_set_error(task, strdup(msg));
       task_save_handler_finished(task, state);
       return;
    }
@@ -566,15 +581,13 @@ static void task_save_handler(retro_task_t *task)
       else
       {
          char new_msg[128];
-         new_msg[0] = '\0';
-
          snprintf(new_msg, sizeof(new_msg),
                msg_hash_to_str(MSG_SAVED_STATE_TO_SLOT),
                state->state_slot);
          msg = strdup(new_msg);
       }
 
-      if (!task_get_mute(task) && msg)
+      if (!((flg & RETRO_TASK_FLG_MUTE) > 0) && msg)
       {
          task_set_title(task, msg);
          msg = NULL;
@@ -627,7 +640,11 @@ static bool task_push_undo_save_state(const char *path, void *data, size_t size)
    task->handler                 = task_save_handler;
    task->callback                = undo_save_state_cb;
    task->title                   = strdup(msg_hash_to_str(MSG_UNDOING_SAVE_STATE));
-   task->mute                    = (state->flags & SAVE_TASK_FLAG_MUTE) ? true : false;
+
+   if (state->flags & SAVE_TASK_FLAG_MUTE)
+      task->flags               |=  RETRO_TASK_FLG_MUTE;
+   else
+      task->flags               &= ~RETRO_TASK_FLG_MUTE;
 
    task_queue_push(task);
 
@@ -672,9 +689,10 @@ bool content_undo_save_state(void)
 static void task_load_handler_finished(retro_task_t *task,
       save_task_state_t *state)
 {
+   uint8_t flg;
    load_task_data_t *task_data = NULL;
 
-   task_set_finished(task, true);
+   task_set_flags(task, RETRO_TASK_FLG_FINISHED, true);
 
    if (state->file)
    {
@@ -682,7 +700,9 @@ static void task_load_handler_finished(retro_task_t *task,
       free(state->file);
    }
 
-   if (!task_get_error(task) && task_get_cancelled(task))
+   flg = task_get_flags(task);
+
+   if (!task_get_error(task) && ((flg & RETRO_TASK_FLG_CANCELLED) > 0))
       task_set_error(task, strdup("Task canceled"));
 
    if (!(task_data = (load_task_data_t*)calloc(1, sizeof(*task_data))))
@@ -703,6 +723,7 @@ static void task_load_handler_finished(retro_task_t *task,
  **/
 static void task_load_handler(retro_task_t *task)
 {
+   uint8_t flg;
    ssize_t remaining, bytes_read;
    save_task_state_t *state = (save_task_state_t*)task->state;
 
@@ -731,7 +752,7 @@ static void task_load_handler(retro_task_t *task)
 
 #ifdef HAVE_CHEEVOS
    if (rcheevos_hardcore_active())
-      task_set_cancelled(task, true);
+      task_set_flags(task, RETRO_TASK_FLG_CANCELLED, true);
 #endif
 
    remaining          = MIN(state->size - state->bytes_read, SAVE_STATE_CHUNK);
@@ -742,20 +763,17 @@ static void task_load_handler(retro_task_t *task)
    if (state->size > 0)
       task_set_progress(task, (state->bytes_read / (float)state->size) * 100);
 
-   if (task_get_cancelled(task) || bytes_read != remaining)
+   flg = task_get_flags(task);
+
+   if (((flg & RETRO_TASK_FLG_CANCELLED) > 0) || bytes_read != remaining)
    {
       if (state->flags & SAVE_TASK_FLAG_AUTOLOAD)
       {
-         char *msg = (char*)malloc(8192 * sizeof(char));
-
-         msg[0] = '\0';
-
-         snprintf(msg,
-               8192 * sizeof(char),
+         char msg[128];
+         snprintf(msg, sizeof(msg),
                msg_hash_to_str(MSG_AUTOLOADING_SAVESTATE_FAILED),
                path_basename(state->path));
          task_set_error(task, strdup(msg));
-         free(msg);
       }
       else
          task_set_error(task, strdup(msg_hash_to_str(MSG_FAILED_TO_LOAD_STATE)));
@@ -770,34 +788,27 @@ static void task_load_handler(retro_task_t *task)
    {
       task_free_title(task);
 
-      if (!task_get_mute(task))
+      if (!((flg & RETRO_TASK_FLG_MUTE) > 0))
       {
-         size_t msg_size   = 8192 * sizeof(char);
-         char *msg         = (char*)malloc(msg_size);
-
-         msg[0]            = '\0';
+         char msg[128];
 
          if (state->flags & SAVE_TASK_FLAG_AUTOLOAD)
-         {
-            snprintf(msg,
-                  msg_size - 1,
+            snprintf(msg, sizeof(msg),
                   msg_hash_to_str(MSG_AUTOLOADING_SAVESTATE_SUCCEEDED),
                   path_basename(state->path));
-         }
          else
          {
             if (state->state_slot < 0)
                strlcpy(msg,
                      msg_hash_to_str(MSG_LOADED_STATE_FROM_SLOT_AUTO),
-                     msg_size - 1);
+                     sizeof(msg));
             else
-               snprintf(msg, msg_size - 1,
+               snprintf(msg, sizeof(msg),
                      msg_hash_to_str(MSG_LOADED_STATE_FROM_SLOT),
                      state->state_slot);
          }
 
          task_set_title(task, strdup(msg));
-         free(msg);
       }
 
       goto end;
@@ -807,19 +818,11 @@ static void task_load_handler(retro_task_t *task)
 
 not_found:
    {
-      size_t msg_size   = 8192 * sizeof(char);
-      char *msg         = (char*)malloc(msg_size);
-
-      msg[0] = '\0';
-
-      snprintf(msg,
-            msg_size - 1,
-            "%s \"%s\".",
+      char msg[128];
+      snprintf(msg, sizeof(msg), "%s \"%s\".",
             msg_hash_to_str(MSG_FAILED_TO_LOAD_STATE),
             path_basename(state->path));
-
       task_set_title(task, strdup(msg));
-      free(msg);
    }
 
 end:
@@ -1195,7 +1198,11 @@ static void task_push_save_state(const char *path, void *data, size_t size, bool
    task->handler                 = task_save_handler;
    task->callback                = save_state_cb;
    task->title                   = strdup(msg_hash_to_str(MSG_SAVING_STATE));
-   task->mute                    = (state->flags & SAVE_TASK_FLAG_MUTE) ? true : false;
+
+   if (state->flags & SAVE_TASK_FLAG_MUTE)
+      task->flags               |=  RETRO_TASK_FLG_MUTE;
+   else
+      task->flags               &= ~RETRO_TASK_FLG_MUTE;
 
    if (!task_queue_push(task))
    {
@@ -1301,7 +1308,11 @@ static void task_push_load_and_save_state(const char *path, void *data,
    task->handler                 = task_load_handler;
    task->callback                = content_load_and_save_state_cb;
    task->title                   = strdup(msg_hash_to_str(MSG_LOADING_STATE));
-   task->mute                    = (state->flags & SAVE_TASK_FLAG_MUTE) ? true : false;
+
+   if (state->flags & SAVE_TASK_FLAG_MUTE)
+      task->flags               |=  RETRO_TASK_FLG_MUTE;
+   else
+      task->flags               &= ~RETRO_TASK_FLG_MUTE;
 
    if (!task_queue_push(task))
    {
@@ -1586,7 +1597,11 @@ bool content_load_state(const char *path,
    task->handler                = task_load_handler;
    task->callback               = content_load_state_cb;
    task->title                  = strdup(msg_hash_to_str(MSG_LOADING_STATE));
-   task->mute                   = (state->flags & SAVE_TASK_FLAG_MUTE) ? true : false;
+
+   if (state->flags & SAVE_TASK_FLAG_MUTE)
+      task->flags               |=  RETRO_TASK_FLG_MUTE;
+   else
+      task->flags               &= ~RETRO_TASK_FLG_MUTE;
 
    task_queue_push(task);
 
