@@ -45,16 +45,6 @@
 
 RETRO_BEGIN_DECLS
 
-enum screenshot_task_flags
-{
-   SS_TASK_FLAG_BGR24               = (1 << 0),
-   SS_TASK_FLAG_SILENCE             = (1 << 1),
-   SS_TASK_FLAG_IS_IDLE             = (1 << 2),
-   SS_TASK_FLAG_IS_PAUSED           = (1 << 3),
-   SS_TASK_FLAG_HISTORY_LIST_ENABLE = (1 << 4),
-   SS_TASK_FLAG_WIDGETS_READY       = (1 << 5)
-};
-
 typedef struct nbio_buf
 {
    void *buf;
@@ -62,26 +52,6 @@ typedef struct nbio_buf
    unsigned bufsize;
 } nbio_buf_t;
 
-typedef struct screenshot_task_state screenshot_task_state_t;
-
-struct screenshot_task_state
-{
-   struct scaler_ctx scaler;
-   uint8_t *out_buffer;
-   const void *frame;
-   void *userbuf;
-
-   int pitch;
-   unsigned width;
-   unsigned height;
-   unsigned pixel_format_type;
-
-   uint8_t flags;
-
-   char filename[PATH_MAX_LENGTH];
-   char shotname[NAME_MAX_LENGTH];
-};
-
 #ifdef HAVE_NETWORKING
 typedef struct
 {
@@ -109,8 +79,6 @@ void *task_push_http_post_transfer_with_user_agent(const char *url, const char *
 void *task_push_http_post_transfer_with_headers(const char *url, const char *post_data, bool mute,
    const char *type, const char *headers, retro_task_callback_t cb, void *user_data);
 
-task_retriever_info_t *http_task_get_transfer_list(void);
-
 void *task_push_webdav_stat(const char *url, bool mute, const char *headers,
       retro_task_callback_t cb, void *userdata);
 void *task_push_webdav_mkdir(const char *url, bool mute, const char *headers,
@@ -308,6 +276,7 @@ void menu_explore_wait_for_init_task(void);
 extern const char* const input_builtin_autoconfs[];
 
 /* cloud sync tasks */
+void task_push_cloud_sync_update_driver(void);
 void task_push_cloud_sync(void);
 
 RETRO_END_DECLS
