@@ -50,6 +50,8 @@ def replace_global_in(source):
         ('IN.frame_count', 'FrameCount'),
         ('IN.frame_direction', 'FrameDirection'),
         ('IN.rotation', 'Rotation'),
+        ('IN.core_aspect', 'OriginalAspect'),
+        ('IN.core_aspect_rot', 'OriginalAspectRotated'),
     ]
 
     for line in source.splitlines():
@@ -109,6 +111,8 @@ def no_uniform(elem):
         '_frame_count',
         '_frame_direction',
         '_rotation',
+        '_core_aspect',
+        '_core_aspect_rot',
         '_mvp_matrix',
         '_vertex_coord',
         'sampler2D'
