@@ -1,4 +1,4 @@
-﻿#include <QCloseEvent>
+#include <QCloseEvent>
 #include <QSettings>
 #include <QResizeEvent>
 #include <QMessageBox>
@@ -173,8 +173,8 @@ void PlaylistEntryDialog::loadPlaylistOptions()
    m_coreComboBox->addItem(
          msg_hash_to_str(MENU_ENUM_LABEL_VALUE_QT_CORE_SELECTION_ASK));
    m_databaseComboBox->addItem(
-           QString("<") 
-         + msg_hash_to_str(MENU_ENUM_LABEL_VALUE_NOT_AVAILABLE) 
+           QString("<")
+         + msg_hash_to_str(MENU_ENUM_LABEL_VALUE_NOT_AVAILABLE)
          + ">",
          QFileInfo(m_mainwindow->getCurrentPlaylistPath()).fileName().remove(".lpl"));
 
@@ -381,7 +381,7 @@ void CoreInfoDialog::showCoreInfo()
    int      row  = 0;
    int row_count = m_formLayout->rowCount();
    int       i   = 0;
-   QVector<QHash<QString, QString> > info_list 
+   QVector<QHash<QString, QString> > info_list
                  = m_mainwindow->getCoreInfo();
 
    if (row_count > 0)
@@ -392,7 +392,7 @@ void CoreInfoDialog::showCoreInfo()
          /* removeRow() and takeRow() was only added in 5.8! */
          m_formLayout->removeRow(0);
 #else
-         /* something is buggy here... 
+         /* something is buggy here...
           * sometimes items appear duplicated, and other times not */
          QLayoutItem *item = m_formLayout->itemAt(0);
          QWidget        *w = NULL;
@@ -455,7 +455,7 @@ QColor getLabelColor(const QString& objectName)
    QLabel dummyColor;
    dummyColor.setObjectName(objectName);
    dummyColor.ensurePolished();
-   return dummyColor.palette().color(QPalette::Foreground);
+   return dummyColor.palette().color(QPalette::WindowText);
 }
 
 /* stolen from Qt Creator */
@@ -482,7 +482,7 @@ private:
 
          /* Widget wants to be bigger than available space */
          if (innerSizeHint.height() > innerSize.height())
-         { 
+         {
             innerSize.setWidth(innerSize.width() - scrollBarWidth());
             innerSize.setHeight(innerSizeHint.height());
          }
@@ -536,14 +536,18 @@ ViewOptionsDialog::ViewOptionsDialog(MainWindow *mainwindow, QWidget *parent) :
    int width;
    QGridLayout        *layout = new QGridLayout(this);
    QLabel      *m_headerLabel = new QLabel(this);
-   /* Header label with large font and a bit of spacing 
+   /* Header label with large font and a bit of spacing
     * (align with group boxes) */
    QFont      headerLabelFont = m_headerLabel->font();
    const int        pointSize = headerLabelFont.pointSize();
    QHBoxLayout *headerHLayout = new QHBoxLayout;
    const int       leftMargin = QApplication::style()->pixelMetric(QStyle::PM_LayoutLeftMargin);
 
+#if (QT_VERSION > QT_VERSION_CHECK(6, 0, 0))
+   m_optionsStack->setContentsMargins(0, 0, 0, 0);
+#else
    m_optionsStack->setMargin(0);
+#endif
 
    headerLabelFont.setBold(true);
 
@@ -576,9 +580,9 @@ ViewOptionsDialog::ViewOptionsDialog(MainWindow *mainwindow, QWidget *parent) :
    addCategory(new UserCategory(this));
    addCategory(new DirectoryCategory(this));
 
-   width  = 
-        m_optionsList->sizeHintForColumn(0) 
-      + m_optionsList->frameWidth() * 2 
+   width  =
+        m_optionsList->sizeHintForColumn(0)
+      + m_optionsList->frameWidth() * 2
       + 5;
    width += m_optionsList->verticalScrollBar()->sizeHint().width();
 
@@ -601,9 +605,9 @@ QIcon getIcon(OptionsCategory *category)
 {
    settings_t *settings        = config_get_ptr();
    const char *path_dir_assets = settings->paths.directory_assets;
-   QPixmap pixmap              = QPixmap(QString(path_dir_assets) 
-         + "/xmb/monochrome/png/" 
-         + category->categoryIconName() 
+   QPixmap pixmap              = QPixmap(QString(path_dir_assets)
+         + "/xmb/monochrome/png/"
+         + category->categoryIconName()
          + ".png");
    return QIcon(getColorizedPixmap(pixmap, getLabelColor("iconColor")));
 }
@@ -728,7 +732,7 @@ ViewOptionsWidget::ViewOptionsWidget(MainWindow *mainwindow, QWidget *parent) :
 
    m_thumbnailCacheSpinBox->setSuffix(" MB");
    m_thumbnailCacheSpinBox->setRange(0, 99999);
-   
+
    m_thumbnailDropSizeSpinBox->setSuffix(" px");
    m_thumbnailDropSizeSpinBox->setRange(0, 99999);
 
@@ -825,7 +829,7 @@ void ViewOptionsWidget::loadViewOptions()
    int i;
    int themeIndex    = 0;
    int playlistIndex = 0;
-   QColor highlightColor                       = 
+   QColor highlightColor                       =
       m_settings->value("highlight_color",
             QApplication::palette().highlight().color()).value<QColor>();
    QPixmap highlightPixmap(m_highlightColorPushButton->iconSize());
@@ -1144,9 +1148,9 @@ void CoreOptionsDialog::buildLayout()
 
          for (j = 0; j < opts; j++)
          {
-            QString desc               = 
+            QString desc               =
                core_option_manager_get_desc(coreopts, j, false);
-            QString val                = 
+            QString val                =
                core_option_manager_get_val(coreopts, j);
             QComboBox *combo_box       = NULL;
             QLabel *descLabel          = NULL;
@@ -1193,7 +1197,7 @@ void CoreOptionsDialog::buildLayout()
             }
 
             for (k = 0; k < option->vals->size; k++)
-               combo_box->addItem(option->vals->elems[k].data, option->key);
+               combo_box->addItem(option->vals->elems[k].data, QVariant::fromValue(QString(option->key)));
 
             combo_box->setCurrentText(val);
             combo_box->setProperty("default_index",
@@ -1481,7 +1485,7 @@ void ShaderParamsDialog::onFilterComboBoxIndexChanged(int)
    if (!ok)
       return;
 
-   if (     menu_shader 
+   if (     menu_shader
          && (pass >= 0)
          && (pass < static_cast<int>(menu_shader->passes)))
    {
@@ -1722,6 +1726,7 @@ void ShaderParamsDialog::onShaderLoadPresetClicked()
 {
    QString path, filter;
    QByteArray pathArray;
+   gfx_ctx_flags_t flags;
    struct video_shader *menu_shader  = NULL;
    struct video_shader *video_shader = NULL;
    const char *pathData              = NULL;
@@ -1731,7 +1736,6 @@ void ShaderParamsDialog::onShaderLoadPresetClicked()
    const char *shader_preset_dir     = settings->paths.directory_video_shader;
 #else
    const char *shader_preset_dir     = NULL;
-
    menu_driver_get_last_shader_preset_path(&shader_preset_dir, NULL);
 #endif
 
@@ -1742,23 +1746,26 @@ void ShaderParamsDialog::onShaderLoadPresetClicked()
 
    filter.append("Shader Preset (");
 
-   /* NOTE: Maybe we should have a way to get a list 
+   flags.flags     = 0;
+   video_context_driver_get_flags(&flags);
+
+   /* NOTE: Maybe we should have a way to get a list
     * of all shader types instead of hard-coding this? */
-   if (video_shader_is_supported(RARCH_SHADER_CG))
+   if (BIT32_GET(flags.flags, GFX_CTX_FLAGS_SHADERS_CG))
    {
-      filter.append(QLatin1Literal(" *"));
+      filter.append(QLatin1String(" *"));
       filter.append(".cgp");
    }
 
-   if (video_shader_is_supported(RARCH_SHADER_GLSL))
+   if (BIT32_GET(flags.flags, GFX_CTX_FLAGS_SHADERS_GLSL))
    {
-      filter.append(QLatin1Literal(" *"));
+      filter.append(QLatin1String(" *"));
       filter.append(".glslp");
    }
 
-   if (video_shader_is_supported(RARCH_SHADER_SLANG))
+   if (BIT32_GET(flags.flags, GFX_CTX_FLAGS_SHADERS_SLANG))
    {
-      filter.append(QLatin1Literal(" *"));
+      filter.append(QLatin1String(" *"));
       filter.append(".slangp");
    }
 
@@ -1879,6 +1886,7 @@ void ShaderParamsDialog::onShaderResetAllPasses()
 
 void ShaderParamsDialog::onShaderAddPassClicked()
 {
+   gfx_ctx_flags_t flags;
    QString path, filter;
    QByteArray pathArray;
    struct video_shader *menu_shader      = NULL;
@@ -1901,16 +1909,17 @@ void ShaderParamsDialog::onShaderAddPassClicked()
 
    filter.append("Shader (");
 
-   /* NOTE: Maybe we should have a way to get a list 
+   flags.flags     = 0;
+   video_context_driver_get_flags(&flags);
+
+   /* NOTE: Maybe we should have a way to get a list
     * of all shader types instead of hard-coding this? */
-   if (video_shader_is_supported(RARCH_SHADER_CG))
-      filter.append(QLatin1Literal(" *.cg"));
-
-   if (video_shader_is_supported(RARCH_SHADER_GLSL))
-      filter.append(QLatin1Literal(" *.glsl"));
-
-   if (video_shader_is_supported(RARCH_SHADER_SLANG))
-      filter.append(QLatin1Literal(" *.slang"));
+   if (BIT32_GET(flags.flags, GFX_CTX_FLAGS_SHADERS_CG))
+      filter.append(QLatin1String(" *.cg"));
+   if (BIT32_GET(flags.flags, GFX_CTX_FLAGS_SHADERS_GLSL))
+      filter.append(QLatin1String(" *.glsl"));
+   if (BIT32_GET(flags.flags, GFX_CTX_FLAGS_SHADERS_SLANG))
+      filter.append(QLatin1String(" *.slang"));
 
    filter.append(")");
 
@@ -2020,19 +2029,17 @@ void ShaderParamsDialog::operateShaderPreset(bool save, const char *path, unsign
                true);
 
       if (ret)
-         runloop_msg_queue_push(
-               msg_hash_to_str(MSG_SHADER_PRESET_SAVED_SUCCESSFULLY),
-               1, 100, true, NULL,
-               MESSAGE_QUEUE_ICON_DEFAULT,
-               MESSAGE_QUEUE_CATEGORY_INFO
-               );
+      {
+         const char *_msg = msg_hash_to_str(MSG_SHADER_PRESET_SAVED_SUCCESSFULLY);
+         runloop_msg_queue_push(_msg, strlen(_msg), 1, 100, true, NULL,
+               MESSAGE_QUEUE_ICON_DEFAULT, MESSAGE_QUEUE_CATEGORY_INFO);
+      }
       else
-         runloop_msg_queue_push(
-               msg_hash_to_str(MSG_ERROR_SAVING_SHADER_PRESET),
-               1, 100, true, NULL,
-               MESSAGE_QUEUE_ICON_DEFAULT,
-               MESSAGE_QUEUE_CATEGORY_ERROR
-               );
+      {
+         const char *_msg = msg_hash_to_str(MSG_ERROR_SAVING_SHADER_PRESET);
+         runloop_msg_queue_push(_msg, strlen(_msg), 1, 100, true, NULL,
+               MESSAGE_QUEUE_ICON_DEFAULT, MESSAGE_QUEUE_CATEGORY_ERROR);
+      }
    }
    else
    {
@@ -2041,24 +2048,20 @@ void ShaderParamsDialog::operateShaderPreset(bool save, const char *path, unsign
                path_dir_video_shader,
                path_dir_menu_config))
       {
-         runloop_msg_queue_push(
-               msg_hash_to_str(MSG_SHADER_PRESET_REMOVED_SUCCESSFULLY),
-               1, 100, true, NULL,
-               MESSAGE_QUEUE_ICON_DEFAULT,
-               MESSAGE_QUEUE_CATEGORY_INFO
-               );
+         const char *_msg = msg_hash_to_str(MSG_SHADER_PRESET_REMOVED_SUCCESSFULLY);
+         runloop_msg_queue_push(_msg, strlen(_msg), 1, 100, true, NULL,
+               MESSAGE_QUEUE_ICON_DEFAULT, MESSAGE_QUEUE_CATEGORY_INFO);
 
 #ifdef HAVE_MENU
          menu_state_get_ptr()->flags |=  MENU_ST_FLAG_ENTRIES_NEED_REFRESH;
 #endif
       }
       else
-         runloop_msg_queue_push(
-               msg_hash_to_str(MSG_ERROR_REMOVING_SHADER_PRESET),
-               1, 100, true, NULL,
-               MESSAGE_QUEUE_ICON_DEFAULT,
-               MESSAGE_QUEUE_CATEGORY_ERROR
-               );
+      {
+         const char *_msg = msg_hash_to_str(MSG_ERROR_REMOVING_SHADER_PRESET);
+         runloop_msg_queue_push(_msg, strlen(_msg), 1, 100, true, NULL,
+               MESSAGE_QUEUE_ICON_DEFAULT, MESSAGE_QUEUE_CATEGORY_ERROR);
+      }
    }
 }
 
@@ -2181,28 +2184,28 @@ void ShaderParamsDialog::updateRemovePresetButtonsState()
             menu_shader_manager_auto_preset_exists(
                SHADER_PRESET_GLOBAL,
                path_dir_video_shader,
-               path_dir_menu_config 
+               path_dir_menu_config
                ));
    if (removeCorePresetAction)
       removeCorePresetAction->setEnabled(
             menu_shader_manager_auto_preset_exists(
                SHADER_PRESET_CORE,
                path_dir_video_shader,
-               path_dir_menu_config 
+               path_dir_menu_config
                ));
    if (removeParentPresetAction)
       removeParentPresetAction->setEnabled(
             menu_shader_manager_auto_preset_exists(
                SHADER_PRESET_PARENT,
                path_dir_video_shader,
-               path_dir_menu_config 
+               path_dir_menu_config
                ));
    if (removeGamePresetAction)
       removeGamePresetAction->setEnabled(
             menu_shader_manager_auto_preset_exists(
                SHADER_PRESET_GAME,
                path_dir_video_shader,
-               path_dir_menu_config 
+               path_dir_menu_config
                ));
 }
 
@@ -2235,14 +2238,14 @@ void ShaderParamsDialog::buildLayout()
 
    getShaders(&menu_shader, &video_shader);
 
-   /* NOTE: For some reason, menu_shader_get() returns a COPY 
+   /* NOTE: For some reason, menu_shader_get() returns a COPY
     * of what get_current_shader() gives us.
-    * And if you want to be able to change shader settings/parameters 
+    * And if you want to be able to change shader settings/parameters
     * from both the raster menu and
-    * Qt at the same time... you must change BOTH or one will 
+    * Qt at the same time... you must change BOTH or one will
     * overwrite the other.
     *
-    * AND, during a context reset, video_shader will be NULL 
+    * AND, during a context reset, video_shader will be NULL
     * but not menu_shader, so don't totally bail
     * just because video_shader is NULL.
     *
@@ -2256,7 +2259,7 @@ void ShaderParamsDialog::buildLayout()
       if (video_shader->passes == 0)
          setWindowTitle(msg_hash_to_str(MENU_ENUM_LABEL_VALUE_SHADER_OPTIONS));
    }
-   /* Normally we'd only use video_shader, 
+   /* Normally we'd only use video_shader,
     * but the Vulkan driver returns a NULL shader when there
     * are zero passes, so just fall back to menu_shader.
     */
@@ -2278,7 +2281,7 @@ void ShaderParamsDialog::buildLayout()
 
    clearLayout();
 
-   /* Only check video_shader for the path, menu_shader seems stale... 
+   /* Only check video_shader for the path, menu_shader seems stale...
     * e.g. if you remove all the shader passes,
     * it still has the old path in it, but video_shader does not
     */
