@@ -54,8 +54,8 @@ using namespace Windows::Graphics::Display;
 using namespace Windows::Devices::Enumeration;
 using namespace Windows::Storage;
 
-char uwp_dir_install[PATH_MAX_LENGTH] = { 0 };
-char uwp_dir_data[PATH_MAX_LENGTH]    = { 0 };
+char uwp_dir_install[DIR_MAX_LENGTH]  = { 0 };
+char uwp_dir_data[DIR_MAX_LENGTH]     = { 0 };
 char uwp_device_family[128]           = { 0 };
 char win32_cpu_model_name[128]        = { 0 };
 
@@ -224,7 +224,7 @@ int main(Platform::Array<Platform::String^>^)
    Platform::String^ data_dir     = local_folder + L"\\";
 
    /* Delete VFS cache dir, we do this because this allows a far more
-    * concise implementation than manually implementing a function to do this 
+    * concise implementation than manually implementing a function to do this
     * This may be a little slower but shouldn't really matter as the cache dir
     * should never have more than a few items */
    Platform::String^ vfs_dir     = local_folder + L"\\VFSCACHE";
@@ -274,7 +274,7 @@ App::App() :
 /* The first method called when the IFrameworkView is being created. */
 void App::Initialize(CoreApplicationView^ applicationView)
 {
-   /* Register event handlers for app lifecycle. This example 
+   /* Register event handlers for app lifecycle. This example
     * includes Activated, so that we can make the CoreWindow active and start
     * rendering on the window. */
    applicationView->Activated         +=
@@ -365,9 +365,9 @@ void App::Run()
 
       if (!x)
       {
-         /* HACK: I have no idea why is this necessary but 
+         /* HACK: I have no idea why is this necessary but
           * it is required to get proper scaling on Xbox *
-          * Perhaps PreferredLaunchViewSize is broken and 
+          * Perhaps PreferredLaunchViewSize is broken and
           * we need to wait until the app starts to call TryResizeView */
          m_windowResized = true;
          x               = true;
@@ -379,27 +379,27 @@ void App::Run()
 }
 
 /* Required for IFrameworkView.
- * Terminate events do not cause Uninitialize to be called. 
+ * Terminate events do not cause Uninitialize to be called.
  * It will be called if your IFrameworkView
  * class is torn down while the app is in the foreground. */
 void App::Uninitialize()
 {
    main_exit(NULL);
 
-   /* If this instance of RetroArch was started from another app/frontend 
+   /* If this instance of RetroArch was started from another app/frontend
     * and the frontend passed "launchOnExit" parameter:
-    * 1. launch the app specified in "launchOnExit", most likely the 
+    * 1. launch the app specified in "launchOnExit", most likely the
     *    same app that started RetroArch
-    * 2. RetroArch goes to background and RunAsyncAndCatchErrors doesn't 
+    * 2. RetroArch goes to background and RunAsyncAndCatchErrors doesn't
     *    return, because the target app is immediately started.
-    * 3. Explicitly exit in App::OnEnteredBackground if 
-    *    m_launchOnExitShutdown is set. Otherwise, RetroArch doesn't 
+    * 3. Explicitly exit in App::OnEnteredBackground if
+    *    m_launchOnExitShutdown is set. Otherwise, RetroArch doesn't
     *    properly shutdown.
     */
    if (m_launchOnExit != nullptr && !m_launchOnExit->IsEmpty())
-   {		
+   {
       try
-      {			
+      {
          /* Launch the target app */
          m_launchOnExitShutdown = true;
          auto ret               = RunAsyncAndCatchErrors<bool>([&]() {
@@ -419,12 +419,12 @@ void App::OnActivated(CoreApplicationView^ applicationView, IActivatedEventArgs^
    int ret;
    int argc = NULL;
    std::vector<char*> argv;
-   /* using std::string as temp buf instead of char* array 
+   /* using std::string as temp buf instead of char* array
     * to avoid manual char allocations */
-   std::vector<std::string> argvTmp; 
+   std::vector<std::string> argvTmp;
    ParseProtocolArgs(args, &argc, &argv, &argvTmp);
 
-   /* Start only if not already initialized. 
+   /* Start only if not already initialized.
     * If there is a game in progress, just return */
    if (m_initialized)
       return;
@@ -442,16 +442,16 @@ void App::OnActivated(CoreApplicationView^ applicationView, IActivatedEventArgs^
       bool reset                 = false;
       int width                  = uwp_get_width();
       int height                 = uwp_get_height();
-      /* Reset driver to D3D11 if set to OpenGL on boot as cores can 
-       * just set to 'gl' when needed and there is no good reason to 
+      /* Reset driver to D3D11 if set to OpenGL on boot as cores can
+       * just set to 'gl' when needed and there is no good reason to
        * use 'gl' for the menus
-       * Do not change the default driver if the content is already 
-       * initialized through arguments, as this would crash RA for 
+       * Do not change the default driver if the content is already
+       * initialized through arguments, as this would crash RA for
        * cores that use only ANGLE */
       settings_t *settings       = config_get_ptr();
       content_state_t *p_content = content_state_get_ptr();
       char *currentdriver        = settings->arrays.video_driver;
-      if (     strcmpi(currentdriver, "gl") == 0 
+      if (     strcmpi(currentdriver, "gl") == 0
             && !p_content->flags & CONTENT_ST_FLAG_IS_INITED)
       {
          /* Set driver to default */
@@ -460,7 +460,7 @@ void App::OnActivated(CoreApplicationView^ applicationView, IActivatedEventArgs^
                config_get_default_video());
          reset = true; /* Reset needed */
       }
-      if (     (settings->uints.video_fullscreen_x != width) 
+      if (     (settings->uints.video_fullscreen_x != width)
             || (settings->uints.video_fullscreen_y != height))
       {
          /* Get width and height from display again */
@@ -482,15 +482,15 @@ void App::OnActivated(CoreApplicationView^ applicationView, IActivatedEventArgs^
 
 void App::OnSuspending(Platform::Object^ sender, SuspendingEventArgs^ args)
 {
-   /* This function will ensure that configs are saved in case the app 
+   /* This function will ensure that configs are saved in case the app
     * is sent to background or terminated for saving configs on quit
-    * for saving configs on quit now configs will be saved in 
+    * for saving configs on quit now configs will be saved in
     * `retroarch_main_quit` at `retroarch.c`
-    * If this function is called because of app closed by quit, 
+    * If this function is called because of app closed by quit,
     * the below code must be ignored
 
-   /* Save app state asynchronously after requesting a deferral. 
-    * Holding a deferral indicates that the application is busy 
+   /* Save app state asynchronously after requesting a deferral.
+    * Holding a deferral indicates that the application is busy
     * performing suspending operations. Be aware that a deferral may
     * not be held indefinitely. After about five seconds, the app will
     * be forced to exit. */
@@ -543,7 +543,7 @@ void App::OnResuming(Platform::Object^ sender, Platform::Object^ args)
 
 void App::OnEnteredBackground(Platform::Object^ sender, EnteredBackgroundEventArgs^ args)
 {
-   /* RetroArch entered background because another app/frontend 
+   /* RetroArch entered background because another app/frontend
     * was launched on exit, so properly quit */
    if (m_launchOnExitShutdown)
       CoreApplication::Exit();
@@ -636,6 +636,8 @@ void App::OnAcceleratorKey(CoreDispatcher^ sender, AcceleratorKeyEventArgs^ args
       mod |= RETROKMOD_CAPSLOCK;
    if ((window->GetKeyState(VirtualKey::Scroll) & CoreVirtualKeyStates::Locked) == CoreVirtualKeyStates::Locked)
       mod |= RETROKMOD_SCROLLOCK;
+   if ((window->GetKeyState(VirtualKey::NumberKeyLock) & CoreVirtualKeyStates::Locked) == CoreVirtualKeyStates::Locked)
+      mod |= RETROKMOD_NUMLOCK;
    if ((window->GetKeyState(VirtualKey::LeftWindows) & CoreVirtualKeyStates::Down) == CoreVirtualKeyStates::Down ||
          (window->GetKeyState(VirtualKey::RightWindows) & CoreVirtualKeyStates::Down) == CoreVirtualKeyStates::Down)
       mod |= RETROKMOD_META;
@@ -743,8 +745,11 @@ void App::OnPackageInstalling(PackageCatalog^ sender,
    if (args->IsComplete)
    {
       char msg[512];
-      snprintf(msg, sizeof(msg), "Package \"%ls\" installed, a restart may be necessary", args->Package->DisplayName->Data());
-      runloop_msg_queue_push(msg, 1, 5 * 60, false, NULL, MESSAGE_QUEUE_ICON_DEFAULT, MESSAGE_QUEUE_CATEGORY_INFO);
+      size_t _len = snprintf(msg, sizeof(msg),
+            "Package \"%ls\" installed, a restart may be necessary",
+            args->Package->DisplayName->Data());
+      runloop_msg_queue_push(msg, _len, 1, 5 * 60, false, NULL,
+            MESSAGE_QUEUE_ICON_DEFAULT, MESSAGE_QUEUE_CATEGORY_INFO);
    }
 }
 
@@ -753,12 +758,12 @@ void App::ParseProtocolArgs(Windows::ApplicationModel::Activation::IActivatedEve
    argvTmp->clear();
    argv->clear();
 
-   /* If the app is activated using protocol, 
+   /* If the app is activated using protocol,
     * it is expected to be in this format:
     * "retroarch:?cmd=<RetroArch CLI arguments>&launchOnExit=<app to launch on exit>"
     * For example:
     * retroarch:?cmd=retroarch -L cores\core_libretro.dll "c:\mypath\path with spaces\game.rom"&launchOnExit=LaunchApp:
-    * "cmd" and "launchOnExit" are optional. If none specified, 
+    * "cmd" and "launchOnExit" are optional. If none specified,
     * it will normally launch into menu
     */
    if (args->Kind == ActivationKind::Protocol)
@@ -780,7 +785,7 @@ void App::ParseProtocolArgs(Windows::ApplicationModel::Activation::IActivatedEve
          {
             std::wstring wsValue(arg->Value->ToString()->Data());
             std::string strValue(wsValue.begin(), wsValue.end());
-            std::istringstream iss(strValue);				
+            std::istringstream iss(strValue);
             std::string s;
 
             /* Set escape character to NULL char to preserve backslashes in
@@ -788,8 +793,8 @@ void App::ParseProtocolArgs(Windows::ApplicationModel::Activation::IActivatedEve
             while (iss >> std::quoted(s, '"', (char)0))
                argvTmp->push_back(s);
          }
-         /* If RetroArch UWP app is started using protocol 
-          * with argument "launchOnExit", this gives an option 
+         /* If RetroArch UWP app is started using protocol
+          * with argument "launchOnExit", this gives an option
           * to launch another app on RA exit,
           * making it easy to integrate RA with other UWP frontends */
          else if (arg->Name == "launchOnExit")
@@ -826,7 +831,7 @@ extern "C" {
    {
       if (App::GetInstance()->IsInitialized())
       {
-         if (fullscreen != 
+         if (fullscreen !=
                ApplicationView::GetForCurrentView()->IsFullScreenMode)
          {
             if (fullscreen)
@@ -838,11 +843,11 @@ extern "C" {
       }
       else
       {
-         /* In case the window is not activated yet, 
-          * TryResizeView will fail and we have to set the 
+         /* In case the window is not activated yet,
+          * TryResizeView will fail and we have to set the
           * initial parameters instead
-          * Note that these are preserved after restarting the app 
-          * and used for the UWP splash screen size (!), so they 
+          * Note that these are preserved after restarting the app
+          * and used for the UWP splash screen size (!), so they
           * should be set only during init and not changed afterwards */
          ApplicationView::PreferredLaunchViewSize      = Size(width, height);
          ApplicationView::PreferredLaunchWindowingMode = fullscreen ? ApplicationViewWindowingMode::FullScreen : ApplicationViewWindowingMode::PreferredLaunchViewSize;
@@ -968,7 +973,7 @@ extern "C" {
                const LONG32 resolution_scale = static_cast<LONG32>(Windows::Graphics::Display::DisplayInformation::GetForCurrentView()->ResolutionScale);
                surface_scale                 = static_cast<float>(resolution_scale) / 100.0f;
                ret                           = static_cast<LONG32>(
-                     CoreWindow::GetForCurrentThread()->Bounds.Height 
+                     CoreWindow::GetForCurrentThread()->Bounds.Height
                      * surface_scale);
                }
                finished = true;
@@ -1012,7 +1017,7 @@ extern "C" {
                const LONG32 resolution_scale = static_cast<LONG32>(Windows::Graphics::Display::DisplayInformation::GetForCurrentView()->ResolutionScale);
                surface_scale = static_cast<float>(resolution_scale) / 100.0f;
                returnValue   = static_cast<LONG32>(
-                     CoreWindow::GetForCurrentThread()->Bounds.Width 
+                     CoreWindow::GetForCurrentThread()->Bounds.Width
                      * surface_scale);
                }
                finished = true;
@@ -1071,12 +1076,12 @@ extern "C" {
       switch (id)
       {
          case RETRO_DEVICE_ID_MOUSE_X:
-            return screen 
-               ? uwp_current_input.mouse_screen_x 
+            return screen
+               ? uwp_current_input.mouse_screen_x
                : uwp_current_input.mouse_rel_x;
          case RETRO_DEVICE_ID_MOUSE_Y:
-            return screen 
-               ? uwp_current_input.mouse_screen_y 
+            return screen
+               ? uwp_current_input.mouse_screen_y
                : uwp_current_input.mouse_rel_y;
          case RETRO_DEVICE_ID_MOUSE_LEFT:
             return uwp_current_input.mouse_left;
@@ -1106,12 +1111,12 @@ extern "C" {
       switch (id)
       {
          case RETRO_DEVICE_ID_POINTER_X:
-            return screen 
-               ? uwp_current_input.touch[idx].full_x 
+            return screen
+               ? uwp_current_input.touch[idx].full_x
                : uwp_current_input.touch[idx].x;
          case RETRO_DEVICE_ID_POINTER_Y:
-            return screen 
-               ? uwp_current_input.touch[idx].full_y 
+            return screen
+               ? uwp_current_input.touch[idx].full_y
                : uwp_current_input.touch[idx].y;
          case RETRO_DEVICE_ID_POINTER_PRESSED:
             return uwp_current_input.touch[idx].isInContact;
